<?php
/**
 *  Uninstall
 *
 *  The uninstall.php performs tasks when uninstalling Indexreloaded
 *
 *  @package Indexreloaded
 */

defined( 'WP_UNINSTALL_PLUGIN' ) || die;

/**
 * Deletes all files in a directory recursively.
 *
 * @param string $dir directory to clear.
 */
function irld_rmdir_recursive( $dir ) {
	$entries = scandir( $dir, SCANDIR_SORT_NONE );
	foreach ( $entries as $entry ) {
		if ( ( '.' === $entry ) || ( '..' === $entry ) ) {
			continue;
		}
		$path = $dir . DIRECTORY_SEPARATOR . $entry;
		if ( is_file( $path ) || is_link( $path ) ) {
			unlink( $path ); // phpcs:ignore WordPress.WP.AlternativeFunctions.unlink_unlink
		} else {
			irld_rmdir_recursive( $path );
		}
	}
	rmdir( $dir ); // phpcs:ignore WordPress.WP.AlternativeFunctions.file_system_operations_rmdir
}

$staticdir = trim( get_option( 'indexreloaded_pathcssjs' ) );
$home_dir  = rtrim( ABSPATH, '/' );
if ( ( strlen( $staticdir ) >= 2 ) && ( '/' === $staticdir[0] ) ) {
	$staticdir = $home_dir . $staticdir;
	if ( is_dir( $staticdir ) ) {
		irld_rmdir_recursive( $staticdir );
	}
}

// Remove options.
global $wpdb;
if ( $wpdb->options ) {
	$wpdb->query( // phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching
		$wpdb->prepare(
			"DELETE FROM {$wpdb->options} WHERE option_name LIKE %s",
			'indexreloaded_%'
		)
	);

} else {
	$wpdb->query( // phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching
		$wpdb->prepare(
			"DELETE FROM {$wpdb->sitemeta} WHERE meta_key LIKE %s",
			'indexreloaded_%'
		)
	);
}
