<?php
/**
 *  Indexreloaded
 *
 *  The Indexreloaded indexreloaded-class reworks the final output from WordPress
 *
 *  @package Indexreloaded\Classes
 */

namespace GiseleWendl\Indexreloaded\Controller;

defined( 'ABSPATH' ) || die( -1 );
if ( ! class_exists( 'Indexreloadedjsmin' ) ) {
	require 'thirdparty/class-indexreloadedjsmin.php';
}

require 'class-indexreloadedcssabovebelow.php';

/**
 * Indexreloaded
 */
class Indexreloaded {
	/**
	 * Modify output? 1 = dont modify original output at all
	 *
	 * @var boolean
	 */
	protected $dontmod = true;
	/**
	 * Modify JS? 1 = dont modify JS at all
	 *
	 * @var boolean
	 */
	protected $dontmodjs = false;
	/**
	 * Modify CSS? 1 = dont modify CSS at all
	 *
	 * @var boolean
	 */
	protected $dontmodcss = false;
	/**
	 * Excludes
	 *
	 * @var array
	 */
	protected $excludesarr = array();
	/**
	 * Includes.
	 *
	 * @var array
	 */
	protected $includesarr = array();
	/**
	 * Excludes for processing
	 *
	 * @var array
	 */
	protected $excludesprocessingarr = array();
	/**
	 * Includes for processing.
	 *
	 * @var array
	 */
	protected $includesprocessingarr = array();
	/**
	 * Folder where Indexreloaded stores JS and CSS-files.
	 *
	 * @var string
	 */
	protected $cssjsfolder = 'cssjs';
	/**
	 * Process files (JS and CSS).
	 *
	 * @var boolean
	 */
	protected $opt_processfiles = true;
	/**
	 * Process JS.
	 *
	 * @var boolean
	 */
	protected $opt_processjsfiles = true;
	/**
	 * Process CSS.
	 *
	 * @var boolean
	 */
	protected $opt_processcssfiles = true;
	/**
	 * JS generated by IndexReloaded will be loaded defered or not.
	 *
	 * @var boolean
	 */
	protected $asynch_last_js = false;
	/**
	 * All JS-files in output will be defered.
	 *
	 * @var boolean
	 */
	protected $defer_all_js = false;
	/**
	 * But dont not defer jquery.
	 *
	 * @var boolean
	 */
	protected $dont_defer_jquery = true;
	/**
	 * Licencing level.
	 *
	 * @var boolean
	 */
	protected $lvc = true;
	/**
	 * Force creation of new files. You can force new files (CSS and JS) with URL-Parameter ?forceNewFiles=1 as well.
	 *
	 * @var boolean
	 */
	protected $force_new_files = false;
	/**
	 * CSS will be compressed
	 *
	 * @var boolean
	 */
	protected $do_crunch_css = true;
	/**
	 *  CSS will be split in above and below the fold
	 *
	 * @var boolean
	 */
	protected $generate_css_below_the_fold = true;
	/**
	 * Remove CSS from output which does not sort out CCSS during CCSS creation.
	 *
	 * @var boolean
	 */
	protected $remove_unneeded_css = true;
	/**
	 * Tags from HTML-model used during CCSS-creation.
	 *
	 * @var array
	 */
	protected $bufferintags = array();
	/**
	 * Classes from HTML-model used during CCSS-creation.
	 *
	 * @var array
	 */
	protected $bufferinclasses = array();
	/**
	 * Numeric Classes excluded from model as proper class names, but here stored away as identifying numeric jail strings. Its later used during CCSS-creation.
	 *
	 * @var array
	 */
	public $bufferinclasses_num = array();
	/**
	 * Input types from HTML-model used during CCSS-creation.
	 *
	 * @var array
	 */
	protected $bufferinputtypes = array();
	/**
	 * Ids from HTML-model used during CCSS-creation.
	 *
	 * @var array
	 */
	protected $bufferinids = array();
	/**
	 * Numeric Ids excluded from model as proper Ids, but here stored away as identifying numeric jail strings. Its later used during CCSS-creation.
	 *
	 * @var array
	 */
	public $bufferinids_num = array();
	/**
	 * Array of identifiers for numeric classes and ids that must be excluded as proper classes or ids from the model for CCSS, for them the concerning identifier is stored in the model
	 *
	 * @var array
	 */
	public $numericjailarray = array( 'menu-', 'wpml-', 'page-', 'post-', 'random-', 'wpfMainWrapper-' );
	/**
	 * Array of identifiers for numeric classes and ids that however must not be excluded as proper classes or ids from the model for CCSS, they serve as a filter for the numericjailarray
	 *
	 * @var array
	 */
	public $numericnojailarray = array( 'tx-page-', 'tx-post-', 'wpml-ls-slot-', 'page-template-txo-onepager-' );

	/**
	 * Tags that during CCSS-creation must stay in CCSS.
	 *
	 * @var array
	 */
	protected $tags_to_keep_above_the_fold = array();
	/**
	 * Classes that during CCSS-creation must stay in CCSS.
	 *
	 * @var array
	 */
	protected $classes_to_keep_above_the_fold = array();
	/**
	 * Ids that during CCSS-creation must stay in CCSS.
	 *
	 * @var array
	 */
	protected $ids_to_keep_above_the_fold = array();

	/**
	 * Make a report for the debug window regarding CCSS creation.
	 *
	 * @var boolean
	 */
	protected $make_folding_css_report = false;
	/**
	 * Array holding entries to the CCSS folding report.
	 *
	 * @var array
	 */
	protected $folding_css_report = array();
	/**
	 * Index for processed CSS.
	 *
	 * @var int
	 */
	protected $if_css_rep = -1;
	/**
	 * Size of the CCSS (above the fold).
	 *
	 * @var int
	 */
	protected $lenoutputcssabove = 0;
	/**
	 * Size of the CSS below the fold.
	 *
	 * @var int
	 */
	protected $lenoutputcssbelow = 0;
	/**
	 * Compress processed JS.
	 *
	 * @var boolean
	 */
	protected $do_compress_js = true;
	/**
	 * Minify processed JS.
	 *
	 * @var boolean
	 */
	protected $opt_minify_js_files = true;
	/**
	 * Show the debug window. You can force the debug window with URL-Parameter ?showDebugWindow=1 as well.
	 *
	 * @var boolean
	 */
	public $show_debug_window = true;
	/**
	 * Html of the debug windows is appended to this tag.
	 *
	 * @var string
	 */
	public $show_debug_window_body_tag = '<body>';
	/**
	 * Array holding identifiers for JS that must not be minimized
	 *
	 * @var array
	 */
	protected $nominifyarr = array();
	/**
	 * In production mode GET-parameters concering Indexreloaded will be ignored
	 *
	 * @var boolean
	 */
	protected $production_mode = false;
	/**
	 * The user_id (0 for anonymous) sorts out a different CSS-naming-rule for loggedin users
	 *
	 * @var boolean
	 */
	protected $user_id = 0;
	/**
	 * Relative path in windows notation to plugin, normally 'wp-content\plugins\indexreloaded'
	 *
	 * @var string
	 */
	protected $extensionrelwinpath = 'wp-content\plugins\indexreloaded';
	/**
	 * Relative path to plugin, normally 'wp-content/plugins/indexreloaded'
	 *
	 * @var string
	 */
	protected $extensionrelpath = 'wp-content/plugins/indexreloaded';
	/**
	 * Server used for licence-verification
	 *
	 * @var string
	 */
	public $donationserver = 'www.toctoc.ch';
	/**
	 * Key of the licenced version.
	 *
	 * @var string
	 */
	public $secret = '';
	/**
	 * Try fix bad CSS adds a nuber of safety checks to CSS remake, always true.
	 *
	 * @var boolean
	 */
	protected $try_fix_bad_css = true;
	/**
	 * Always true, removes defaults from HTML.
	 *
	 * @var boolean
	 */
	protected $fix_html_defaults = true;
	/**
	 * Legacy option, normally false
	 *
	 * @var boolean
	 */
	protected $use_querystring = false;
	/**
	 * If postprocessing take more than this (in ms) the errorlog will show a warning.
	 *
	 * @var int
	 */
	protected $max_execution_time = 800;
	/**
	 * Tag to which the preload-links are prepended.
	 *
	 * @var string
	 */
	protected $preload_tag = '';
	/**
	 * Image (Hero) to be preloaded.
	 *
	 * @var array
	 */
	protected $preloadimage = '';
	/**
	 * List of CSS-files that should be preloadeded.
	 *
	 * @var array
	 */
	protected $preloadstylesarr = array();
	/**
	 * List of JS-files that should be preloadeded.
	 *
	 * @var array
	 */
	protected $preloadscriptsarr = array();
	/**
	 * List of font-files that should be preloadeded.
	 *
	 * @var array
	 */
	protected $preloadfontsarr = array();
	/**
	 * Try to remove "Archive"-strings from page title. Works for English, French and German.
	 *
	 * @var boolean
	 */

	protected $clean_archive_strings_in_pagetitle = true;
	/**
	 * Remove generator metatags.
	 *
	 * @var boolean
	 */
	protected $clean_plugin_notes = true;
	/**
	 * Remove pingback link in HTML.
	 *
	 * @var boolean
	 */
	protected $remove_pingbacks = true;
	/**
	 * Remove RSS-link tag in HTML.
	 *
	 * @var boolean
	 */
	protected $remove_rss = true;
	/**
	 * Remove shortlink tag in HTML.
	 *
	 * @var boolean
	 */
	protected $remove_shortlink = true;
	/**
	 * Load of uncritical CSS with a bigger delay.
	 *
	 * @var int
	 */
	protected $load_cssbelow_in_slowmotion = 0;
	/**
	 * Inline or file-references to CCSS.
	 *
	 * @var boolean
	 */
	protected $inline_ccss = true;
	/**
	 * HTML-body serving as model for CCSS creation.
	 *
	 * @var string
	 */
	public $modelbuffer_body = '';
	/**
	 * Refracted CCSS has a level of refraction which is 0, 1 or 2.
	 *
	 * @var boolean
	 */
	protected $ccss_refracted = 0;
	/**
	 * Include particular CDATA-JS into processing.
	 *
	 * Normally we exclude all CDATA-JS from processing. This list identifies ids of Inline CDATA that isn't excluded from processing.
	 * The reason is that they relay on JS-files loaded before these CDATA JS follows, so one should exclude plenty of JS-files from processing.
	 * As these CDATA-JS do not contain nonces or other values changing at each page load, we should include them into processing.
	 *
	 * @var string
	 */
	protected $cdata_ign_lst = 'lodash-js-after, wp-data-js-after,wp-i18n-js-after,-js-translations';
	/**
	 * Userrole-dependent md5.
	 *
	 * @var string
	 */
	protected $user_role_md5 = '';
	/**
	 * Trace input to jsmin.
	 *
	 * @var boolean
	 */
	protected $errlog_jsmin = false;
	/**
	 * Trace handling of cache during CCSS creation.
	 *
	 * @var boolean
	 */
	protected $errlog_caching = false;
	/**
	 * Parsing HTML content and reorganize CSS and JS.
	 *
	 * @param string $buffer HTML to be post processed.
	 * @param int    $user_id Id of the current user, 0 if not logged in.
	 * @param string $relative_path_to_plugin relative path to extension.
	 * @param string $userrolemd5 md5 identifier for userrole.
	 *
	 * @return string $buffer modified.
	 */
	public function content_post_proc( $buffer, $user_id = 0, $relative_path_to_plugin = '', $userrolemd5 = '' ) {
		$starttimedebug          = microtime( true );
		$starttimedebugcallback  = $starttimedebug;
		$show_debug_window       = false;
		$timestart               = microtime( true );
		$lenbuffer               = strlen( $buffer );
		$this->show_debug_window = $show_debug_window;
		$this->user_id           = $user_id;
		$this->user_role_md5     = $userrolemd5;
		$this->secret            = '';
		$this->donationserver    = '';
		$api_reset               = false;
		$baseurl                 = '';
		$optdirectresponse       = 'wp-admin,.xml,themes/twentythirteen,wordfence,robots,.js,wc-ajax,get_coins_info,get_nonces,min.css,wallets_apiversion,min.js,wp-json,wp-includes,phpMyAdmin,tt-cssjs';
		$arrdirectresponse       = explode( ',', $optdirectresponse );
		$pagename                = $this->current_page_name();
		foreach ( $arrdirectresponse as $directresponse ) {
			if ( ( str_replace( $directresponse, '', $pagename ) !== $pagename ) ) {
				return $buffer;
			}
		}

		$serverrequri = '';
		if ( ! isset( $_SERVER['REQUEST_URI'] ) ) {
			if ( isset( $_SERVER['PHP_SELF'] ) ) {
				$serverrequri = sanitize_text_field( wp_unslash( $_SERVER['PHP_SELF'] ) );
			}
		} else {
			$serverrequri = sanitize_text_field( wp_unslash( $_SERVER['REQUEST_URI'] ) );
		}

		$pagename = $serverrequri;
		foreach ( $arrdirectresponse as $directresponse ) {
			if ( ( str_replace( $directresponse, '', $pagename ) !== $pagename ) ) {
				return $buffer;
			}
		}

		$opts     = require_once realpath( str_replace( 'Classes\Controller', '', str_replace( 'Classes/Controller', '', __DIR__ ) ) ) . DIRECTORY_SEPARATOR .
		str_replace( '/', DIRECTORY_SEPARATOR, 'include/configuration.php' );
		$tempopts = array();
		if ( isset( $opts['0'] ) ) {
			$tempopts = $opts['0'];
			// check for pageopts.
			$pageoptsfound = false;
			foreach ( $opts as $pageopts => $pageopt ) {
				if ( true === $pageoptsfound ) {
					break;
				}

				if ( '0' !== $pageopts ) {
					$pageoptspages = explode( ',', $pageopts );
					if ( count( $pageoptspages ) > 0 ) {
						foreach ( $pageoptspages as $pageoptspage ) {
							if ( str_replace( $pageoptspage, '', $pagename ) !== $pagename ) {
								// pageopts found.
								$pageoptsfound = true;
								$opts          = array_merge( $tempopts, $pageopt );
								break;
							}
						}
					} elseif ( str_replace( $pageopts, '', $pagename ) !== $pagename ) {
							// pageopts found.
							$pageoptsfound = true;
							$opts          = array_merge( $tempopts, $pageopt );
							break;
					}
				}
			}

			if ( false === $pageoptsfound ) {
				$opts = $tempopts;
			}
		}

		$this->cssjsfolder         = 'wp-content/uploads/cssjs';
		$this->secret              = $opts['api_key'];
		$this->donationserver      = trim( $opts['api_server'] );
		$this->extensionrelpath    = str_replace( '\\', '/', $relative_path_to_plugin );
		$this->extensionrelwinpath = str_replace( '/', '\\', $relative_path_to_plugin );
		$current_page_name         = $this->current_page_name();
		if ( '' !== $opts['cssjsfolder'] ) {
			$this->cssjsfolder = $opts['cssjsfolder'];
		}

		if ( '' !== $opts['force_base_url'] ) {
			$baseurl = $opts['force_base_url'];
		}

		$ip = $this->get_client_ip();
		if ( '' !== $opts['debug_ip'] ) {
			if ( '*' === $opts['debug_ip'] ) {
				if ( 1 === intval( $opts['show_debug_window'] ) ) {
					$this->show_debug_window = true;
				}
			} elseif ( $opts['debug_ip'] === $ip ) {
				if ( 1 === intval( $opts['show_debug_window'] ) ) {
					$this->show_debug_window = true;
				}
			}
		}

		$debuginfolding        = '<div>';
		$tdifftolastrun        = 1000 * ( microtime( true ) - $starttimedebug );
		$starttimedebug        = microtime( true );
		$starttimedebugfolding = microtime( true );
		$debuginfolding       .= '<span>Initialize: ' . round( $tdifftolastrun, 1 ) . ' ms</span><br />';
		if ( count( $opts ) > 0 ) {
			if ( '' !== $opts['deactivate_on_pages'] ) {
				$opts['deactivate_on_pages'] = '/wp-admin/,' . $opts['deactivate_on_pages'];
				if ( str_replace( $current_page_name, '', $opts['deactivate_on_pages'] ) !== $opts['deactivate_on_pages'] ) {
					$deactivate_on_pagesarr = explode( ',', str_replace( "\n", '', str_replace( "\r", '', $opts['deactivate_on_pages'] ) ) );
					$cntda                  = count( $deactivate_on_pagesarr );
					$foundpage              = false;
					for ( $i = 0; $i < $cntda; $i++ ) {
						if ( trim( $deactivate_on_pagesarr[ $i ] ) === trim( $current_page_name ) ) {
							$foundpage = true;
							break;
						}
					}

					if ( true === $foundpage ) {
						$opts['dontmod'] = 1;
					}
				}
			}

			if ( 1 === intval( $opts['inline_ccss'] ) ) {
				$this->inline_ccss = true;
			} elseif ( isset( $opts['inline_ccss'] ) ) {
					$this->inline_ccss = false;
			}

			if ( 1 === intval( $opts['generate_css_below_the_fold'] ) ) {
				$this->generate_css_below_the_fold = true;
				if ( 1 === intval( $opts['show_debug_window'] ) ) {
					if ( 1 === intval( $opts['css_folding_report'] ) ) {
						$this->make_folding_css_report = true;
					}
				}
			} elseif ( isset( $opts['generate_css_below_the_fold'] ) ) {
					$this->generate_css_below_the_fold = false;
					$this->inline_ccss                 = false;
			}

			// CDATA-excludes.
			$cdata_ign_lst_arr = explode( ',', $this->cdata_ign_lst );

			// DebugWindow.
			$this_show_debug_window_was_true = false;
			if ( true === $this->show_debug_window ) {
				$this_show_debug_window_was_true = true;
			}

			if ( 0 === intval( $opts['show_debug_window'] ) ) {
				$this->show_debug_window = false;
			}

			$foldingmd5         = '';
			$foldingmd5filename = '';

			/*
			 * for generate_css_below_the_fold here we check the HTML for present tags, classes and ids.
			 * it results in the "document cloud".
			 * In generate_css_below_the_fold the "document cloud" is checked against present CSS.
			 * CSS holding (exclusively) elements from the "document cloud" remain above the fold.
			 */
			if ( true === $this->generate_css_below_the_fold ) {
				if ( '' !== trim( $opts['tags_to_keep_above_the_fold'] ) ) {
					$opts['tags_to_keep_above_the_fold'] = str_replace( ' ', '', str_replace( "\n", '', str_replace( "\r", '', $opts['tags_to_keep_above_the_fold'] ) ) );
					$this->tags_to_keep_above_the_fold   = explode( ',', $opts['tags_to_keep_above_the_fold'] );
				}

				if ( '' !== trim( $opts['classes_to_keep_above_the_fold'] ) ) {
					$opts['classes_to_keep_above_the_fold'] = str_replace( ' ', '', str_replace( "\n", '', str_replace( "\r", '', $opts['classes_to_keep_above_the_fold'] ) ) );
					$this->classes_to_keep_above_the_fold   = explode( ',', $opts['classes_to_keep_above_the_fold'] );
				}

				if ( '' !== trim( $opts['ids_to_keep_above_the_fold'] ) ) {
					$opts['ids_to_keep_above_the_fold'] = str_replace( ' ', '', str_replace( "\n", '', str_replace( "\r", '', $opts['ids_to_keep_above_the_fold'] ) ) );
					$this->ids_to_keep_above_the_fold   = explode( ',', $opts['ids_to_keep_above_the_fold'] );
				}

				$foldingbuffer   = $buffer;
				$foldingmd5      = $this->buffer_fold_meta( $foldingbuffer );
				$tdifftolastrun  = 1000 * ( microtime( true ) - $starttimedebugfolding );
				$debuginfolding .= '<span>Folding element cloud: ' . round( $tdifftolastrun, 1 ) . ' ms</span><br />';
				$starttimedebug  = microtime( true );
				if ( true === $this->generate_css_below_the_fold ) {
					$foldingmd5filename = '-' . $foldingmd5;
				} else {
					$foldingmd5        = '';
					$this->inline_ccss = false;
				}
			}

			if ( 1 === intval( $opts['dontmod'] ) ) {
				$this->dontmod = true;
			} elseif ( isset( $opts['dontmod'] ) ) {
					$this->dontmod = false;
			}

			if ( '' !== trim( $opts['show_debug_window_body_tag'] ) ) {
				$this->show_debug_window_body_tag = $opts['show_debug_window_body_tag'];
			}

			if ( 1 === intval( $opts['force_new_files'] ) ) {
				$this->force_new_files = true;
			} elseif ( isset( $opts['force_new_files'] ) ) {
					$this->force_new_files = false;
			}

			if ( 1 === intval( $opts['dontmodJS'] ) ) {
				$this->dontmodjs = true;
			} elseif ( isset( $opts['dontmodJS'] ) ) {
					$this->dontmodjs = false;
			}

			if ( 1 === intval( $opts['lvc'] ) ) {
				$this->lvc = true;
			} elseif ( isset( $opts['lvc'] ) ) {
					$this->lvc = false;
			}

			$this->remove_unneeded_css = true;
			if ( 0 === intval( $opts['remove_unused_css'] ) ) {
				$this->remove_unneeded_css = false;
			}

			$this->load_cssbelow_in_slowmotion = 1;
			if ( 0 === intval( $opts['load_cssbelow_in_slowmotion'] ) ) {
				$this->load_cssbelow_in_slowmotion = 0;
			}

			if ( 1 === intval( $opts['dontmodCSS'] ) ) {
				$this->dontmodcss = true;
			} elseif ( isset( $opts['dontmodCSS'] ) ) {
					$this->dontmodcss = false;
			}

			if ( 1 === intval( $opts['opt_processfiles'] ) ) {
				$this->opt_processfiles = true;
			} elseif ( isset( $opts['opt_processfiles'] ) ) {
					$this->opt_processfiles = false;
			}

			if ( 1 === intval( $opts['opt_processjsfiles'] ) ) {
				$this->opt_processjsfiles = true;
			} elseif ( isset( $opts['opt_processjsfiles'] ) ) {
					$this->opt_processjsfiles = false;
			}

			if ( true === $this->opt_processjsfiles ) {
				if ( 1 === intval( $opts['asynch_last_js'] ) ) {
					$this->asynch_last_js = true;
				}

				if ( 1 === intval( $opts['defer_all_js'] ) ) {
					$this->defer_all_js = true;
				}

				$this->dont_defer_jquery = false;
				if ( 1 === intval( $opts['dont_defer_jquery'] ) ) {
					$this->dont_defer_jquery = true;
				}
			}

			if ( 1 === intval( $opts['opt_minify_js_files'] ) ) {
				$this->opt_minify_js_files = true;

			} elseif ( isset( $opts['opt_minify_js_files'] ) ) {
					$this->opt_minify_js_files = false;
			}

			if ( 1 === intval( $opts['opt_processcssfiles'] ) ) {
				$this->opt_processcssfiles = true;
			} elseif ( isset( $opts['opt_processcssfiles'] ) ) {
					$this->opt_processcssfiles = false;
			}

			$this->try_fix_bad_css = false;
			if ( 1 === intval( $opts['try_fix_bad_css'] ) ) {
				$this->try_fix_bad_css = true;
			}

			$this->fix_html_defaults = false;
			if ( 1 === intval( $opts['fix_html_defaults'] ) ) {
				$this->fix_html_defaults = true;
			}

			if ( 1 === intval( $opts['do_crunch_css'] ) ) {
				$this->do_crunch_css = true;
			} elseif ( isset( $opts['do_crunch_css'] ) ) {
					$this->do_crunch_css = false;
			}

			if ( isset( $opts['includesarr'] ) ) {
				$this->includesarr = explode( ',', $opts['includesarr'] );
			}

			$jqueryexclude = '';
			if ( isset( $opts['excludesarr'] ) ) {
				if ( '*' !== $opts['excludesarr'] ) {
					if ( str_replace( '/jquery.js', '', $opts['excludesarr'] ) === $opts['excludesarr'] ) {
						$jqarr = explode( '/jquery.js', $buffer );
						if ( count( $jqarr ) === 2 ) {
							$jqueryexclude = '/jquery.js,';
						}
					}

					if ( str_replace( '/jquery.min.js', '', $opts['excludesarr'] ) === $opts['excludesarr'] ) {
						$jqarr = explode( '/jquery.min.js', $buffer );
						if ( count( $jqarr ) === 2 ) {
							$jqueryexclude = '/jquery.min.js,';
						}
					}

					if ( str_replace( "id='jquery-core-js'", '', $opts['excludesarr'] ) === $opts['excludesarr'] ) {
						$jqarr = explode( "id='jquery-core-js'", $buffer );
						if ( count( $jqarr ) === 2 ) {
							$jqueryexclude = "id='jquery-core-js',";
						}
					}

					$opts['excludesarr'] = $jqueryexclude . '[CDATA[,application/ld+json,' . str_replace( "\n", '', str_replace( "\r", '', $opts['excludesarr'] ) );
				}

				$this->excludesarr = explode( ',', $opts['excludesarr'] );
			}

			$this->excludesprocessingarr = $this->excludesarr;
			if ( isset( $opts['includes_processing'] ) ) {
				$this->includesprocessingarr = explode( ',', str_replace( "\n", '', str_replace( "\r", '', $opts['includes_processing'] ) ) );
			}

			$this->nominifyarr       = explode( ',', str_replace( "\n", '', str_replace( "\r", '', $opts['no_minify_js_list'] ) ) );
			$this->preload_tag       = trim( $opts['preload_tag'] );
			$this->preloadimage      = trim( $opts['preload_image'] );
			$this->preloadstylesarr  = explode( ',', str_replace( "\n", '', str_replace( "\r", '', $opts['preload_css_list'] ) ) );
			$this->preloadscriptsarr = explode( ',', str_replace( "\n", '', str_replace( "\r", '', $opts['preload_js_list'] ) ) );
			$this->preloadfontsarr   = explode( ',', str_replace( "\n", '', str_replace( "\r", '', $opts['preload_fonts_list'] ) ) );
			if ( 1 === intval( $opts['clean_archive_strings_in_pagetitle'] ) ) {
				$this->clean_archive_strings_in_pagetitle = true;
			} elseif ( isset( $opts['clean_archive_strings_in_pagetitle'] ) ) {
					$this->clean_archive_strings_in_pagetitle = false;
			}

			if ( 1 === intval( $opts['clean_plugin_notes'] ) ) {
				$this->clean_plugin_notes = true;
			} elseif ( isset( $opts['clean_plugin_notes'] ) ) {
					$this->clean_plugin_notes = false;
			}

			if ( 1 === intval( $opts['remove_pingbacks'] ) ) {
				$this->remove_pingbacks = true;
			} elseif ( isset( $opts['remove_pingbacks'] ) ) {
					$this->remove_pingbacks = false;
			}

			if ( 1 === intval( $opts['remove_rss'] ) ) {
				$this->remove_rss = true;
			} elseif ( isset( $opts['remove_rss'] ) ) {
					$this->remove_rss = false;
			}

			if ( 1 === intval( $opts['remove_shortlink'] ) ) {
				$this->remove_shortlink = true;
			} elseif ( isset( $opts['remove_shortlink'] ) ) {
					$this->remove_shortlink = false;
			}

			if ( 1 === intval( $opts['production_mode'] ) ) {
				$this->production_mode = true;
			}

			// end | configuration options.
			// build some string for debug window, options used.
			$dbgepa = $opts['excludes_processing'];
			$dbgipa = $opts['includes_processing'];
			$dbgea  = $opts['excludesarr'];
			$dbgia  = $opts['includesarr'];
			$dbgnm  = $opts['no_minify_js_list'];
			// end | build some string for debug window, options used.

			// options dependencies.
			if ( true === $this->dontmodjs ) {
				$this->opt_processjsfiles = false;
			}

			if ( true === $this->dontmodcss ) {
				$this->opt_processcssfiles = false;
			}
			// end | options dependencies.
		}

		// more options dependencies.
		if ( true === $this->opt_minify_js_files ) {
			$this->do_compress_js = true;
		} else {
			$this->do_compress_js = false;
		}

		if ( false === $this->production_mode ) {
			if ( isset( $_GET['forceNewFiles'] ) ) { // phpcs:ignore WordPress.Security.NonceVerification.Recommended
				if ( '1' === trim( intval( wp_unslash( $_GET['forceNewFiles'] ) ) ) ) { // phpcs:ignore WordPress.Security.NonceVerification.Recommended
					$this->dontmod             = false;
					$this->dontmodjs           = false;
					$this->dontmodcss          = false;
					$this->opt_processfiles    = true;
					$this->opt_processjsfiles  = true;
					$this->opt_processcssfiles = true;
					$this->force_new_files     = true;
				}
			}

			if ( isset( $_GET['showDebugWindow'] ) ) { // phpcs:ignore WordPress.Security.NonceVerification.Recommended
				if ( '1' === trim( intval( wp_unslash( $_GET['showDebugWindow'] ) ) ) ) { // phpcs:ignore WordPress.Security.NonceVerification.Recommended
					if ( false === $this_show_debug_window_was_true ) {
						$this->show_debug_window = true;
						if ( 1 === intval( $opts['css_folding_report'] ) ) {
							$this->make_folding_css_report = true;
						}
					}
				}
			}

			if ( isset( $_GET['dontModIndex'] ) ) { // phpcs:ignore WordPress.Security.NonceVerification.Recommended
				if ( '1' === trim( intval( wp_unslash( $_GET['dontModIndex'] ) ) ) ) { // phpcs:ignore WordPress.Security.NonceVerification.Recommended
					$this->dontmod = true;
				}
			}
		}

		// ensure options hierarchy.
		if ( false === $this->opt_processcssfiles ) {
			$this->do_crunch_css = false;
		}

		if ( true === $this->dontmodcss ) {
			$this->dontmodcss          = true;
			$this->opt_processcssfiles = false;
			$this->do_crunch_css       = false;
		}

		if ( false === $this->do_compress_js ) {
			$this->opt_minify_js_files = false;
		}

		if ( false === $this->opt_processjsfiles ) {
			$this->do_compress_js      = false;
			$this->opt_minify_js_files = false;
		}

		if ( true === $this->dontmodjs ) {
			$this->opt_processjsfiles  = false;
			$this->do_compress_js      = false;
			$this->opt_minify_js_files = false;
		}

		if ( true === $this->dontmod ) {
			$this->dontmodjs           = true;
			$this->dontmodcss          = true;
			$this->opt_processfiles    = false;
			$this->opt_processjsfiles  = false;
			$this->opt_processcssfiles = false;
			$this->force_new_files     = false;
			$this->do_compress_js      = false;
			$this->opt_minify_js_files = false;
			$this->do_crunch_css       = false;
		}

		if ( true === $this->generate_css_below_the_fold ) {
			$cfg_str_css = 's';
		} else {
			$cfg_str_css = 'a';
		}

		if ( true === $this->do_crunch_css ) {
			$cfg_str_css .= 'c';
		} else {
			$cfg_str_css .= 'u';
		}

		if ( 0 === intval( $this->user_id ) ) {
			$cfg_str_css .= 'a';
		} else {
			$cfg_str_css .= 'l';
		}

		// end more options dependencies.

		// make strings with options used for debug window.
		$debugopt = '';
		if ( true === $this->show_debug_window ) {
			$debuginfo  = '<div id="tt_ri_dbg">';
			$debuginfo .= '<div><span class="tt_ri_dbg_close" title="close debug window" onclick="document.getElementById(\'tt_ri_dbg\').style.display=\'none\';">X</span></div>' .
			'<div class="ttirl_title"><strong>IndexReloaded monitor</strong><br /><span class="ttirlsmall">' . gmdate( 'F j, Y, g:i:s a' ) . '</span></div>';
		} else {
			$debuginfo = '';
		}
		// end make strings with options used for debug window.

		// inits of vars used in this function.
		$scriptoutput             = '';
		$cssoutput                = '';
		$cssoutbelow              = '';
		$excludarrcnt             = count( $this->excludesarr );
		$excludprocessingarrcnt   = count( $this->excludesprocessingarr );
		$includesprocessingarrcnt = count( $this->includesprocessingarr );
		if ( '*' === $this->includesprocessingarr[0] ) {
			$includesprocessingarrcnt = 0;
		}

		$incluedescnt = count( $this->includesarr );
		if ( '*' === $this->includesarr[0] ) {
			$incluedescnt = 0;
		}

		$no_minify_cnt  = count( $this->nominifyarr );
		$cntininecss    = 0;
		$cntininejs     = 0;
		$cntcss         = 0;
		$cntjs          = 0;
		$len_inline_css = 0;
		$len_inline_js  = 0;
		$lencss         = 0;
		$lenjs          = 0;
		$cntoutputcss   = 0;
		$cntoutputjs    = 0;
		$lenoutputcss   = 0;
		$lenoutputjs    = 0;
		$cntkeepcss     = 0;
		$cntkeepcssext  = 0;
		$cntkeepjs      = 0;
		$cntkeepjsext   = 0;
		// end | inits of vars used in this function.
		if ( true === $this->show_debug_window ) {
			$tdifftolastrun = 1000 * ( microtime( true ) - $starttimedebug );
			$starttimedebug = microtime( true );
			$debuginfo     .= $debuginfolding . '<span>Load options: ' . round( $tdifftolastrun, 1 ) . ' ms</span><br /></div>';
		}

		// Save the input and make some basic replacements in the input for the subsequent processing.
		$bufferin = $buffer;
		$buffer   = str_replace( '<!--[IF', '<!--[if', $buffer );
		$buffer   = str_replace( '<![ENDIF]-->', '<![endif]-->', $buffer );
		$buffer   = str_replace( '<SCRIPT', '<script', $buffer );
		$buffer   = str_replace( '</SCRIPT>', '</script>', $buffer );
		$buffer   = str_replace( 'REL="STYLESHEET"', 'rel="stylesheet"', $buffer );
		$buffer   = str_replace( '<LINK', '<link', $buffer );
		$buffer   = str_replace( 'SRC="HTTPS:', 'src="https:', $buffer );
		$buffer   = str_replace( 'SRC="', 'src="', $buffer );
		$buffer   = str_replace( 'HREF="', 'href="', $buffer );
		$buffer   = str_replace( '<STYLE', '<style', $buffer );
		$buffer   = str_replace( '<style >', '<style>', $buffer );
		$buffer   = str_replace( '</STYLE>', '</style>', $buffer );
		$buffer   = str_replace( 'src="' . $baseurl, 'src="/', $buffer );
		$buffer   = str_replace( 'url("' . $baseurl, 'url("/', $buffer );
		$buffer   = str_replace( 'src=\'' . $baseurl, 'src=\'/', $buffer );
		$buffer   = str_replace( 'url(\'' . $baseurl, 'url(\'/', $buffer );
		if ( true === $this->try_fix_bad_css ) {
			// more cleanings.
			require_once 'addons/changes-html.php';
		}

		if ( false === $this->use_querystring ) {
			$verarr      = explode( '.js?ver=', $buffer );
			$countverarr = count( $verarr );
			if ( $countverarr > 0 ) {
				for ( $v = 1; $v < $countverarr; $v++ ) {
					$verarrdimtwo   = explode( '\'', $verarr[ $v ] );
					$verarrdimthree = explode( '"', $verarr[ $v ] );
					$verarrdimfour  = explode( '?', $verarr[ $v ] );
					$leavever       = false;
					if ( count( $verarrdimfour ) > 0 ) {
						if ( count( $verarrdimthree ) > 0 ) {
							if ( strlen( $verarrdimfour[0] ) < strlen( $verarrdimthree[0] ) ) {
								$leavever = true;
							}
						}

						if ( count( $verarrdimtwo ) > 0 ) {
							if ( strlen( $verarrdimfour[0] ) < strlen( $verarrdimtwo[0] ) ) {
								$leavever = true;
							}
						}
					}

					if ( false === $leavever ) {
						if ( ( count( $verarrdimtwo ) > 0 ) && ( count( $verarrdimthree ) > 0 ) ) {
							if ( strlen( $verarrdimtwo[0] ) < strlen( $verarrdimthree[0] ) ) {
								$verarrdimtwo[0] = '';
								$verarr[ $v ]    = implode( '\'', $verarrdimtwo );
							}

							if ( strlen( $verarrdimthree[0] ) < strlen( $verarrdimtwo[0] ) ) {
								$verarrdimthree[0] = '';
								$verarr[ $v ]      = implode( '"', $verarrdimthree );
							}
						} elseif ( ( 0 === count( $verarrdimtwo ) ) && ( count( $verarrdimthree ) > 0 ) ) {
								$verarrdimthree[0] = '';
								$verarr[ $v ]      = implode( '"', $verarrdimthree );
						} elseif ( ( count( $verarrdimtwo ) > 0 ) && ( 0 === count( $verarrdimthree ) ) ) {
								$verarrdimtwo[0] = '';
								$verarr[ $v ]    = implode( '\'', $verarrdimtwo );
						}
					} else {
						$verarr[ $v ] = '?ver=' . $verarr[ $v ];
					}
				}

				$buffer = implode( '.js', $verarr );
			}

			$verarr      = explode( '.css?ver=', $buffer );
			$countverarr = count( $verarr );
			if ( $countverarr > 0 ) {
				for ( $v = 1; $v < $countverarr; $v++ ) {
					$verarrdimtwo   = explode( '\'', $verarr[ $v ] );
					$verarrdimthree = explode( '"', $verarr[ $v ] );
					$verarrdimfour  = explode( '?', $verarr[ $v ] );
					$verarrdimfive  = explode( ',', $verarr[ $v ] );
					$leavever       = false;
					if ( count( $verarrdimfour ) > 0 ) {
						if ( count( $verarrdimthree ) > 0 ) {
							if ( strlen( $verarrdimfour[0] ) < strlen( $verarrdimthree[0] ) ) {
								$leavever = true;
							}
						}

						if ( count( $verarrdimtwo ) > 0 ) {
							if ( strlen( $verarrdimfour[0] ) < strlen( $verarrdimtwo[0] ) ) {
								$leavever = true;
							}
						}

						if ( count( $verarrdimfive ) > 0 ) {
							if ( strlen( $verarrdimfour[0] ) < strlen( $verarrdimfive[0] ) ) {
								$leavever = true;
							}
						}
					}

					if ( false === $leavever ) {
						if ( ( count( $verarrdimtwo ) > 0 ) && ( count( $verarrdimthree ) > 0 ) && ( count( $verarrdimfive ) > 0 ) ) {
							if ( ( strlen( $verarrdimtwo[0] ) < strlen( $verarrdimthree[0] ) ) && ( strlen( $verarrdimtwo[0] ) < strlen( $verarrdimfive[0] ) ) ) {
								$verarrdimtwo[0] = '';
								$verarr[ $v ]    = implode( '\'', $verarrdimtwo );
							}

							if ( ( strlen( $verarrdimthree[0] ) < strlen( $verarrdimtwo[0] ) ) && ( strlen( $verarrdimthree[0] ) < strlen( $verarrdimfive[0] ) ) ) {
								$verarrdimthree[0] = '';
								$verarr[ $v ]      = implode( '"', $verarrdimthree );
							}

							if ( ( strlen( $verarrdimfive[0] ) < strlen( $verarrdimthree[0] ) ) && ( strlen( $verarrdimfive[0] ) < strlen( $verarrdimtwo[0] ) ) ) {
								$verarrdimfive[0] = '';
								$verarr[ $v ]     = implode( ',', $verarrdimfive );
							}
						} elseif ( ( count( $verarrdimtwo ) > 0 ) && ( count( $verarrdimthree ) > 0 ) && ( 0 === count( $verarrdimfive ) ) ) {
							if ( strlen( $verarrdimtwo[0] ) < strlen( $verarrdimthree[0] ) ) {
								$verarrdimtwo[0] = '';
								$verarr[ $v ]    = implode( '\'', $verarrdimtwo );
							}

							if ( strlen( $verarrdimthree[0] ) < strlen( $verarrdimtwo[0] ) ) {
								$verarrdimthree[0] = '';
								$verarr[ $v ]      = implode( '"', $verarrdimthree );
							}
						} elseif ( ( 0 === count( $verarrdimtwo ) ) && ( count( $verarrdimthree ) > 0 ) && ( 0 === count( $verarrdimfive ) ) ) {

								$verarrdimthree[0] = '';
								$verarr[ $v ]      = implode( '"', $verarrdimthree );

						} elseif ( ( count( $verarrdimtwo ) > 0 ) && ( 0 === count( $verarrdimthree ) ) && ( 0 === count( $verarrdimfive ) ) ) {
								$verarrdimtwo[0] = '';
								$verarr[ $v ]    = implode( '\'', $verarrdimtwo );

						} elseif ( ( 0 === count( $verarrdimtwo ) ) && ( count( $verarrdimthree ) > 0 ) && ( count( $verarrdimfive ) > 0 ) ) {
							if ( strlen( $verarrdimfive[0] ) < strlen( $verarrdimthree[0] ) ) {
								$verarrdimfive[0] = '';
								$verarr[ $v ]     = implode( ',', $verarrdimfive );
							}

							if ( strlen( $verarrdimthree[0] ) < strlen( $verarrdimfive[0] ) ) {
								$verarrdimthree[0] = '';
								$verarr[ $v ]      = implode( '"', $verarrdimthree );
							}
						} elseif ( ( count( $verarrdimtwo ) > 0 ) && ( 0 === count( $verarrdimthree ) ) && ( count( $verarrdimfive ) > 0 ) ) {
							if ( strlen( $verarrdimfive[0] ) < strlen( $verarrdimtwo[0] ) ) {
								$verarrdimfive[0] = '';
								$verarr[ $v ]     = implode( ',', $verarrdimfive );
							}

							if ( strlen( $verarrdimtwo[0] ) < strlen( $verarrdimfive[0] ) ) {
								$verarrdimtwo[0] = '';
								$verarr[ $v ]    = implode( '\'', $verarrdimtwo );
							}
						} elseif ( ( 0 === count( $verarrdimtwo ) ) && ( 0 === count( $verarrdimthree ) ) && ( count( $verarrdimfive ) > 0 ) ) {
								$verarrdimfive[0] = '';
								$verarr[ $v ]     = implode( ',', $verarrdimfive );
						}
					} else {
						$verarr[ $v ] = '?ver=' . $verarr[ $v ];
					}
				}

				$buffer = implode( '.css', $verarr );
			}
		}

		if ( true === $this->show_debug_window ) {
			$tdifftolastrun = 1000 * ( microtime( true ) - $starttimedebug );
			$starttimedebug = microtime( true );
			$debuginfo     .= '<div><span>Normalize HTML: ' . round( $tdifftolastrun, 1 ) . ' ms</span><br />';
		}
		// End | save the input and make some basic replacements in the input for the subsequent processing.

		// Checking if-tags for scripts or stylesheets.
		$indexifarr    = explode( '<!--[if', $buffer );
		$indexifarrcnt = count( $indexifarr );
		$condifs       = array();
		$posif         = 0;
		$debug         = '';
		$skippedi      = 0;
		for ( $i = 1; $i < $indexifarrcnt; $i++ ) {
			$indexifarr2                               = explode( ']>', $indexifarr[ $i - $skippedi ] );
			$condifs[ $i - $skippedi - 1 ]['if']       = '<!--[if' . $indexifarr2[0] . ']>';
			$newiflen                                  = strlen( '<!--[if' ) + strlen( $indexifarr2[0] ) + strlen( ']>' );
			$condifs[ $i - $skippedi - 1 ]['iflength'] = $newiflen;
			$indexendifarr2                            = explode( '<![endif]-->', $indexifarr2[1] );
			if ( '' !== trim( str_replace( "\n", '', str_replace( "\r", '', $indexendifarr2[0] ) ) ) ) {
				if ( str_replace( '<script', '', $indexendifarr2[0] ) !== $indexendifarr2[0] ) {
					$condifs[ $i - $skippedi - 1 ]['js'] = 1;
				} else {
					$condifs[ $i - $skippedi - 1 ]['js'] = 0;
				}

				if ( str_replace( 'rel="stylesheet"', '', $indexendifarr2[0] ) !== $indexendifarr2[0] ) {
					$condifs[ $i - $skippedi - 1 ]['css'] = 1;
				} elseif ( str_replace( '<style', '', $indexendifarr2[0] ) !== $indexendifarr2[0] ) {
						$condifs[ $i - $skippedi - 1 ]['css'] = 1;
				} else {
					$condifs[ $i - $skippedi - 1 ]['css'] = 0;
				}
			} else {
				$condifs[ $i - $skippedi - 1 ]['if']       = '';
				$condifs[ $i - $skippedi - 1 ]['iflength'] = '';
				++$skippedi;
			}

			$posif = $posif + strlen( $indexifarr[ $i - $skippedi - 1 ] );
			if ( '' !== trim( $indexendifarr2[0] ) ) {
				$condifs[ $i - $skippedi - 1 ]['posif']        = $posif;
				$condifs[ $i - $skippedi - 1 ]['statementlen'] = strlen( $indexendifarr2[0] );
			}

			$posif = $posif + strlen( '<!--[if' );
		}

		// end | checkin if-tags for scripts or stylesheets.
		$scripts = array();
		// find scripts in the page.
		$i_skipped = 0;
		if ( false === $this->dontmodjs ) {
			$indexjsarr         = explode( '<script', $buffer );
			$indexjsarrcnt      = count( $indexjsarr );
			$posscript          = 0;
			$i_skipped          = 1;
			$posscriptipliscorr = 0;
			$scriptiplusstart   = '';
			$strlenscript       = strlen( '<script' );
			for ( $i = 1; $i < $indexjsarrcnt; $i++ ) {
				$onmissing_end_script = false;
				$posscript            = $posscript + $posscriptipliscorr + strlen( $indexjsarr[ $i - 1 ] );
				$posscriptipliscorr   = 0;
				$scriptiplusstart     = '';
				$strlenscript         = strlen( '<script' );
				$strlenscript_skipped = 0;
				$indexjsarr2          = explode( '</script>', $indexjsarr[ $i ] );
				$indexjsarr2_zero     = $indexjsarr2[0];
				if ( 1 === count( $indexjsarr2 ) ) {
					$onmissing_end_script = true;
					$idx_o_e_s            = 0;

					do {
						// no </script> present, so next script could be part of a document.write("<script .
						if ( ( $i + 1 ) < $indexjsarrcnt ) {
							$concats_endscripttag = false;
							// includes/script-loader.php does a weirdo ... it outputs a </scr' + 'ipt>' );.
							$indexjsarr2_zero_jsconcattest = str_replace( "'+'", '', $indexjsarr2[0] );
							$indexjsarr2_zero_jsconcattest = str_replace( "' + '", '', $indexjsarr2_zero_jsconcattest );
							$indexjsarr2_zero_jsconcattest = str_replace( '"+"', '', $indexjsarr2_zero_jsconcattest );
							$indexjsarr2_zero_jsconcattest = str_replace( '" + "', '', $indexjsarr2_zero_jsconcattest );
							if ( $indexjsarr2_zero_jsconcattest !== $indexjsarr2[0] ) {
								if ( str_replace( '</script>', '', $indexjsarr2_zero_jsconcattest ) !== $indexjsarr2_zero_jsconcattest ) {
									$concats_endscripttag = true;
								}
							}

							if ( 1 === count( $indexjsarr2 ) ) {
								$scriptiplusstart .= '<script' . $indexjsarr2[0];
							} elseif ( count( $indexjsarr2 ) === 2 ) {
								$scriptiplusstart .= '<script' . $indexjsarr2[0] . '</script>' . $indexjsarr2[1];
								if ( true === $concats_endscripttag ) {
									$onmissing_end_script = false;
								}
							} elseif ( count( $indexjsarr2 ) === 3 ) {
								$scriptiplusstart    .= '<script' . $indexjsarr2[0] . '</script>' . $indexjsarr2[1] . '</script>' . $indexjsarr2[2];
								$onmissing_end_script = false;

							}

							++$idx_o_e_s;
							$strlenscript_skipped = $idx_o_e_s * $strlenscript;
							++$i;
							++$i_skipped;
							$posscriptipliscorr += strlen( $indexjsarr[ $i - 1 ] );
							$indexjsarr2         = explode( '</script>', $indexjsarr[ $i ] );

						} else {
							if ( 1 === count( $indexjsarr2 ) ) {
								$scriptiplusstart .= '<script' . $indexjsarr2[0];
							} elseif ( count( $indexjsarr2 ) === 2 ) {
								$scriptiplusstart .= '<script' . $indexjsarr2[0] . '</script>' . $indexjsarr2[1];
							}

							$onmissing_end_script = false;
						}
					} while ( true === $onmissing_end_script );

				} else {
					$scriptiplusstart = '<script' . $indexjsarr2[0];
				}

				$strlenscript = $strlenscript + $strlenscript_skipped;
				$excludethis  = false;
				$excludeall   = false;
				if ( '*' === $this->excludesarr[0] ) {
					$excludeall = true;
				}

				$cnt_cdata_ign_lst_arr = count( $cdata_ign_lst_arr );
				$excludeprocessingthis = false;
				if ( str_replace( 'type="text/html"', '', $indexjsarr2_zero ) !== $indexjsarr2_zero ) {
					$excludethis = true;
				} elseif ( str_replace( 'type="text/template"', '', $indexjsarr2_zero ) !== $indexjsarr2_zero ) {
					$excludethis = true;
				} else {

					for ( $j = 0; $j < $excludarrcnt; $j++ ) {
						if ( true === $excludeall ) {
							$excludethis = true;
							break;
						} elseif ( str_replace( trim( $this->excludesarr[ $j ] ), '', $indexjsarr2_zero ) !== $indexjsarr2_zero ) {
							$excludethis = true;
							if ( trim( $this->excludesarr[ $j ] ) === '[CDATA[' ) {
								for ( $cd = 0; $cd < $cnt_cdata_ign_lst_arr; $cd++ ) {
									if ( str_replace( trim( $cdata_ign_lst_arr[ $cd ] ), '', $indexjsarr2_zero ) !== $indexjsarr2_zero ) {
										$excludethis = false;
										break;
									}
								}
							}

							break;
						}
					}
				}

				$excludeall = false;
				if ( '*' === $this->excludesprocessingarr[0] ) {
					$excludeall = true;
				}

				if ( str_replace( 'type="text/html"', '', $indexjsarr2_zero ) !== $indexjsarr2_zero ) {
					$excludeprocessingthis = true;
				} elseif ( str_replace( 'type="text/template"', '', $indexjsarr2_zero ) !== $indexjsarr2_zero ) {
					$excludeprocessingthis = true;
				} else {
					for ( $j = 0; $j < $excludprocessingarrcnt; $j++ ) {
						if ( true === $excludeall ) {
							$excludeprocessingthis = true;
							break;
						} elseif ( str_replace( trim( $this->excludesprocessingarr[ $j ] ), '', $indexjsarr2_zero ) !== $indexjsarr2_zero ) {
							$excludeprocessingthis = true;
							if ( trim( $this->excludesprocessingarr[ $j ] ) === '[CDATA[' ) {
								for ( $cd = 0; $cd < $cnt_cdata_ign_lst_arr; $cd++ ) {
									if ( str_replace( trim( $cdata_ign_lst_arr[ $cd ] ), '', $indexjsarr2_zero ) !== $indexjsarr2_zero ) {
										$excludeprocessingthis = false;
										break;
									}
								}
							}

							break;
						}
					}
				}

				for ( $j = 0; $j < $incluedescnt; $j++ ) {
					if ( str_replace( trim( $this->includesarr[ $j ] ), '', $indexjsarr2_zero ) !== $indexjsarr2_zero ) {
						$excludethis = false;
					}
				}

				for ( $j = 0; $j < $includesprocessingarrcnt; $j++ ) {
					if ( str_replace( trim( $this->includesprocessingarr[ $j ] ), '', $indexjsarr2_zero ) !== $indexjsarr2_zero ) {
						$excludeprocessingthis = false;
					}
				}

				if ( false === $excludethis ) {
					$scripts[ $i - $i_skipped ]['script']    = $scriptiplusstart . '</script>';
					$scripts[ $i - $i_skipped ]['posscript'] = $posscript;
					if ( true === $excludeprocessingthis ) {
						$scripts[ $i - $i_skipped ]['scriptnoprocessing'] = 1;
					} else {
						$scripts[ $i - $i_skipped ]['scriptnoprocessing'] = 0;
					}
				} else {
					++$cntkeepjs;
					++$i_skipped;
				}

				$posscript = $posscript + $strlenscript;
			}
		}

		// End | find scripts in the page.

		$erradd = '';
		// Find style and stylesheets in the page.

		$cascadingss    = array();
		$cascadingslink = array();
		$cascadingsi    = array();
		$idown          = 1;
		if ( false === $this->dontmodcss ) {
			$indexcssarr    = explode( '<link ', $buffer );
			$indexcssarrcnt = count( $indexcssarr );
			$poscascadings  = 0;
			for ( $i = 1; $i < $indexcssarrcnt; $i++ ) {
				$poscascadings = $poscascadings + strlen( $indexcssarr[ $i - 1 ] );
				$indexcssarr2  = explode( '>', $indexcssarr[ $i ] );
				if ( str_replace( 'rel="stylesheet"', '', $indexcssarr2[0] ) !== $indexcssarr2[0] ) {
					$excludethis           = false;
					$excludeprocessingthis = false;
					$excludeall            = false;
					if ( '*' === $this->excludesarr[0] ) {
						$excludeall = true;
					}

					for ( $j = 0; $j < $excludarrcnt; $j++ ) {
						if ( true === $excludeall ) {
							$excludethis = true;
						} elseif ( str_replace( trim( $this->excludesarr[ $j ] ), '', $indexcssarr2[0] ) !== $indexcssarr2[0] ) {
							$excludethis = true;
						}
					}

					$excludeall = false;
					if ( '*' === $this->excludesprocessingarr[0] ) {
						$excludeall = true;
					}

					for ( $j = 0; $j < $excludprocessingarrcnt; $j++ ) {
						if ( true === $excludeall ) {
							$excludeprocessingthis = true;
						} elseif ( str_replace( trim( $this->excludesprocessingarr[ $j ] ), '', $indexcssarr2[0] ) !== $indexcssarr2[0] ) {
							$excludeprocessingthis = true;
						}
					}

					for ( $j = 0; $j < $incluedescnt; $j++ ) {
						if ( str_replace( trim( $this->includesarr[ $j ] ), '', $indexcssarr2[0] ) !== $indexcssarr2[0] ) {
							$excludethis = false;
						}
					}

					for ( $j = 0; $j < $includesprocessingarrcnt; $j++ ) {
						if ( str_replace( trim( $this->includesprocessingarr[ $j ] ), '', $indexcssarr2[0] ) !== $indexcssarr2[0] ) {
							$excludeprocessingthis = false;
							$erradd               .= 'includesprocessing: indexcssarr2[0]: ' . $indexcssarr2[0] . ' for $i = ' . $i . '<br><br>';
						}
					}

					if ( false === $excludethis ) {
						$cascadingslink[ $i - $idown ]['css']           = '<link ' . $indexcssarr2[0] . '>';
						$cascadingslink[ $i - $idown ]['inlinestyle']   = '';
						$cascadingslink[ $i - $idown ]['poscascadings'] = $poscascadings;
						if ( true === $excludeprocessingthis ) {
							$cascadingslink[ $i - $idown ]['cssnoprocessing'] = 1;
						} else {
							$cascadingslink[ $i - $idown ]['cssnoprocessing'] = 0;
						}
					} else {
						++$cntkeepcss;
						--$cntcss;
						++$idown;
					}
				} else {
					++$idown;
				}

				$poscascadings = $poscascadings + strlen( '<link ' );
			}

			$indexcssinlarr    = explode( '<style', $buffer );
			$indexcssinlarrcnt = count( $indexcssinlarr );
			$poscascadings     = 0;
			$idown             = 1;
			for ( $i = 1; $i < $indexcssinlarrcnt; $i++ ) {
				$containcomment    = false;
				$poscascadings     = $poscascadings + strlen( $indexcssinlarr[ $i - 1 ] );
				$fulltagarr        = explode( '</style>', $indexcssinlarr[ $i ] );
				$styletagcomplete  = '<style' . $fulltagarr[0] . '</style>';
				$indexcssinlarrwrk = str_replace( '<!--', '', $fulltagarr[0] );
				$indexcssinlarrwrk = str_replace( '-->', '', $indexcssinlarrwrk );
				$inlinestyle       = '';
				if ( $indexcssinlarrwrk !== $fulltagarr[0] ) {
					$containcomment  = true;
					$indexcssinlarr2 = explode( '--', $fulltagarr[0] );
					$inlinestyle     = $this->crunchcss( $indexcssinlarr2[1] );
					$fulltagarr[0]   = $inlinestyle;

				}

				$indexcssinlarr2 = explode( '>', $fulltagarr[0] );
				$cntparts        = count( $indexcssinlarr2 );
				$inlinestyleraw  = $indexcssinlarr2[1];
				for ( $x = 2; $x < $cntparts; $x++ ) {
					$inlinestyleraw .= '>' . $indexcssinlarr2[ $x ];
				}

				$inlinestyle = $this->crunchcss( $inlinestyleraw );
				$excludethis = false;
				$excludeall  = false;
				if ( '*' === $this->excludesarr[0] ) {
					$excludeall = true;
				}

				for ( $j = 0; $j < $excludarrcnt; $j++ ) {
					if ( true === $excludeall ) {
						$excludethis = true;
					} elseif ( str_replace( trim( $this->excludesarr[ $j ] ), '', $fulltagarr[0] ) !== $fulltagarr[0] ) {
						$excludethis = true;
					}
				}

				for ( $j = 0; $j < $incluedescnt; $j++ ) {
					if ( str_replace( trim( $this->includesarr[ $j ] ), '', $fulltagarr[0] ) !== $fulltagarr[0] ) {
						$excludethis = false;
					}
				}

				if ( false === $excludethis ) {
					$cascadingsi[ $i - $idown ]['css']             = $styletagcomplete;
					$erradd                                       .= 'INCLUDE FOR $i: ' . $i . ':, $idown: ' . $idown . ', styletag ' . $inlinestyle . '<br><br>';
					$cascadingsi[ $i - $idown ]['inlinestyle']     = $inlinestyle;
					$cascadingsi[ $i - $idown ]['poscascadings']   = $poscascadings;
					$cascadingsi[ $i - $idown ]['cssnoprocessing'] = 0;
				} else {
					++$idown;
				}
			}

			$poscascadings         = $poscascadings + strlen( '<style' );
			$icss                  = 0;
			$cascadingslinkcount   = count( $cascadingslink );
			$cascadingsicount      = count( $cascadingsi );
			$lastib                = 0;
			$ib                    = 0;
			$candposcascadingslink = 0;
			if ( $cascadingslinkcount > 0 ) {
				for ( $i = 0; $i < $cascadingslinkcount; $i++ ) {
					$candposcascadingslink = intval( $cascadingslink[ $i ]['poscascadings'] );
					$foundi2               = 0;
					if ( $cascadingsicount > $lastib ) {
						for ( $ib = $lastib; $ib < $cascadingsicount; $ib++ ) {
							$candposcascadingsi = intval( $cascadingsi[ $ib ]['poscascadings'] );
							if ( $candposcascadingsi < $candposcascadingslink ) {
								$candposcascadings                       = $candposcascadingsi;
								$lastib                                  = $ib + 1;
								$cascadingss[ $icss ]['css']             = $cascadingsi[ $ib ]['css'];
								$cascadingss[ $icss ]['inlinestyle']     = $cascadingsi[ $ib ]['inlinestyle'];
								$cascadingss[ $icss ]['poscascadings']   = $cascadingsi[ $ib ]['poscascadings'];
								$cascadingss[ $icss ]['cssnoprocessing'] = $cascadingsi[ $ib ]['cssnoprocessing'];
								++$icss;
							}
						}
					}

					$cascadingss[ $icss ]['css']             = $cascadingslink[ $i ]['css'];
					$cascadingss[ $icss ]['inlinestyle']     = $cascadingslink[ $i ]['inlinestyle'];
					$cascadingss[ $icss ]['poscascadings']   = $cascadingslink[ $i ]['poscascadings'];
					$cascadingss[ $icss ]['cssnoprocessing'] = $cascadingslink[ $i ]['cssnoprocessing'];
					++$icss;
					if ( ( $i + 1 ) === $cascadingslinkcount ) {
						for ( $ib = $lastib; $ib < $cascadingsicount; $ib++ ) {
								$lastib                                  = $ib + 1;
								$cascadingss[ $icss ]['css']             = $cascadingsi[ $ib ]['css'];
								$cascadingss[ $icss ]['inlinestyle']     = $cascadingsi[ $ib ]['inlinestyle'];
								$cascadingss[ $icss ]['poscascadings']   = $cascadingsi[ $ib ]['poscascadings'];
								$cascadingss[ $icss ]['cssnoprocessing'] = $cascadingsi[ $ib ]['cssnoprocessing'];
								++$icss;
						}
					}
				}
			} elseif ( $cascadingsicount > 0 ) {
				$lastib = 0;
				for ( $ib = $lastib; $ib < $cascadingsicount; $ib++ ) {
					$candposcascadingsi = intval( $cascadingsi[ $ib ]['poscascadings'] );
					if ( $candposcascadingsi < $candposcascadingslink ) {
						$candposcascadings                       = $candposcascadingsi;
						$lastib                                  = $ib + 1;
						$cascadingss[ $icss ]['css']             = $cascadingsi[ $ib ]['css'];
						$cascadingss[ $icss ]['inlinestyle']     = $cascadingsi[ $ib ]['inlinestyle'];
						$cascadingss[ $icss ]['poscascadings']   = $cascadingsi[ $ib ]['poscascadings'];
						$cascadingss[ $icss ]['cssnoprocessing'] = $cascadingsi[ $ib ]['cssnoprocessing'];
						++$icss;
					}
				}
			}
		}

		if ( true === $this->show_debug_window ) {
			$tdifftolastrun = 1000 * ( microtime( true ) - $starttimedebug );
			$starttimedebug = microtime( true );
			$debuginfo     .= '<span>Find scripts and CSS: ' . round( $tdifftolastrun, 1 ) . ' ms</span><br /></div>';
		}
		// end | find style and stylesheets in the page.
		$servername      = str_replace( 'https://', '', site_url() );
		$scriptoutputarr = array();
		if ( false === $this->dontmodjs ) {
			$condifscnt   = count( $condifs );
			$scriptscnt   = count( $scripts );
			$bufferout    = $buffer;
			$icondifs     = -1;
			$externalmode = 0;
			// position on the first if with js inside.
			$condif_info_js = 0;
			do {
				++$icondifs;
				if ( isset( $condifs[ $icondifs ]['js'] ) ) {
					$condif_info_js = $condifs[ $icondifs ]['js'];
				} else {
					$condif_info_js = 0;
				}
			} while ( ( 0 === $condif_info_js ) && ( $icondifs < $condifscnt ) );

			$indexinif        = 0;
			$scriptblock      = 1;
			$scriptsprocessed = 0;
			if ( isset( $scripts[0]['scriptnoprocessing'] ) ) {
				$exludefromprocessing = intval( $scripts[0]['scriptnoprocessing'] );
			} else {
				$exludefromprocessing = 0;
			}

			$forcenewgroupprocessingexcluded = 1;
			$takeendif                       = false;
			for ( $i = 0; $i < $scriptscnt; $i++ ) {
				if ( intval( $scripts[ $i ]['scriptnoprocessing'] ) !== $exludefromprocessing ) {
					$forcenewgroupprocessingexcluded = 0;
					$exludefromprocessing            = intval( $scripts[ $i ]['scriptnoprocessing'] );
					++$scriptblock;
				}
				// Here we replace existing scripts from HTML.
				$bufferout = str_replace( $scripts[ $i ]['script'], '', $bufferout );
				// get rid of CDATA-strings.
				$scripts[ $i ]['script'] = str_replace( '/* <![CDATA[ */', '', $scripts[ $i ]['script'] );
				$scripts[ $i ]['script'] = str_replace( '/* ]]> */', '', $scripts[ $i ]['script'] );
				$scripts[ $i ]['script'] = str_replace( '/*<![CDATA[*/', '', $scripts[ $i ]['script'] );
				$scripts[ $i ]['script'] = str_replace( '/*]]>*/', '', $scripts[ $i ]['script'] );
				if ( $condifscnt > 0 ) {
					if ( $icondifs < $condifscnt ) {
						if ( ( $condifs[ $icondifs ]['posif'] < $scripts[ $i ]['posscript'] ) && ( $condifs[ $icondifs ]['posif'] + $condifs[ $icondifs ]['iflength'] +
							$condifs[ $icondifs ]['statementlen'] > $scripts[ $i ]['posscript'] ) ) {
							$scripts[ $i ]['script']     = "\n" . $condifs[ $icondifs ]['if'] . "\n" . $scripts[ $i ]['script'] . "\n";
							$scriptblock                 = $scriptblock + $forcenewgroupprocessingexcluded;
							$scripts[ $i ]['ifstate']    = $condifs[ $icondifs ]['if'];
							$scripts[ $i ]['script']     = $scripts[ $i ]['script'] . "\n" . '<![endif]-->';
							$scripts[ $i ]['endifstate'] = '<![endif]-->';
							$scripts[ $i ]['block']      = $scriptblock;
							++$scriptsprocessed;
							++$icondifs;
							do {
								++$icondifs;
							} while ( isset( $condifs[ $icondifs ] ) && ( 0 === $condifs[ $icondifs ]['js'] ) &&
									( $condifs[ $icondifs ]['posif'] + $condifs[ $icondifs ]['iflength'] +
									$condifs[ $icondifs ]['statementlen'] <
									$scripts[ $i ]['posscript'] ) &&
									( $icondifs < $condifscnt ) );
						}
					}
				}

				$scripts[ $i ]['block']          = $scriptblock;
				$forcenewgroupprocessingexcluded = 1;
			}

			$scriptoutput = '';

			for ( $i = 0; $i < $scriptscnt; $i++ ) {
				$hostedexternally = false;
				if ( ( str_replace( 'src="//', '', $scripts[ $i ]['script'] ) !== $scripts[ $i ]['script'] ) ||
						( str_replace( 'src="https:', '', $scripts[ $i ]['script'] ) !== $scripts[ $i ]['script'] ) ||
						( str_replace( 'src="http:', '', $scripts[ $i ]['script'] ) !== $scripts[ $i ]['script'] ) ||
						( str_replace( 'src="//cdn:', '', $scripts[ $i ]['script'] ) !== $scripts[ $i ]['script'] ) ||
						( str_replace( '"application/ld+json">', '', $scripts[ $i ]['script'] ) !== $scripts[ $i ]['script'] ) ||
						( str_replace( 'src="//', '', $scripts[ $i ]['script'] ) !== $scripts[ $i ]['script'] ) ||
						( str_replace( 'src=\'//', '', $scripts[ $i ]['script'] ) !== $scripts[ $i ]['script'] ) ||
						( str_replace( 'src=\'https:', '', $scripts[ $i ]['script'] ) !== $scripts[ $i ]['script'] ) ||
						( str_replace( 'src=\'http:', '', $scripts[ $i ]['script'] ) !== $scripts[ $i ]['script'] ) ||
						( str_replace( 'src=\'//cdn:', '', $scripts[ $i ]['script'] ) !== $scripts[ $i ]['script'] ) ) {
					$hostedexternally = true;
					if ( str_replace( '"application/ld+json">', '', $scripts[ $i ]['script'] ) === $scripts[ $i ]['script'] ) {

						if ( str_replace( $servername, '', $scripts[ $i ]['script'] ) !== $scripts[ $i ]['script'] ) {
							$hostedexternally = false;
						}
					}
				}

				if ( true === $hostedexternally ) {
					if ( 0 === $externalmode ) {
						++$scriptblock;
					}

					$scripts[ $i ]['file']                = '';
					$scripts[ $i ]['filequerystring']     = '';
					$scripts[ $i ]['fullfilequerystring'] = '';
					$externalmode                         = 1;
					++$cntkeepjs;
					++$cntkeepjsext;
					--$cntjs;
					// external script.
				} else {
					if ( 1 === $externalmode ) {
						$scripts[ $i ]['script'] = $scripts[ $i ]['script'];
						++$scriptblock;
					}

					$scripts[ $i ]['script'] = str_replace( 'src="http://' . $servername, 'src="', $scripts[ $i ]['script'] );
					$scripts[ $i ]['script'] = str_replace( 'src="https://' . $servername, 'src="', $scripts[ $i ]['script'] );
					$scripts[ $i ]['script'] = str_replace( 'src="//' . $servername, 'src="', $scripts[ $i ]['script'] );
					$scripts[ $i ]['script'] = str_replace( 'src=\'http://' . $servername, 'src=\'', $scripts[ $i ]['script'] );
					$scripts[ $i ]['script'] = str_replace( 'src=\'https://' . $servername, 'src=\'', $scripts[ $i ]['script'] );
					$scripts[ $i ]['script'] = str_replace( 'src=\'//' . $servername, 'src=\'', $scripts[ $i ]['script'] );
					$filearr                 = explode( ' src=', $scripts[ $i ]['script'] );
					if ( isset( $filearr[1] ) ) {
						$filarr_content = $filearr[1];
					} else {
						$filarr_content = '';
					}

					$filearr2  = explode( '"', substr( $filarr_content, 1 ) );
					$filearr22 = explode( '\'', substr( $filarr_content, 1 ) );
					if ( ( 0 !== strlen( $filearr2[0] ) ) && ( 0 !== strlen( $filearr22[0] ) ) ) {
						if ( strlen( $filearr2[0] ) < strlen( $filearr22[0] ) ) {
							$filefilestr = $filearr2[0];
						} else {
							$filefilestr = $filearr22[0];
						}
					} elseif ( ( 0 !== strlen( $filearr2[0] ) ) && ( 0 === strlen( $filearr22[0] ) ) ) {
						$filefilestr = $filearr2[0];
					} elseif ( ( 0 !== strlen( $filearr22[0] ) ) && ( 0 === strlen( $filearr2[0] ) ) ) {
						$filefilestr = $filearr22[0];
					} else {
						$filefilestr = '';
					}

					if ( '\\' === DIRECTORY_SEPARATOR ) {
						// windows.
						$filefromroot = str_replace( '/', '\\', $filefilestr );
					} else {
						$filefromroot = $filefilestr;
					}

					if ( substr( $filefromroot, 0, 1 ) !== DIRECTORY_SEPARATOR ) {
						$filefromroot = DIRECTORY_SEPARATOR . $filefromroot;
					}

					$rawfilestrarr = explode(
						'?',
						realpath(
							str_replace(
								$this->extensionrelwinpath . '\Classes\Controller',
								'',
								str_replace(
									$this->extensionrelpath .
									'/Classes/Controller',
									'',
									__DIR__
								)
							)
						) . $filefromroot
					);
					$rawfilestr    = $rawfilestrarr[0];
					$rawfilestr    = str_replace( '.gzip', '', $rawfilestr );
					if ( str_replace( '.php', '', $rawfilestr ) !== $rawfilestr ) {
						$isphp = 1;
					} else {
						$isphp = 0;
					}

					$scripts[ $i ]['file'] = str_replace( ':\\', ':\\\\', $rawfilestr );
					if ( count( $rawfilestrarr ) > 1 ) {
						$rawfilestrarr2  = explode( '"', $rawfilestrarr[1] );
						$rawfilestrarr22 = explode( '\'', $rawfilestrarr[1] );
						if ( ( 0 !== strlen( $rawfilestrarr2[0] ) ) && ( 0 !== strlen( $rawfilestrarr22[0] ) ) ) {
							if ( strlen( $rawfilestrarr2[0] ) < strlen( $rawfilestrarr22[0] ) ) {
								$rawfilestr = $rawfilestrarr2[0];
							} else {
								$rawfilestr = $rawfilestrarr22[0];
							}
						} elseif ( ( 0 !== strlen( $rawfilestrarr2[0] ) ) && ( 0 === strlen( $rawfilestrarr22[0] ) ) ) {
							$rawfilestr = $rawfilestrarr2[0];
						} elseif ( ( 0 !== strlen( $rawfilestrarr22[0] ) ) && ( 0 === strlen( $rawfilestrarr2[0] ) ) ) {
							$rawfilestr = $rawfilestrarr22[0];
						}

						$rawfilestr = str_replace( ':\\', ':\\\\', $rawfilestr );
						if ( 0 !== intval( $rawfilestr ) ) {
							// like the number 1395835571.
							if ( time() - intval( $rawfilestr ) > 5 ) {
								$scripts[ $i ]['filequerystring']     = $rawfilestr;
								$scripts[ $i ]['fullfilequerystring'] = $rawfilestr;
							}
						} else {
							$scripts[ $i ]['filequerystring']     = '';
							$scripts[ $i ]['fullfilequerystring'] = $rawfilestr;
						}
					}

					if ( 1 === $isphp ) {
						if ( 0 === $externalmode ) {
							$scripts[ $i ]['script'] = "\n" . $scripts[ $i ]['script'];
							++$scriptblock;
						}

						$externalmode = 1;
					} else {
						$externalmode = 0;
					}
				}

				$scripts[ $i ]['block']    = $scriptblock . intval( $scripts[ $i ]['block'] );
				$scripts[ $i ]['external'] = $externalmode;
				$scriptoutput             .= $scripts[ $i ]['script'] . "\n";
			}
		}

		$logscripts      = $scripts;
		$countlogscripts = count( $logscripts );
		for ( $l = 0; $l < $countlogscripts; $l++ ) {
			$logscripts[ $l ]['script'] = substr( $logscripts[ $l ]['script'], 50, 90 );
		}

		// Do the grouping on the CSS.
		$cssoutputarr = array();
		if ( false === $this->dontmodcss ) {
			if ( ! isset( $bufferout ) ) {
				$bufferout = $buffer;
			}

			$condifscnt     = count( $condifs );
			$cascadingsscnt = count( $cascadingss );
			$icondifs       = -1;
			$externalmode   = 0;
			// position on the first if with js inside.
			if ( isset( $condifs[0]['css'] ) ) {
				$condif_info_css = 0;
				do {
					++$icondifs;
					if ( isset( $condifs[ $icondifs ]['css'] ) ) {
						$condif_info_css = $condifs[ $icondifs ]['css'];
					} else {
						$condif_info_css = 0;
					}
				} while ( ( 0 === $condif_info_css ) && ( $icondifs < $condifscnt ) );

			}

			$indexinif    = 0;
			$cssblock     = 1;
			$processedcss = 0;
			if ( isset( $cascadingss[0]['cssnoprocessing'] ) ) {
				$exludefromprocessing = $cascadingss[0]['cssnoprocessing'];
			} else {
				$exludefromprocessing = '';
			}

			$forcenewgroupprocessingexcluded = 1;
			for ( $i = 0; $i < $cascadingsscnt; $i++ ) {
				if ( intval( $cascadingss[ $i ]['cssnoprocessing'] ) !== $exludefromprocessing ) {
					$forcenewgroupprocessingexcluded = 0;
					$exludefromprocessing            = intval( $cascadingss[ $i ]['cssnoprocessing'] );
					++$cssblock;
				}

				$bufferout = str_replace( $cascadingss[ $i ]['css'], '', $bufferout );
				if ( $condifscnt > 0 ) {
					if ( $icondifs < $condifscnt ) {
						if ( ( $condifs[ $icondifs ]['posif'] < $cascadingss[ $i ]['poscascadings'] ) && ( $condifs[ $icondifs ]['posif'] + $condifs[ $icondifs ]['iflength'] +
							$condifs[ $icondifs ]['statementlen'] > $cascadingss[ $i ]['poscascadings'] ) ) {
							$cascadingss[ $i ]['css']            = "\n" . $condifs[ $icondifs ]['if'] . "\n" . $cascadingss[ $i ]['css'] . "\n";
							$cssblock                            = $cssblock + $forcenewgroupprocessingexcluded;
							$cascadingss[ $i ]['ifstate']        = $condifs[ $icondifs ]['if'];
							$cascadingss[ $i - 1 ]['css']        = $cascadingss[ $i - 1 ]['css'] . "\n" . '<![endif]-->';
							$cascadingss[ $i - 1 ]['endifstate'] = '<![endif]-->';
							$cascadingss[ $i ]['block']          = $cssblock;
							++$icondifs;
							++$processedcss;
							do {
								++$icondifs;
							} while ( isset( $condifs[ $icondifs ] ) && ( 0 === $condifs[ $icondifs ]['css'] ) &&
									( $condifs[ $icondifs ]['posif'] + $condifs[ $icondifs ]['iflength'] +
									$condifs[ $icondifs ]['statementlen'] <
									$cascadingss[ $i ]['poscascadings'] ) &&
									( $icondifs < $condifscnt ) );

						}
					}
				}

				$cascadingss[ $i ]['block']      = $cssblock;
				$forcenewgroupprocessingexcluded = 1;
			}

			$cssoutput      = '';
			$cssoutputbelow = '';
			$cssblock       = 1;
			$mediatype      = '';
			for ( $i = 0; $i < $cascadingsscnt; $i++ ) {
				$hostedexternally = false;
				if ( ( str_replace( 'src="https:', '', $cascadingss[ $i ]['css'] ) !== $cascadingss[ $i ]['css'] ) ||
				( str_replace( 'src="http:', '', $cascadingss[ $i ]['css'] ) !== $cascadingss[ $i ]['css'] ) ||
				( str_replace( 'src="//', '', $cascadingss[ $i ]['css'] ) !== $cascadingss[ $i ]['css'] ) ||
				( str_replace( 'href="//', '', $cascadingss[ $i ]['css'] ) !== $cascadingss[ $i ]['css'] ) ||
				( str_replace( 'href="http:', '', $cascadingss[ $i ]['css'] ) !== $cascadingss[ $i ]['css'] ) ||
				( str_replace( 'googleapis.com', '', $cascadingss[ $i ]['css'] ) !== $cascadingss[ $i ]['css'] ) ||
				( str_replace( 'href="https:', '', $cascadingss[ $i ]['css'] ) !== $cascadingss[ $i ]['css'] ) ) {
					$hostedexternally = true;
					if ( str_replace( $servername, '', $cascadingss[ $i ]['css'] ) !== $cascadingss[ $i ]['css'] ) {
						$hostedexternally = false;
					}
				}

				if ( true === $hostedexternally ) {
					if ( 0 === $externalmode ) {
						$cascadingss[ $i ]['css'] = "\n" . $cascadingss[ $i ]['css'];
						++$cssblock;
					}

					$cascadingss[ $i ]['file']                = '';
					$cascadingss[ $i ]['filequerystring']     = '';
					$cascadingss[ $i ]['fullfilequerystring'] = '';
					$cascadingss[ $i ]['path']                = '';
					$cascadingss[ $i ]['mediatype']           = '';
					$externalmode                             = 1;
					++$cntkeepcss;
					++$cntkeepcssext;
					--$cntcss;
					// external css.
				} else {
					if ( 1 === $externalmode ) {
						$cascadingss[ $i ]['css'] = "\n" . $cascadingss[ $i ]['css'];
						++$cssblock;
					}

					// mediatype.
					$mediatype = '';
					$mediaarr  = array();
					$mediaarr  = explode( 'media="', $cascadingss[ $i ]['css'] );
					if ( count( $mediaarr ) > 1 ) {
						$newmediatypearr = explode( '"', $mediaarr[1] );
						if ( count( $newmediatypearr ) > 0 ) {
							$mediatype = $newmediatypearr[0];
						}
					}

					if ( ( '' === $mediatype ) || ( 'all' === trim( $mediatype ) ) ) {
						$cascadingss[ $i ]['mediatype'] = '';
					} else {
						$cascadingss[ $i ]['mediatype'] = '@media ' . trim( $mediatype ) . ' {' . "\n";
					}

					$cascadingss[ $i ]['css'] = str_replace( 'href="http://' . $servername, 'href="', $cascadingss[ $i ]['css'] );
					$cascadingss[ $i ]['css'] = str_replace( 'href="https://' . $servername, 'href="', $cascadingss[ $i ]['css'] );
					$cascadingss[ $i ]['css'] = str_replace( 'href="//' . $servername, 'href="', $cascadingss[ $i ]['css'] );
					$cascadingss[ $i ]['css'] = str_replace( 'href=\'http://' . $servername, 'href=\'', $cascadingss[ $i ]['css'] );
					$cascadingss[ $i ]['css'] = str_replace( 'href=\'https://' . $servername, 'href=\'', $cascadingss[ $i ]['css'] );
					$cascadingss[ $i ]['css'] = str_replace( 'href=\'//' . $servername, 'href=\'', $cascadingss[ $i ]['css'] );
					$filearr                  = explode( 'href=', $cascadingss[ $i ]['css'] );
					if ( isset( $filearr[1] ) ) {
						$filearr_content = $filearr[1];
					} else {
						$filearr_content = '';
					}

					$filearr2     = explode( '"', substr( $filearr_content, 1 ) );
					$pathfromroot = substr( $filearr2[0], 0, strrpos( $filearr2[0], '/' ) );
					if ( substr( $pathfromroot, 0, 1 ) !== '/' ) {
						$pathfromroot = '/' . $pathfromroot;
					}

					if ( '\\' === DIRECTORY_SEPARATOR ) {
						// windows.
						$filefromroot = str_replace( '/', '\\', $filearr2[0] );
					} else {
						$filefromroot = $filearr2[0];
					}

					if ( substr( $filefromroot, 0, 1 ) !== DIRECTORY_SEPARATOR ) {
						$filefromroot = DIRECTORY_SEPARATOR . $filefromroot;
					}

					$filefromroot = str_replace( '.gzip', '', $filefromroot );
					if ( str_replace( '.php', '', $filefromroot ) !== $filefromroot ) {
						$isphp = 1;
					} else {
						$isphp = 0;
					}

					$rawfilestrarr             = explode(
						'?',
						realpath(
							str_replace(
								$this->extensionrelwinpath . '\Classes\Controller',
								'',
								str_replace( $this->extensionrelpath . '/Classes/Controller', '', __DIR__ )
							)
						) .
						$filefromroot
					);
					$rawfilestr                = $rawfilestrarr[0];
					$cascadingss[ $i ]['file'] = str_replace( ':\\', ':\\\\', $rawfilestr );
					if ( count( $rawfilestrarr ) > 1 ) {
						$rawfilestrarr2 = explode( '"', $rawfilestrarr[1] );
						$rawfilestr     = $rawfilestrarr2[0];
						$rawfilestr     = str_replace( ':\\', ':\\\\', $rawfilestr );
						if ( 0 !== intval( $rawfilestr ) ) {
							// like the number 1395835571.
							if ( time() - intval( $rawfilestr ) > 5 ) {
								$cascadingss[ $i ]['filequerystring'] = $rawfilestr;
							}

							$cascadingss[ $i ]['fullfilequerystring'] = $rawfilestr;

						} else {
							$cascadingss[ $i ]['fullfilequerystring'] = $rawfilestr;
						}
					}

					$cascadingss[ $i ]['path'] = $pathfromroot;
					$serveruri                 = '';
					if ( isset( $_SERVER['REQUEST_URI'] ) ) {
						$serveruri = sanitize_text_field( wp_unslash( $_SERVER['REQUEST_URI'] ) );
					}

					$rootpath  = str_replace( ':\\', ':\\\\', realpath( str_replace( 'Classes' . DIRECTORY_SEPARATOR . 'Controller', '', __DIR__ ) ) . DIRECTORY_SEPARATOR );
					$rootpath  = str_replace( $this->extensionrelwinpath . DIRECTORY_SEPARATOR, '', str_replace( $this->extensionrelpath . DIRECTORY_SEPARATOR, '', $rootpath ) );
					$rootpath .= str_replace( '/', DIRECTORY_SEPARATOR, substr( $serveruri, 1 ) );
					if ( ( $cascadingss[ $i ]['file'] === $rootpath )
							&& ( '' === $cascadingss[ $i ]['inlinestyle'] ) ) {
						if ( 0 === $externalmode ) {
							$cascadingss[ $i ]['css'] = "\n" . $cascadingss[ $i ]['css'];
							++$cssblock;
						}

						$externalmode = 1;
					} elseif ( 1 === $isphp ) {
						if ( 0 === $externalmode ) {
							$cascadingss[ $i ]['css'] = "\n" . $cascadingss[ $i ]['css'];
							++$cssblock;
						}

						$externalmode = 1;
					} else {
						$externalmode = 0;
					}
				}

				$cascadingss[ $i ]['external'] = $externalmode;
				$cascadingss[ $i ]['block']    = $cssblock . intval( $cascadingss[ $i ]['block'] );
				$cssoutput                    .= $cascadingss[ $i ]['css'] . "\n";
				if ( true === $this->generate_css_below_the_fold ) {
					$cssoutputbelow .= str_replace( '.css', 'below.css', $cascadingss[ $i ]['css'] ) . "\n";
				}
			}
		}

		// end | Do the grouping on the CSS.
		if ( true === $this->show_debug_window ) {
			$tdifftolastrun = 1000 * ( microtime( true ) - $starttimedebug );
			$starttimedebug = microtime( true );
			$debuginfo     .= '<div><span>Regroup found files: ' . round( $tdifftolastrun, 1 ) . ' ms</span><br />';
		}

		// now build filenames for the master file found from files in blocks and make new scripts array.
		$lastfiletime = 0;
		clearstatcache(); // you can use the clearstatcache() function to clear the information that PHP caches about a file.
		$groupedscripts = array();
		if ( false === $this->dontmodjs ) {
			$iscriptblock = 0;
			$g            = 0;
			$gsub         = 0;
			$tmpmd5str    = '';
			for ( $i = 0; $i < $scriptscnt; $i++ ) {
				if ( intval( $scripts[ $i ]['block'] ) !== $iscriptblock ) {
					$iscriptblock = intval( $scripts[ $i ]['block'] );
					if ( ( '' !== $tmpmd5str ) || ( 0 !== $lastfiletime ) ) {
						$groupedscripts[ $g ]['md5css'] = 'f' . round( $lastfiletime, 0 ) . md5( $tmpmd5str ) . $g . '.js';
					} else {
						$groupedscripts[ $g ]['md5css'] = '';
					}

					$tmpmd5str    = '';
					$lastfiletime = 0;
					++$g;
					$gsub                                 = 0;
					$groupedscripts[ $g ]['scriptoutput'] = "\n";
				}

				$groupedscripts[ $g ]['file'][ $gsub ] = array();
				$namingstring                          = '';
				if ( ( str_replace(
					':\\',
					':\\\\',
					( realpath(
						str_replace(
							$this->extensionrelwinpath . '\Classes\Controller',
							'',
							str_replace( $this->extensionrelpath . '/Classes/Controller', '', __DIR__ )
						)
					) . DIRECTORY_SEPARATOR )
				) === $scripts[ $i ]['file'] ) || ( '' === $scripts[ $i ]['file'] ) ) {
					$groupedscripts[ $g ]['file'][ $gsub ][0] = 'inline';
					++$cntininejs;
					if ( ( 0 === $scripts[ $i ]['external'] ) && ( 0 === $scripts[ $i ]['scriptnoprocessing'] ) ) {
						$groupedscripts[ $g ]['file'][ $gsub ][1] = str_replace( '<!--', '', str_replace( '// -->', '', $scripts[ $i ]['script'] ) );
						$namingstring                             = $groupedscripts[ $g ]['file'][ $gsub ][1];
					} else {
						$groupedscripts[ $g ]['file'][ $gsub ][1] = $scripts[ $i ]['script'];
						$namingstring                             = $groupedscripts[ $g ]['file'][ $gsub ][1];
					}

					$len_inline_js = $len_inline_js + strlen( $groupedscripts[ $g ]['file'][ $gsub ][1] );

				} else {
					++$cntjs;
					$groupedscripts[ $g ]['file'][ $gsub ][0] = $scripts[ $i ]['file'];
					$namingstring                             = $groupedscripts[ $g ]['file'][ $gsub ][0];
					$groupedscripts[ $g ]['file'][ $gsub ][1] = '';

					if ( isset( $groupedscripts[ $g ]['md5css'] ) ) {
						$groupedscripts[ $g ]['md5css'] . ', g: ' . $g . ', i: ' . $i . '<br />';
					}
				}

				if ( isset( $groupedscripts[ $g ]['scriptoutput'] ) ) {
					$groupedscripts[ $g ]['scriptoutput'] .= $scripts[ $i ]['script'] . "\n";
				} else {
					$groupedscripts[ $g ]['scriptoutput'] = $scripts[ $i ]['script'] . "\n";
				}

				if ( ( 0 === $scripts[ $i ]['external'] ) && ( 0 === $scripts[ $i ]['scriptnoprocessing'] ) ) {
					if ( 'inline' !== $groupedscripts[ $g ]['file'][ $gsub ][0] ) {
						if ( ! isset( $scripts[ $i ]['filequerystring'] ) ) {
							$scripts[ $i ]['filequerystring'] = '';
						}

						if ( ! isset( $scripts[ $i ]['fullfilequerystring'] ) ) {
							$scripts[ $i ]['fullfilequerystring'] = '';
						}

						if ( '' !== $scripts[ $i ]['filequerystring'] ) {
							$filetime = $scripts[ $i ]['filequerystring'];
						} elseif ( '' !== $scripts[ $i ]['file'] ) {
							if ( str_replace( '/temp', '', $scripts[ $i ]['file'] ) !== $scripts[ $i ]['file'] ) {
								$filetime = filesize( $scripts[ $i ]['file'] );
							} elseif ( file_exists( $scripts[ $i ]['file'] ) ) {
									$filetime = filemtime( $scripts[ $i ]['file'] );
							} else {
								$serveruri = '';
								if ( isset( $_SERVER['REQUEST_URI'] ) ) {
									$serveruri = sanitize_text_field( wp_unslash( $_SERVER['REQUEST_URI'] ) );
								}

								irld_trace_log( 'IndexReloaded: referenced JS-file "' . $scripts[ $i ]['file'] . '" not found in page ' . $serveruri, 0 );
								$filetime = time();
							}
						} else {
								$filetime = strlen( $scripts[ $i ]['script'] );
						}

						$lastfiletime = ( $lastfiletime + $filetime ) / 2;
					} else {
						$lastfiletime = ( $lastfiletime + strlen( $scripts[ $i ]['script'] ) ) / 2;
					}

					$ifstate = '';
					if ( isset( $scripts[ $i ]['ifstate'] ) ) {
						$ifstate = $scripts[ $i ]['ifstate'] . "\n";
					}

					$endifstate = '';
					if ( isset( $scripts[ $i ]['endifstate'] ) ) {
						$endifstate = $scripts[ $i ]['endifstate'] . "\n";
					}

					if ( isset( $groupedscripts[ $g ]['ifstate'] ) ) {
						$groupedscripts_ifstate = $groupedscripts[ $g ]['ifstate'];
					} else {
						$groupedscripts_ifstate = '';
					}

					if ( '' === $groupedscripts_ifstate ) {
						$groupedscripts[ $g ]['ifstate'] = $groupedscripts_ifstate . $ifstate;
					}

					if ( isset( $groupedscripts[ $g ]['endifstate'] ) ) {
						$groupedscripts_endifstate = $groupedscripts[ $g ]['endifstate'];
					} else {
						$groupedscripts_endifstate = '';
					}

					if ( '' === $groupedscripts_endifstate ) {
						$groupedscripts[ $g ]['endifstate'] = $groupedscripts_endifstate . $endifstate;
					}

					$tmpmd5str .= $namingstring;
				}

				++$gsub;
			}

			if ( ( '' !== $tmpmd5str ) || ( 0 !== $lastfiletime ) ) {
				$groupedscripts[ $g ]['md5css'] = 'f' . round( $lastfiletime, 0 ) . md5( $tmpmd5str ) . $g . '.js';
			} else {
				$groupedscripts[ $g ]['md5css'] = '';
			}

			$groupedscriptscount = count( $groupedscripts );
			$scriptoutput        = '';
			for ( $i = 0; $i < $groupedscriptscount; $i++ ) {
				if ( isset( $groupedscripts[ $i ]['scriptoutput'] ) ) {
					$groupedscripts_scriptoutput = $groupedscripts[ $i ]['scriptoutput'];
				} else {
					$groupedscripts_scriptoutput = '';
				}

				$scriptoutput .= $groupedscripts_scriptoutput;
			}
		}

		// end | now build filenames for the master file found from files in blocks and make new scripts array.
		// now build filenames for blockfiles and make new css array.
		$groupedcss = array();
		if ( false === $this->dontmodcss ) {
			$cssblock     = 0;
			$g            = 0;
			$gsub         = 0;
			$tmpmd5str    = '';
			$lastfiletime = 0;
			$tmpfilename  = '';
			for ( $i = 0; $i < $cascadingsscnt; $i++ ) {
				if ( intval( $cascadingss[ $i ]['block'] ) !== $cssblock ) {
					$cssblock = intval( $cascadingss[ $i ]['block'] );
					if ( ( '' !== $tmpmd5str ) || ( 0 !== $lastfiletime ) ) {
						$groupedcss[ $g ]['md5css'] = 'f' . md5( $tmpfilename . $tmpmd5str ) . '-' . $cfg_str_css . $g . $foldingmd5filename . '.css';
					} else {
						$groupedcss[ $g ]['md5css'] = '';
					}

					$tmpmd5str    = '';
					$lastfiletime = 0;
					$tmpfilename  = '';
					++$g;
					$gsub                          = 0;
					$groupedcss[ $g ]['cssoutput'] = "\n";
				}

				$groupedcss[ $g ]['file'][ $gsub ] = array();
				if ( ( str_replace(
					':\\',
					':\\\\',
					realpath(
						str_replace(
							$this->extensionrelwinpath . '\Classes\Controller',
							'',
							str_replace( $this->extensionrelpath . '/Classes/Controller', '', __DIR__ )
						)
					)
				) . DIRECTORY_SEPARATOR ) === $cascadingss[ $i ]['file'] ) {
					$groupedcss[ $g ]['file'][ $gsub ][0] = 'inline';
					++$cntininecss;
					$groupedcss[ $g ]['file'][ $gsub ][1] = $cascadingss[ $i ]['inlinestyle'];
					$groupedcss[ $g ]['file'][ $gsub ][2] = '';
					$len_inline_css                       = $len_inline_css + strlen( $groupedcss[ $g ]['file'][ $gsub ][1] );
				} else {
					$groupedcss[ $g ]['file'][ $gsub ][0] = $cascadingss[ $i ]['file'];
					++$cntcss;
					$groupedcss[ $g ]['file'][ $gsub ][1] = $cascadingss[ $i ]['path'];
					$groupedcss[ $g ]['file'][ $gsub ][2] = $cascadingss[ $i ]['mediatype'];
				}

				$groupedcss[ $g ]['cssoutput'] .= $cascadingss[ $i ]['css'] . "\n";
				if ( ( 0 === $cascadingss[ $i ]['external'] ) && ( 0 === $cascadingss[ $i ]['cssnoprocessing'] ) ) {
					if ( 'inline' !== $groupedcss[ $g ]['file'][ $gsub ][0] ) {
						if ( isset( $cascadingss[ $i ]['filequerystring'] ) ) {
							$cascadingss_filequerystring = $cascadingss[ $i ]['filequerystring'];
						} else {
							$cascadingss_filequerystring = '';
						}

						if ( '' !== $cascadingss_filequerystring ) {
							$filetime = $cascadingss_filequerystring;
						} elseif ( str_replace( '/temp', '', $cascadingss[ $i ]['file'] ) !== $cascadingss[ $i ]['file'] ) {
								$filetime = filesize( $cascadingss[ $i ]['file'] );
						} elseif ( file_exists( $cascadingss[ $i ]['file'] ) ) {
								$filetime = filemtime( $cascadingss[ $i ]['file'] );
						} else {
							$filetime = time();
						}

						$lastfiletime = ( $lastfiletime + $filetime ) / 2;
						$tmpfilename .= '-' . $filetime;
					} else {
						$tmpmd5str .= 's' . strlen( $cascadingss[ $i ]['css'] ) . '_';
					}

					$ifstate = '';
					if ( isset( $cascadingss[ $i ]['ifstate'] ) ) {
						$ifstate = $cascadingss[ $i ]['ifstate'] . "\n";
					}

					$endifstate = '';
					if ( isset( $cascadingss[ $i ]['endifstate'] ) ) {
						$endifstate = $cascadingss[ $i ]['endifstate'] . "\n";
					}

					if ( isset( $groupedcss[ $g ]['ifstate'] ) ) {
						$groupedcss_ifstate = $groupedcss[ $g ]['ifstate'];
					} else {
						$groupedcss_ifstate = '';
					}

					if ( '' === $groupedcss_ifstate ) {
						$groupedcss[ $g ]['ifstate'] = $groupedcss_ifstate . $ifstate;
					}

					if ( isset( $groupedcss[ $g ]['endifstate'] ) ) {
						$groupedcss_endifstate = $groupedcss[ $g ]['endifstate'];
					} else {
						$groupedcss_endifstate = '';
					}

					if ( '' === $groupedcss_endifstate ) {
						$groupedcss[ $g ]['endifstate'] = $groupedcss_endifstate . $endifstate;
					}
				}

				++$gsub;
			}

			if ( ( '' !== $tmpmd5str ) || ( 0 !== $lastfiletime ) ) {
				$groupedcss[ $g ]['md5css'] = 'f' . md5( $tmpfilename . $tmpmd5str ) . '-' . $cfg_str_css . $g . $foldingmd5filename . '.css';
			} else {
				$groupedcss[ $g ]['md5css'] = '';
			}

			$groupedcsscount = count( $groupedcss );
			$cssoutput       = '';
			for ( $i = 0; $i < $groupedcsscount; $i++ ) {
				if ( isset( $groupedcss[ $i ]['cssoutput'] ) ) {
					$groupedcss_cssoutput = $groupedcss[ $i ]['cssoutput'];
				} else {
					$groupedcss_cssoutput = '';
				}

				$cssoutput .= $groupedcss_cssoutput . "\n";
			}

			if ( true === $this->generate_css_below_the_fold ) {
				$cssoutputbelow = '';
				for ( $i = 0; $i < $groupedcsscount; $i++ ) {
					if ( isset( $groupedcss[ $i ]['cssoutput'] ) ) {
						$cssoutputbelow .= str_replace( '.css', 'below.css', $groupedcss[ $i ]['cssoutput'] ) . "\n";
					}
				}
			}
		}

		// end | build filenames for blockfiles and make new css array.
		if ( true === $this->show_debug_window ) {
			$tdifftolastrun = 1000 * ( microtime( true ) - $starttimedebug );
			$starttimedebug = microtime( true );
			$debuginfo     .= '<span>Create output file names: ' . round( $tdifftolastrun, 1 ) . ' ms</span><br />';
		}

		if ( true === $this->opt_processfiles ) {
			if ( '\\' === DIRECTORY_SEPARATOR ) {
				// windows.
				$filefromroot = str_replace( '/', '\\', $this->cssjsfolder );
			} else {
				$filefromroot = $this->cssjsfolder;
			}

			if ( substr( $filefromroot, 0, 1 ) !== DIRECTORY_SEPARATOR ) {
				$filefromroot = DIRECTORY_SEPARATOR . $filefromroot;
			}

			$checkfolderpath = realpath(
				str_replace(
					$this->extensionrelwinpath . '\Classes\Controller',
					'',
					str_replace( $this->extensionrelpath . '/Classes/Controller', '', __DIR__ )
				)
			) . $filefromroot;
			if ( ! is_dir( $checkfolderpath ) ) {
				if ( '\\' === DIRECTORY_SEPARATOR ) {
					// windows.
					$filefromroot = str_replace( '/', '\\', $this->cssjsfolder );
				} else {
					$filefromroot = $this->cssjsfolder;
				}

				if ( substr( $filefromroot, 0, 1 ) !== DIRECTORY_SEPARATOR ) {
					$filefromroot = DIRECTORY_SEPARATOR . $filefromroot;
				}

				mkdir( realpath( str_replace( $this->extensionrelwinpath . '\Classes\Controller', '', str_replace( $this->extensionrelpath . '/Classes/Controller', '', __DIR__ ) ) ) . $filefromroot ); // phpcs:ignore WordPress.WP.AlternativeFunctions.file_system_operations_mkdir
			}

			if ( true === $this->opt_processjsfiles ) {
				if ( '\\' === DIRECTORY_SEPARATOR ) {
					// windows.
					$filefromroot = str_replace( '/', '\\', $this->cssjsfolder . '/js' );
				} else {
					$filefromroot = $this->cssjsfolder . '/js';
				}

				if ( substr( $filefromroot, 0, 1 ) !== DIRECTORY_SEPARATOR ) {
					$filefromroot = DIRECTORY_SEPARATOR . $filefromroot;
				}

				$checkfolderpath = realpath(
					str_replace(
						$this->extensionrelwinpath . '\Classes\Controller',
						'',
						str_replace( $this->extensionrelpath . '/Classes/Controller', '', __DIR__ )
					)
				) . $filefromroot;

				if ( ! is_dir( $checkfolderpath ) ) {
					if ( '\\' === DIRECTORY_SEPARATOR ) {
						// windows.
						$filefromroot = str_replace( '/', '\\', $this->cssjsfolder . '/js' );
					} else {
						$filefromroot = $this->cssjsfolder . '/js';
					}

					if ( substr( $filefromroot, 0, 1 ) !== DIRECTORY_SEPARATOR ) {
						$filefromroot = DIRECTORY_SEPARATOR . $filefromroot;
					}

					mkdir( realpath( str_replace( $this->extensionrelwinpath . '\Classes\Controller', '', str_replace( $this->extensionrelpath . '/Classes/Controller', '', __DIR__ ) ) ) . $filefromroot ); // phpcs:ignore WordPress.WP.AlternativeFunctions.file_system_operations_mkdir
				}

				$processedfiles = 0;
				if ( str_replace( ':\\\\', '', $checkfolderpath ) === $checkfolderpath ) {
					$checkfolderpath = str_replace( ':\\', ':\\\\', $checkfolderpath );
				}

				for ( $i = 0; $i <= $groupedscriptscount; $i++ ) {
					if ( isset( $groupedscripts[ $i ]['md5css'] ) ) {
						$groupedscripts_md5css = $groupedscripts[ $i ]['md5css'];
					} else {
						$groupedscripts_md5css = '';
					}

					if ( '' !== $groupedscripts_md5css ) {
						if ( ( ! file_exists( $checkfolderpath . DIRECTORY_SEPARATOR . $groupedscripts[ $i ]['md5css'] ) ) || ( true === $this->force_new_files ) ) {
							$groupedfilescount = count( $groupedscripts[ $i ]['file'] );
							$filecontent       = '';
							for ( $j = 0; $j < $groupedfilescount; $j++ ) {
								$writejstext = '';
								$checkfile   = $groupedscripts[ $i ]['file'][ $j ][0];

								if ( 'inline' === $groupedscripts[ $i ]['file'][ $j ][0] ) {
									$writejstext       = str_replace( '</script>', '', $groupedscripts[ $i ]['file'][ $j ][1] );
									$writejstextarr    = explode( '>', $writejstext );
									$writejstextarr[0] = 'inlinestarttag';
									$writejstext       = str_replace( 'inlinestarttag>', '', implode( '>', $writejstextarr ) );
									if ( true === $this->do_compress_js ) {
										$writejstextarrspace = explode( ' ', $writejstext );
										$writejstextarrtabs  = explode( "\n", $writejstext );
										if ( ( count( $writejstextarrspace ) + count( $writejstextarrtabs ) ) > 4 ) {
											$excludethis = false;
											for ( $nomini = 0; $nomini < $no_minify_cnt; $nomini++ ) {
												if ( str_replace( trim( $this->nominifyarr[ $nomini ] ), '', $writejstext ) !== $writejstext ) {
													$excludethis = true;
												}
											}

											if ( false === $excludethis ) {
												if ( false === $this->is_compressed( $writejstext ) ) {
													if ( true === $this->errlog_jsmin ) {
														irld_trace_log( 'Compressing Inline ' . substr( $writejstext, 0, 256 ) );
													}

													$writejstext = $this->compressjs( $writejstext, $this->opt_minify_js_files );
												} else {
													if ( true === $this->errlog_jsmin ) {
														irld_trace_log( 'Not Compressing Inline ' . substr( $writejstext, 0, 256 ) );
													}

													$writejstext = $this->compressjs( $writejstext, $this->opt_minify_js_files, true );
												}
											}
										}
									}
								} elseif ( file_exists( $checkfile ) ) {
									$writejstext = file_get_contents( $checkfile ); // phpcs:ignore WordPress.WP.AlternativeFunctions.file_get_contents_file_get_contents
									$lenjs       = $lenjs + strlen( $writejstext );
									if ( str_replace( 'function ', '', $writejstext ) !== $writejstext ) {
										if ( true === $this->do_compress_js ) {
											$writejstextarrspace = explode( ' ', $writejstext );
											$writejstextarrtabs  = explode( "\n", $writejstext );
											if ( count( $writejstextarrspace ) + count( $writejstextarrtabs ) > 4 ) {
												$excludethis = false;
												for ( $nomini = 0; $nomini < $no_minify_cnt; $nomini++ ) {
													if ( str_replace( trim( $this->nominifyarr[ $nomini ] ), '', $writejstext ) !== $writejstext ) {
														$excludethis = true;
													}
												}

												if ( false === $excludethis ) {
													if ( false === $this->is_compressed( $writejstext ) ) {
														if ( true === $this->errlog_jsmin ) {
															irld_trace_log( 'Compressing file ' . $checkfile );
														}

														$writejstext = $this->compressjs( $writejstext, $this->opt_minify_js_files );
													} else {
														if ( true === $this->errlog_jsmin ) {
															irld_trace_log( 'Not compressing file ' . $checkfile );
														}

														$writejstext = $this->compressjs( $writejstext, $this->opt_minify_js_files, true );
													}
												}
											} else {
												// remove comments.
												$writejstext = preg_replace( '!/\*[^*]*\*+([^/][^*]*\*+)*/!', '', $writejstext );
											}
										}
									} elseif ( true === $this->do_compress_js ) {
											$writejstextarrspace = explode( ' ', $writejstext );
											$writejstextarrtabs  = explode( "\n", $writejstext );
										if ( count( $writejstextarrspace ) + count( $writejstextarrtabs ) > 4 ) {
											$excludethis = false;
											for ( $nomini = 0; $nomini < $no_minify_cnt; $nomini++ ) {
												if ( str_replace( trim( $this->nominifyarr[ $nomini ] ), '', $writejstext ) !== $writejstext ) {
													$excludethis = true;
												}
											}

											if ( false === $excludethis ) {
												if ( false === $this->is_compressed( $writejstext ) ) {
													if ( true === $this->errlog_jsmin ) {
														irld_trace_log( 'Compressing file without "function " ' . $checkfile );
													}

													$writejstext = $this->compressjs( $writejstext, $this->opt_minify_js_files );
												} else {
													if ( true === $this->errlog_jsmin ) {
														irld_trace_log( 'Not compressing file without "function " ' . $checkfile );
													}

													$writejstext = $this->compressjs( $writejstext, $this->opt_minify_js_files, true );
												}
											}
										} else {
												$writejstext = preg_replace( '!/\*[^*]*\*+([^/][^*]*\*+)*/!', '', $writejstext );
										}
									}

									++$processedfiles;
								}

								if ( false === $this->opt_minify_js_files ) {
									$writejstext = '{' . "\n" . $writejstext . '}' . "\n";
								} else {
									$writejstext = '{' . $writejstext . "}\n";
								}

								$filecontent .= $writejstext;
							}

							$contentmd5 = md5( $filecontent );
							file_put_contents( $checkfolderpath . DIRECTORY_SEPARATOR . $groupedscripts[ $i ]['md5css'], $filecontent ); // phpcs:ignore WordPress.WP.AlternativeFunctions.file_system_operations_file_put_contents
							++$cntoutputjs;
							$lenoutputjs = $lenoutputjs + strlen( $filecontent );
						}

						$ifstate = '';
						if ( isset( $groupedscripts[ $i ]['ifstate'] ) ) {
							$ifstate = $groupedscripts[ $i ]['ifstate'];
						}

						$endifstate = '';
						if ( isset( $groupedscripts[ $i ]['endifstate'] ) ) {
							$endifstate = $groupedscripts[ $i ]['endifstate'];
						}

						$async = '';

						if ( true === $this->asynch_last_js ) {
							$async = 'defer ';
						}

						$groupedscripts[ $i ]['scriptoutput'] = $ifstate . '<script id="indexreloaded-js-' . $i . '" ' . $async . 'src="/' . $this->cssjsfolder . '/js/' . $groupedscripts[ $i ]['md5css'] .
						'" type="text/javascript"></script>' . $endifstate . "\n";
					}
				}

				$groupedscriptscount = count( $groupedscripts );
				$scriptoutput        = '';
				for ( $i = 0; $i < $groupedscriptscount; $i++ ) {
					if ( isset( $groupedscripts[ $i ]['scriptoutput'] ) ) {
						$groupedscripts_i_scriptoutput = $groupedscripts[ $i ]['scriptoutput'];
					} else {
						$groupedscripts_i_scriptoutput = '';
					}

					$scriptoutput .= $groupedscripts_i_scriptoutput;
				}

				$tdifftolastrun = 1000 * ( microtime( true ) - $starttimedebug );
				$starttimedebug = microtime( true );
				if ( true === $this->show_debug_window ) {
					$debuginfo .= '<span>Check output, ' . $groupedscriptscount . ' JS files: ' . round( $tdifftolastrun, 1 ) . ' ms</span><br />';
				}
			}

			$starttimedebugcss = microtime( true );
			// css files.
			if ( true === $this->opt_processcssfiles ) {
				if ( '\\' === DIRECTORY_SEPARATOR ) {
					// windows.
					$filefromroot = str_replace( '/', '\\', $this->cssjsfolder . '/css' );
				} else {
					$filefromroot = $this->cssjsfolder . '/css';
				}

				if ( substr( $filefromroot, 0, 1 ) !== DIRECTORY_SEPARATOR ) {
					$filefromroot = DIRECTORY_SEPARATOR . $filefromroot;
				}

				$checkfolderpath = realpath(
					str_replace(
						$this->extensionrelwinpath . '\Classes\Controller',
						'',
						str_replace(
							$this->extensionrelpath . '/Classes/Controller',
							'',
							__DIR__
						)
					)
				) . $filefromroot;
				if ( str_replace( ':\\\\', '', $checkfolderpath ) === $checkfolderpath ) {
					$checkfolderpath = str_replace( ':\\', ':\\\\', $checkfolderpath );
				}

				if ( ! is_dir( $checkfolderpath ) ) {
					if ( '\\' === DIRECTORY_SEPARATOR ) {
						// windows.
						$filefromroot = str_replace( '/', '\\', $this->cssjsfolder . '/css' );
					} else {
						$filefromroot = $this->cssjsfolder . '/css';
					}

					if ( substr( $filefromroot, 0, 1 ) !== DIRECTORY_SEPARATOR ) {
						$filefromroot = DIRECTORY_SEPARATOR . $filefromroot;
					}

					mkdir( realpath( str_replace( $this->extensionrelwinpath . '\Classes\Controller', '', str_replace( $this->extensionrelpath . '/Classes/Controller', '', __DIR__ ) ) ) . $filefromroot ); // phpcs:ignore WordPress.WP.AlternativeFunctions.file_system_operations_mkdir
				}

				$processedfiles = 0;
				$j2             = 0;
				if ( true === $this->generate_css_below_the_fold ) {
					$starttimedebugmerge = microtime( true );
				}

				$debugmergetime    = 0;
				$cntoutputcssbelow = 0;
				for ( $i = 0; $i < $groupedcsscount; $i++ ) {
					if ( '' !== $groupedcss[ $i ]['md5css'] ) {
						if ( ( ! file_exists( $checkfolderpath . DIRECTORY_SEPARATOR . $groupedcss[ $i ]['md5css'] ) ) || ( true === $this->force_new_files ) ) {
							$groupedfilescount = count( $groupedcss[ $i ]['file'] );
							$filecontent       = '';
							if ( ( true === $this->generate_css_below_the_fold ) && ( true === $this->remove_unneeded_css ) ) {
								$spiltselector = '.indexreloadedcontrol{}';
							} else {
								$spiltselector = '';
							}
							for ( $j = 0; $j < $groupedfilescount; $j++ ) {
								$writecsstext = '';
								$checkfile    = $groupedcss[ $i ]['file'][ $j ][0];
								if ( 'inline' === $groupedcss[ $i ]['file'][ $j ][0] ) {
									$groupedcss[ $i ]['file'][ $j ][1] = str_replace( "\n", '', $groupedcss[ $i ]['file'][ $j ][1] );
									$writecsstext                      = str_replace( '</style>', '', $groupedcss[ $i ]['file'][ $j ][1] );
									$writecsstextarr                   = explode( '>', $writecsstext );
									if ( count( $writecsstextarr ) > 1 ) {
										$writecsstextarr[0] = 'inlinestarttag>' . $writecsstextarr[0];
										$writecsstext       = str_replace( 'inlinestarttag>', "\n", implode( '>', $writecsstextarr ) ) . "\n";
										$erradd            .= '$writecsstext ' . $writecsstext . '<br><br>';
									}

									$writecsstext = $this->handle_css_at_import_files( $writecsstext, '', array(), 0 );
								} elseif ( file_exists( $checkfile ) ) {
									$writecsstext         = file_get_contents( $checkfile ); // phpcs:ignore WordPress.WP.AlternativeFunctions.file_get_contents_file_get_contents
									$checkpath            = $groupedcss[ $i ]['file'][ $j ][1];
									$checkpatharr         = explode( '/', $checkpath );
									$countcheckpatharr    = count( $checkpatharr );
									$writecsstext         = $this->handle_css_at_import_files( $writecsstext, $checkpath, $checkpatharr, $countcheckpatharr );
									$lencss               = $lencss + strlen( $writecsstext );
									$hypos                = '';
									$writecsstextarr      = explode( 'url(', $writecsstext );
									$writecsstextarrcount = count( $writecsstextarr );
									for ( $q = 1; $q < $writecsstextarrcount; $q++ ) {
										$hypos = '';
										if ( substr( $writecsstextarr[ $q ], 0, 1 ) === '\'' ) {
											$writecsstextarr[ $q ] = substr( $writecsstextarr[ $q ], 1 );
											$hypos                 = '\'';
										}

										if ( substr( $writecsstextarr[ $q ], 0, 1 ) === '"' ) {
											$writecsstextarr[ $q ] = substr( $writecsstextarr[ $q ], 1 );
											$hypos                 = '"';
										}

										$writecsstextarr2 = explode( $hypos . ')', $writecsstextarr[ $q ] );
										$urltocheck       = $writecsstextarr2[0];
										$urltocheckout    = str_replace( 'https://', '', $urltocheck );
										$urltocheckout    = str_replace( 'http://', '', $urltocheckout );
										$urltocheckout    = str_replace( 'data:', '', $urltocheckout );
										if ( $urltocheckout === $urltocheck ) {
											if ( substr( $urltocheck, 0, 1 ) !== '/' ) {
												$checkuppatharr      = explode( '../', $urltocheck );
												$countcheckuppatharr = count( $checkuppatharr );
												if ( $countcheckuppatharr > 0 ) {
													$outurltocheck      = $checkuppatharr[ $countcheckuppatharr - 1 ];
													$outurltocheckpart1 = '';
													for ( $p = 0; $p <= ( $countcheckpatharr - $countcheckuppatharr ); $p++ ) {
														$outurltocheckpart1 .= $checkpatharr[ $p ] . '/';
													}

													$urltocheck = $outurltocheckpart1 . $outurltocheck;
												} else {
													$urltocheck = $checkpath . '/' . $urltocheck;
												}

												$writecsstextarr2[0] = $urltocheck;
											}
										}

										$writecsstextarr[ $q ] = $hypos . implode( $hypos . ')', $writecsstextarr2 );
									}

									$writecsstext = implode( 'url(', $writecsstextarr );
									++$processedfiles;
								}

								$endmediatype   = '';
								$startmediatype = '';
								if ( '' !== $groupedcss[ $i ]['file'][ $j ][2] ) {
									$endmediatype           = "\n" . '}';
									$startmediatype         = $groupedcss[ $i ]['file'][ $j ][2];
									$startatmedia           = str_replace( '@media ', '', $startmediatype );
									$startatmedia           = str_replace( ' {' . "\n", '', $startatmedia );
									$startatmedia           = '(' . $startatmedia . ')';
									$writecsstextwrk        = $this->crunchcss( $writecsstext );
									$writecsstextatmediaarr = explode( '@media', $writecsstextwrk );
									$cntatmediaintext       = count( $writecsstextatmediaarr );
									if ( $cntatmediaintext > 1 ) {
										$writecsstextout  = '';
										$writecsstextout .= $writecsstextatmediaarr[0] . $endmediatype . "\n";
										for ( $mt = 1; $mt < $cntatmediaintext; $mt++ ) {
											// mediatype.
											$mediatype = '';
											$mediaarr  = array();
											$mediaarr  = explode( '{', $writecsstextatmediaarr[ $mt ] );
											if ( count( $mediaarr ) > 0 ) {
												$mediatype = $startatmedia . ' and (' . trim( $mediaarr[0] ) . ')';
												array_shift( $mediaarr );
											}

											$writecsstextatmediaarr[ $mt ] = implode( '{', $mediaarr );
											if ( '}' === $writecsstextatmediaarr[ $mt ] ) {
												// EMPTY AT MEDIA, DROP.
												$writecsstextout .= '';
											} else {
												$mediaarr2 = explode( '}}', $writecsstextatmediaarr[ $mt ] );
												if ( count( $mediaarr2 ) > 1 ) {
													$writecsstextout .= '@media ' . trim( $mediatype ) . ' {' . "\n" . $mediaarr2[0] . '}' . $endmediatype . "\n";
													if ( '' !== trim( $mediaarr2[1] ) ) {
														$writecsstextout .= $startmediatype . $mediaarr2[1] . '}' . "\n";
													}
												} else {
													$writecsstextout .= '@media ' . trim( $mediatype ) . ' {' . "\n" . $writecsstextatmediaarr[ $mt ] .
													$endmediatype . "\n";
												}
											}
										}

										$endmediatype = '';
										$writecsstext = $writecsstextout;
									}
								}

								$filecontent .= $startmediatype . $writecsstext . $spiltselector . $endmediatype . "\n";
							}

							if ( true === $this->try_fix_bad_css ) {
								// the special filter for the crimes of Daniel Martin.
								// please don't laugh - it is true - hold on.
								$filecontent = str_replace( '  ', ' ', $filecontent );
								$filecontent = str_replace( '@  font-face', '@font-face', $filecontent );
								$filecontent = str_replace( '_float: left', 'float: inherit', $filecontent );

								if ( str_replace( '<?php', '', $filecontent ) !== $filecontent ) {
									$filecontent = $this->crunchcss( $filecontent );
									$filecontent = str_replace( 'screenand', 'screen and', $filecontent );
									// then probably it's him, he made again an "exclusive" site (WordPress...).
									// with self protected code.
									$danielmartinphpcrimes = explode( '<?php', $filecontent );
									$countdmc              = count( $danielmartinphpcrimes );
									for ( $dm = 1; $dm < $countdmc; $dm++ ) {
										// let's suppose there's always an end tag.
										$danielmartinphpcrimesendtags = explode( '?>', $danielmartinphpcrimes[ $dm ] );
										array_shift( $danielmartinphpcrimesendtags );
										$danielmartinphpcrimes[ $dm ] = implode( '', $danielmartinphpcrimesendtags );
									}

									$filecontent = implode( '', $danielmartinphpcrimes );
								}

								if ( str_replace( 'w\\', '', $filecontent ) !== $filecontent ) {
									// now stupidities like "t\op:19px;".
									$filecontent           = $this->crunchcss( $filecontent );
									$danielmartinphpcrimes = explode( 't\\', $filecontent );
									$countdmc              = count( $danielmartinphpcrimes );
									for ( $dm = 1; $dm < $countdmc; $dm++ ) {
										// let's suppose there's always an end tag ...
										$danielmartinphpcrimesendtags = explode( ';', $danielmartinphpcrimes[ $dm ] );
										array_shift( $danielmartinphpcrimesendtags );
										$danielmartinphpcrimes[ $dm ] = implode( ';', $danielmartinphpcrimesendtags );
									}

									$filecontent           = implode( '', $danielmartinphpcrimes );
									$danielmartinphpcrimes = explode( 'w\\', $filecontent );
									$countdmc              = count( $danielmartinphpcrimes );
									for ( $dm = 1; $dm < $countdmc; $dm++ ) {
										// let's suppose there's always an end tag.
										$danielmartinphpcrimesendtags = explode( ';', $danielmartinphpcrimes[ $dm ] );
										array_shift( $danielmartinphpcrimesendtags );
										$danielmartinphpcrimes[ $dm ] = implode( ';', $danielmartinphpcrimesendtags );
									}

									$filecontent = implode( '', $danielmartinphpcrimes );
								}
							}

							$addcharsetutf = false;
							if ( str_replace( '@charset "UTF-8";', '', $filecontent ) !== $filecontent ) {
								if ( false === $this->generate_css_below_the_fold ) {
									$filecontent = str_replace( '@charset "UTF-8";', '', $filecontent );
									$filecontent = '@charset "UTF-8";' . "\n" . $filecontent;
								}

								$addcharsetutf = true;
							}

							if ( true === $this->generate_css_below_the_fold ) {
								$starttimedebugmerge = microtime( true );
								$filecontents        = array();
								$filecontentsave     = $filecontent;
								$filecontent         = $this->crunchcss( $filecontent );
								++$this->if_css_rep;
								$unsetgenerate_css_below_the_fold = false;
								if ( ( strlen( $this->secret ) !== 20 ) && ( strlen( $this->secret ) !== 19 ) ) {
									$unsetgenerate_css_below_the_fold = true;
								} elseif ( '' !== $filecontent ) {
										$filecontents = $this->split_css_below_above_the_fold( $filecontent );
								}

								if ( ( '' === $filecontents ) || ( true === $unsetgenerate_css_below_the_fold ) ) {
									// fall back on error with Cssabovebelow.
									$filecontent                       = $filecontentsave;
									$this->generate_css_below_the_fold = false;
									$this->make_folding_css_report     = false;
									$groupedcss[ $i ]['md5css']        = str_replace( $foldingmd5filename, '', $groupedcss[ $i ]['md5css'] );
									$cfg_str_cssnew                    = str_replace( 's', 'a', $cfg_str_css );
									$groupedcss[ $i ]['md5css']        = str_replace( '-' . $cfg_str_css, '-' . $cfg_str_cssnew, $groupedcss[ $i ]['md5css'] );
									$cfg_str_cssold                    = $cfg_str_css;
									$cfg_str_css                       = $cfg_str_cssnew;
									$api_reset                         = true;
								} else {
									$filecontent             = $filecontents[0];
									$filecontentbelowthefold = $filecontents[1];
									if ( true === $addcharsetutf ) {
										$filecontent             = str_replace( '@charset "UTF-8";', '', $filecontent );
										$filecontent             = '@charset "UTF-8";' . "\n" . $filecontent;
										$filecontentbelowthefold = str_replace( '@charset "UTF-8";', '', $filecontentbelowthefold );
										$filecontentbelowthefold = '@charset "UTF-8";' . "\n" . $filecontentbelowthefold;
									}

									$filecontent             = str_replace( '@media @', '@', $filecontent );
									$filecontentbelowthefold = str_replace( '@media @', '@', $filecontentbelowthefold );
									$file_content_opos_above = $filecontents[2];
									$file_content_opos_below = $filecontents[3];
									if ( false === $this->do_crunch_css ) {
										$filecontent             = $this->un_crunch_css( $filecontent );
										$filecontentbelowthefold = $this->un_crunch_css( $filecontentbelowthefold );
									}
								}
							} elseif ( true === $api_reset ) {
									$groupedcss[ $i ]['md5css'] = str_replace( $foldingmd5filename, '', $groupedcss[ $i ]['md5css'] );
									$groupedcss[ $i ]['md5css'] = str_replace( '-' . $cfg_str_cssold, '-' . $cfg_str_cssnew, $groupedcss[ $i ]['md5css'] );
							}

							if ( true === $this->do_crunch_css ) {
								if ( '' !== $filecontent ) {
									$filecontent = $this->crunchcss( $filecontent );
								}

								if ( true === $this->generate_css_below_the_fold ) {
									if ( '' !== $filecontentbelowthefold ) {
										$filecontentbelowthefold = $this->crunchcss( $filecontentbelowthefold );
									}
								}
							}

							$erradd    .= '$filecontent : ' . $filecontent . '<br><br>';
							$contentmd5 = 'c' . md5( $filecontent ) . '-' . md5( strrev( $filecontent ) );
							file_put_contents( str_replace( '.css', '.css', $checkfolderpath . DIRECTORY_SEPARATOR . $groupedcss[ $i ]['md5css'] ), $contentmd5 ); // phpcs:ignore WordPress.WP.AlternativeFunctions.file_system_operations_file_put_contents
							file_put_contents( $checkfolderpath . DIRECTORY_SEPARATOR . $contentmd5 . '.css', $filecontent ); // phpcs:ignore WordPress.WP.AlternativeFunctions.file_system_operations_file_put_contents
							if ( true === $this->generate_css_below_the_fold ) {
								$contentmd5 = 'c' . md5( $filecontentbelowthefold ) . '-' . md5( strrev( $filecontentbelowthefold ) );
								file_put_contents( $checkfolderpath . DIRECTORY_SEPARATOR . str_replace( '.css', 'below.css', $groupedcss[ $i ]['md5css'] ), $contentmd5 ); // phpcs:ignore WordPress.WP.AlternativeFunctions.file_system_operations_file_put_contents
								file_put_contents( $checkfolderpath . DIRECTORY_SEPARATOR . $contentmd5 . '.css', $filecontentbelowthefold ); // phpcs:ignore WordPress.WP.AlternativeFunctions.file_system_operations_file_put_contents
								$this->lenoutputcssbelow = $this->lenoutputcssbelow + strlen( $filecontentbelowthefold );
								$this->lenoutputcssabove = $this->lenoutputcssabove + strlen( $filecontent );
								++$cntoutputcssbelow;
								$lenoutputcss = $lenoutputcss + strlen( $filecontentbelowthefold );
							}

							++$cntoutputcss;
							$lenoutputcss = $lenoutputcss + strlen( $filecontent );
						}

						if ( true === $this->generate_css_below_the_fold ) {
							$tdifftolastrunmerge = 1000 * ( microtime( true ) - $starttimedebugmerge );
							$debugmergetime      = $debugmergetime + $tdifftolastrunmerge;
						}

						$ifstate = '';
						if ( isset( $groupedcss[ $i ]['ifstate'] ) ) {
							$ifstate = $groupedcss[ $i ]['ifstate'];
						}

						$endifstate = '';
						if ( isset( $groupedcss[ $i ]['endifstate'] ) ) {
							$endifstate = $groupedcss[ $i ]['endifstate'];
						}

						if ( true === $this->generate_css_below_the_fold ) {
							$file_css_contents = '';
							$modfilenamelink   = '';
							$filenamelink      = '/' . $this->cssjsfolder . '/css/' . $groupedcss[ $i ]['md5css'];
							$path              = realpath(
								str_replace(
									$this->extensionrelwinpath . '\Classes\Controller',
									'',
									str_replace( $this->extensionrelpath . '/Classes/Controller', '', __DIR__ )
								)
							) . $filenamelink;
							if ( file_exists( $path ) ) {
								$file_css_contents = trim( file_get_contents( $path ) ); //phpcs:ignore WordPress.WP.AlternativeFunctions.file_get_contents_file_get_contents
								if ( '' !== $file_css_contents ) {
									if ( true === $this->use_querystring ) {
										$modfilenamelink = $this->create_version_numbered_filename( $filenamelink );
									} else {
										$modfilenamelink = $filenamelink;
									}
								}
							}
						} else {
							$modfilenamelink = '/' . $this->cssjsfolder . '/css/' . str_replace( $foldingmd5filename, '', $groupedcss[ $i ]['md5css'] );
						}

						$arf_phpcs_go     = '<link,rel="stylesheet",type="text/css",href="';
						$arf_phpcs_go_arr = explode( ',', $arf_phpcs_go );
						$arf_phpcs        = implode( ' ', $arf_phpcs_go_arr );
						if ( '' !== $modfilenamelink ) {
							if ( false === $this->use_querystring ) {
								$modfilenamelinkarr = explode( '?', $modfilenamelink );
								if ( 2 === count( $modfilenamelinkarr ) ) {
									$modfilenamelink = $modfilenamelinkarr[0];
								}
							}

							$groupedcss[ $i ]['cssoutput'] = $ifstate . $arf_phpcs . $modfilenamelink . '" />' . $endifstate . "\n";
						} else {
							$groupedcss[ $i ]['cssoutput'] = '';
						}

						if ( true === $this->generate_css_below_the_fold ) {
							$filenamelink = '/' . $this->cssjsfolder . '/css/' . str_replace( '.css', 'below.css', $groupedcss[ $i ]['md5css'] );
							if ( true === $this->use_querystring ) {
								$modfilenamelink = $this->create_version_numbered_filename( $filenamelink );
							} else {
								$modfilenamelink = $filenamelink;
							}

							$groupedcss[ $i ]['cssoutputbelow'] = $ifstate . $arf_phpcs . $modfilenamelink . '" />' . $endifstate . "\n";
						} else {
							$groupedcss[ $i ]['cssoutputbelow'] = '';
						}
					}
				}

				$groupedcsscount = count( $groupedcss );
				$cssoutput       = '';
				$cssoutputbelow  = '';
				for ( $i = 0; $i < $groupedcsscount; $i++ ) {
					if ( isset( $groupedcss[ $i ] ) ) {
						if ( isset( $groupedcss[ $i ]['cssoutput'] ) ) {
							if ( '' !== $groupedcss[ $i ]['cssoutput'] ) {
								$cssoutput .= $groupedcss[ $i ]['cssoutput'];
							}
						}

						if ( isset( $groupedcss[ $i ]['cssoutputbelow'] ) ) {
							if ( '' !== $groupedcss[ $i ]['cssoutputbelow'] ) {
								$cssoutputbelow .= $groupedcss[ $i ]['cssoutputbelow'];
							}
						}
					}
				}

				$tdifftolastrun = 1000 * ( microtime( true ) - $starttimedebugcss ) - $debugmergetime;
				$starttimedebug = microtime( true );
				if ( true === $this->show_debug_window ) {
					$debuginfo .= '<span>Check output, ' . $groupedcsscount . ' CSS files: ' . round( $tdifftolastrun, 1 ) . ' ms</span><br />';
				}
			}
		}

		if ( isset( $bufferout ) ) {
			$bufferout        = str_replace( '</body>', "\n" . $scriptoutput . "\n" . '</body>', $bufferout );
			$cssfilespath     = realpath(
				str_replace(
					$this->extensionrelwinpath . '\Classes\Controller',
					'',
					str_replace( $this->extensionrelpath . '/Classes/Controller', '', __DIR__ )
				)
			) . '/' . $this->cssjsfolder . '/css';
			$arf_phpcs_go     = '<link,rel="stylesheet",type="text/css",href="/';
			$arf_phpcs_go_arr = explode( ',', $arf_phpcs_go );
			$arf_phpcs        = implode( ' ', $arf_phpcs_go_arr );
			$cssoutputwrkarr  = explode( $arf_phpcs . $this->cssjsfolder . '/css/', $cssoutput );
			$cssi             = 1;
			foreach ( $cssoutputwrkarr as &$cssoutputwrkpart ) {
				$cssoutputwrkpartarr = explode( '.css"', $cssoutputwrkpart );
				if ( '' !== trim( $cssoutputwrkpartarr[0] ) ) {
					$cssoutputwrkfilename = $cssoutputwrkpartarr[0] . '.css';
					$modmd5filenamelink   = '';
					if ( file_exists( $cssfilespath . '/' . $cssoutputwrkfilename ) ) {
						$modmd5filenamelink = file_get_contents( $cssfilespath . '/' . $cssoutputwrkfilename ); //phpcs:ignore WordPress.WP.AlternativeFunctions.file_get_contents_file_get_contents
						if ( true === $this->inline_ccss ) {
							$modmd5filenamelink_contents = file_get_contents( $cssfilespath . '/' . $modmd5filenamelink . '.css' ); //phpcs:ignore WordPress.WP.AlternativeFunctions.file_get_contents_file_get_contents
							$cssoutput_inline            = '<style id="indexreloaded_ccss-' . $cssi . '">' . $modmd5filenamelink_contents . '</style>';
							$cssoutputwrkpartarr[0]      = $cssoutput_inline;
							$cssoutputwrkpart            = implode( '.css"', $cssoutputwrkpartarr );
							$cssoutputwrkpart            = str_replace( '</style>.css" />', '</style>', $cssoutputwrkpart );
						} else {
							$cssoutputwrkpartarr[0] = $modmd5filenamelink;
							$cssoutputwrkpart       = implode( '.css"', $cssoutputwrkpartarr );
						}
					} else {
						irld_trace_log( 'file not found: ' . $cssfilespath . '/' . $cssoutputwrkfilename, 0 );
					}
				}

				if ( '' !== trim( $cssoutputwrkpart ) ) {
					++$cssi;
				}
			}

			if ( true === $this->inline_ccss ) {
				$cssoutput = implode( '', $cssoutputwrkarr );
			} else {
				$cssoutput = implode( $arf_phpcs . $this->cssjsfolder . '/css/', $cssoutputwrkarr );
			}

			$cssoutputwrkarr = explode( $arf_phpcs . $this->cssjsfolder . '/css/', $cssoutputbelow );
			foreach ( $cssoutputwrkarr as &$cssoutputwrkpart ) {
				$cssoutputwrkpartarr = explode( '.css"', $cssoutputwrkpart );
				if ( '' !== trim( $cssoutputwrkpartarr[0] ) ) {
					$cssoutputwrkfilename = $cssoutputwrkpartarr[0] . '.css';
					$modmd5filenamelink   = '';
					if ( file_exists( $cssfilespath . '/' . $cssoutputwrkfilename ) ) {
						$modmd5filenamelink     = file_get_contents( $cssfilespath . '/' . $cssoutputwrkfilename ); //phpcs:ignore WordPress.WP.AlternativeFunctions.file_get_contents_file_get_contents
						$cssoutputwrkpartarr[0] = $modmd5filenamelink;
						$cssoutputwrkpart       = implode( '.css"', $cssoutputwrkpartarr );
					} else {
						irld_trace_log( 'file not found: ' . $cssfilespath . '/' . $cssoutputwrkfilename, 0 );
					}
				}
			}

			$cssoutputbelow   = implode( $arf_phpcs . $this->cssjsfolder . '/css/', $cssoutputwrkarr );
			$arf_phpcs_go     = '<script,type="text/javascript",id="indexreloaded-inline-js-load-uccss">';
			$arf_phpcs_go_arr = explode( ',', $arf_phpcs_go );
			$jsoutputbelow    = implode( ' ', $arf_phpcs_go_arr );
			if ( '' !== trim( $cssoutputbelow ) ) {
				$cssoutputbelowarr = explode( "\n", $cssoutputbelow );
				$on_if             = 0;
				$i_js              = 0;
				$jsoutputbelow    .= "\n" .
					'var lStSh = [];';
				$arf_phpcs_go      = '<link,rel="stylesheet",type="text/css",href="';
				$arf_phpcs_go_arr  = explode( ',', $arf_phpcs_go );
				$arf_phpcs         = implode( ' ', $arf_phpcs_go_arr );

				foreach ( $cssoutputbelowarr as $cssoutputblw ) {
					if ( '' !== trim( $cssoutputblw ) ) {
						$cssoutputblwsrc = str_replace( $arf_phpcs, '', $cssoutputblw );
						$cssoutputblwsrc = str_replace( '" />', '', $cssoutputblwsrc );
						if ( ( '<!--[if IE]>' === $cssoutputblwsrc ) || ( '<!--[if IE 7]>' === $cssoutputblwsrc ) || ( '<!--[if IE 9]>' === $cssoutputblwsrc ) || ( '<!--[if IE 8]>' === $cssoutputblwsrc ) ) {
							$jsoutputbelow .= "\tif (navigator.appName === 'Microsoft Internet Explorer' ) {\n";
							$on_if          = 1;
						} elseif ( substr( $cssoutputblwsrc, 0, 4 ) === '<!--' ) {
							$on_if = 0;
						} elseif ( str_replace( '<![endif]-->', '', $cssoutputblwsrc ) !== $cssoutputblwsrc ) {
								$cssoutputblwsrc = str_replace( '<![endif]-->', '', $cssoutputblwsrc );
							if ( 1 === $on_if ) {
								$jsoutputbelow .= "\t\tlStSh[" . $i_js . '] = \'' . $cssoutputblwsrc . "';\n";
								$jsoutputbelow .= "\t}\n";
								$on_if          = 0;
							}
						} else {
							if ( 1 === $on_if ) {
								$jsoutputbelow .= "\t";
							}

								$jsoutputbelow .= "\t" . 'lStSh[' . $i_js . '] = \'' . $cssoutputblwsrc . '\';' . "\n";
						}

						++$i_js;
					}
				}

				if ( false === $this->lvc ) {
					$pathtojsbelow = '/wp-content/plugins/indexreloaded/assets/js/ttri-lstsh.min.js';
				} else {
					$pathtojsbelow = '/wp-content/plugins/indexreloaded/assets/js/ttri-jq-lstsh.min.js';
				}
			}

			$inlinejs     = 'var slowmotion = ' . $this->load_cssbelow_in_slowmotion . ';';
			$siteurl      = site_url( '/', 'https' );
			$pathtojshtml = '';
			$curip        = '';
			if ( isset( $_SERVER['SERVER_ADDR'] ) ) {
				$curip = sanitize_text_field( wp_unslash( $_SERVER['SERVER_ADDR'] ) );
			}

			$langreq    = 'en';
			$actionwp   = 'checkixrdkey';
			$getp       = '&action=' . $actionwp . '&remoteadr=' . $curip . '&remotesite=' . $siteurl . '&lang=' . $langreq . '&secret=' . $this->secret;
			$urlfetch   = 'https://www.toctoc.ch/';
			$urltofetch = $urlfetch . 'wp-admin/admin-ajax.php';
			$gtstrng    = add_query_arg( '_wpspecnonce', irld_get_special_nonce( 'checkixrdkey' ), $urltofetch ) . $getp;
			$gtstrng    = str_replace( 'https://www.toctoc.ch/wp-admin/admin-ajax.php', '', $gtstrng );
			$actionwp   = 'irld_upd_optsnp';
			$getprem    = '&action=' . $actionwp;
			$urltofetch = $siteurl . 'wp-admin/admin-ajax.php';
			$gtstrngopt = add_query_arg( '_wpnonce', wp_create_nonce( 'irld_upd_optsnp' ), $urltofetch ) . $getprem;
			$gtstrngopt = str_replace( $siteurl . 'wp-admin/admin-ajax.php', '', $gtstrngopt );
			$actionwp   = 'irld_upd_lvcnp';
			$getprem    = '&action=' . $actionwp;
			$urltofetch = $siteurl . 'wp-admin/admin-ajax.php';
			$gtstrnglvc = add_query_arg( '_wpnonce', wp_create_nonce( 'irld_upd_lvcnp' ), $urltofetch ) . $getprem;
			$gtstrnglvc = str_replace( $siteurl . 'wp-admin/admin-ajax.php', '', $gtstrnglvc );
			$inlinejs  .= 'var gtstrng = "' . $gtstrng . '";var rmsite = "' . $urlfetch . '";var gtstrnglvc = "' . $gtstrnglvc . '";var locsite = "' .
							$siteurl . '";var gtstrngopt = "' . $gtstrngopt . '";var user_role_md5 = "' . $this->user_role_md5 . '";';

			if ( 1 === $this->ccss_refracted ) {
				$actionwp         = 'irld_upd_ccss';
				$pagename         = $this->current_page_name();
				$getprem          = '&action=' . $actionwp . '&page=' . rawurlencode( $pagename );
				$urltofetch       = $siteurl . 'wp-admin/admin-ajax.php';
				$gtstrnghtml      = add_query_arg( '_wpnonce', wp_create_nonce( 'irld_upd_ccss' ), $urltofetch ) . $getprem;
				$gtstrnghtml      = str_replace( $siteurl . 'wp-admin/admin-ajax.php', '', $gtstrnghtml );
				$arf_phpcs_go     = 'cript,id="indexreloaded-js-jq-ccss",src="';
				$arf_phpcs_go_arr = explode( ',', $arf_phpcs_go );
				$arf_phpcs        = '<s' . implode( ' ', $arf_phpcs_go_arr );

				$pathtojshtml = $arf_phpcs . '/wp-content/plugins/indexreloaded/assets/js/ttri-ccss.min.js" defer></script>';
				$inlinejs    .= 'var gtstrnghtml = "' . $gtstrnghtml . '";';
				if ( true === $this->errlog_caching ) {
					irld_trace_log( 'asking for ajax-delivery of html for page ' . rawurlencode( $pagename ), 0 );
				}
			}

			$jsoutputbelow .= $inlinejs . '</script>';
			if ( '' !== trim( $cssoutputbelow ) ) {
				$arf_phpcs_go     = 'cript,id="indexreloaded-js-load-uccss",src="';
				$arf_phpcs_go_arr = explode( ',', $arf_phpcs_go );
				$arf_phpcs        = '<s' . implode( ' ', $arf_phpcs_go_arr );
				$jsoutputbelow   .= $arf_phpcs . $pathtojsbelow . '" defer></script>';
			}

			$jsoutputbelow .= $pathtojshtml;
			$bufferout      = str_replace( '</body>', "\n" . $jsoutputbelow . "\n" . '</body>', $bufferout );
			$bufferout      = str_replace( '</head>', "\n" . $cssoutput . "\n" . '</head>', $bufferout );
			$lenbufferout   = strlen( $bufferout );
			$tdifftolastrun = 1000 * ( microtime( true ) - $starttimedebugcallback );
			if ( $tdifftolastrun > $this->max_execution_time ) {
				$serveruri = '';
				if ( isset( $_SERVER['REQUEST_URI'] ) ) {
					$serveruri = sanitize_text_field( wp_unslash( $_SERVER['REQUEST_URI'] ) );
				}

				irld_trace_log( 'Postprocess time higher than ' . $this->max_execution_time . ' ms! Got ' . round( $tdifftolastrun, 1 ) . ' ms for ' . $serveruri, 0 );
			}

			if ( true === $this->show_debug_window ) {
				$tdifftolastrun = 1000 * ( microtime( true ) - $starttimedebugcallback );
				if ( true === $this->generate_css_below_the_fold ) {
					$debuginfo .= '<span>CSS above/below the fold: ' . round( $debugmergetime, 1 ) . ' ms</span>';
				}

				$debuginfo .= '<br /><strong>Total time: ' . round( $tdifftolastrun, 1 ) . ' ms</strong>';
				$debuginfo .= '</div>';
				$debuginfo .= '<div class="ttirl_subtitle"><strong>Input</strong><span class="ttirlsmall">, files found for processing</span></div><div>';
				if ( $cntininecss > 0 ) {
					$debuginfo .= '<span>Inline CSS: ' . $cntininecss . '</span><br />';
				}

				if ( $cntininejs > 0 ) {
					$debuginfo .= '<span>Inline JS: ' . $cntininejs . ' </span><br />';
				}

				if ( $cntcss > 0 ) {
					$debuginfo .= '<span>CSS files: ' . $cntcss . ' </span><br />';
				}

				if ( $cntjs > 0 ) {
					$debuginfo .= '<span>JS files: ' . $cntjs . ' </span><br />';
				}

				if ( intval( ( $len_inline_css + $lencss ) / 1024 ) > 0 ) {
					$debuginfo .= '<span>Length CSS: ' . intval( ( $len_inline_css + $lencss ) / 1024 ) . 'kb </span><br />';
				} elseif ( intval( ( $len_inline_css + $lencss ) ) > 0 ) {
					$debuginfo .= '<span>Length CSS: ' . intval( ( $len_inline_css + $lencss ) ) . 'bytes </span><br />';
				}

				if ( intval( ( $len_inline_js + $lenjs ) / 1024 ) > 0 ) {
					$debuginfo .= '<span>Length JS: ' . intval( ( $len_inline_js + $lenjs ) / 1024 ) . 'kb </span><br />';
				} elseif ( intval( ( $len_inline_js + $lenjs ) ) > 0 ) {
						$debuginfo .= '<span>Length JS: ' . intval( ( $len_inline_js + $lenjs ) ) . 'bytes </span><br />';
				}

				$debuginfo .= '</div>';
				if ( intval( $cntkeepcss + $cntkeepjs ) > 0 ) {
					$debuginfo .= '<div class="ttirl_subtitle"><strong>Unchanged</strong><span class="ttirlsmall">, excluded from processing</span></div><div>';
					if ( intval( $cntkeepcss ) > 0 ) {
						$debuginfo .= '<span>CSS files kept: ' . $cntkeepcss . ' </span>';
						if ( intval( $cntkeepcssext ) > 0 ) {
							$debuginfo .= '<span class="ttirlsmall"> (external CSS files: ' . $cntkeepcssext . ')</span>';
						}

						$debuginfo .= '<br />';
					}

					if ( intval( $cntkeepjs ) > 0 ) {
						$debuginfo .= '<span>Inline JS and JS files kept: ' . $cntkeepjs . ' </span>';
						if ( intval( $cntkeepjsext ) > 0 ) {
							$debuginfo .= '<span class="ttirlsmall"> (external JS files: ' . $cntkeepjsext . ')</span>';
						}

						$debuginfo .= '<br />';
					}

					$debuginfo .= '</div>';
				}

				if ( intval( $cntoutputcss + $cntoutputjs ) > 0 ) {
					$debuginfo .= '<div class="ttirl_subtitle"><strong>Output</strong></div><div>';
					if ( intval( $cntoutputcss ) > 0 ) {
						$debuginfo .= '<span>CSS files: ' . $cntoutputcss . ' </span><br />';
						if ( ( $cntoutputcss > 0 ) && ( $cntcss > 0 ) ) {
							$debuginfo .= '<span class="ttirlsmall">Change CSS requests: <b>' . round( 100 * ( ( $cntoutputcss ) / ( $cntcss ) - 1 ), 1 ) . '%</b></span><br />';
						}
					}

					if ( intval( $cntoutputjs ) > 0 ) {
						$debuginfo .= '<span>JS files: ' . $cntoutputjs . ' </span><br />';
						if ( ( $cntoutputjs > 0 ) && ( $cntjs > 0 ) ) {
							$debuginfo .= '<span class="ttirlsmall">Change JS requests: <b>' . round( 100 * ( ( $cntoutputjs ) / ( $cntjs ) - 1 ), 1 ) . '%</b></span><br />';
						}
					}

					$debuginfo .= '</div>';
				}

				if ( ( intval( $lenoutputcss / 1024 ) + intval( $lenoutputjs / 1024 ) ) > 0 ) {
					$debuginfo .= '<div class="ttirl_subtitle"><strong>Output - file size</strong></div><div>';
					if ( intval( $lenoutputcss / 1024 ) > 0 ) {
						$debuginfo .= '<span>Length CSS: ' . intval( $lenoutputcss / 1024 ) . 'kb </span><br />';
						if ( ( intval( $lenoutputcss / 1024 ) > 0 ) && ( intval( ( $len_inline_css + $lencss ) / 1024 ) > 0 ) ) {
							$debuginfo .= '<span class="ttirlsmall">Change in size: <b>' . round(
								100 * ( ( intval( $lenoutputcss / 1024 ) ) /
								( ( intval( ( $len_inline_css + $lencss ) / 1024 ) ) ) - 1 ),
								1
							) . '%</b></span><br />';
						}

						if ( intval( $this->lenoutputcssabove / 1024 ) > 0 ) {
							$debuginfo .= '<span>Length CSS above the fold: ' . intval( $this->lenoutputcssabove / 1024 ) . 'kb </span><br />';
						} elseif ( intval( $this->lenoutputcssabove ) > 0 ) {
							$debuginfo .= '<span>Length CSS above the fold: ' . intval( $this->lenoutputcssabove ) . 'bytes </span><br />';
						}

						if ( intval( $this->lenoutputcssbelow / 1024 ) > 0 ) {
							$debuginfo .= '<span>Length CSS below the fold: ' . intval( $this->lenoutputcssbelow / 1024 ) . 'kb </span><br />';
						} elseif ( intval( $this->lenoutputcssbelow ) > 0 ) {
							$debuginfo .= '<span>Length CSS below the fold: ' . intval( $this->lenoutputcssbelow ) . 'bytes </span><br />';
						}
					}

					if ( intval( $lenoutputjs / 1024 ) > 0 ) {
						$debuginfo .= '<span>Length JS: ' . intval( $lenoutputjs / 1024 ) . 'kb </span><br />';
						if ( ( intval( $lenoutputjs / 1024 ) > 0 ) && ( intval( ( $len_inline_js + $lenjs ) / 1024 ) > 0 ) ) {
							$debuginfo .= '<span class="ttirlsmall">Change in size: <b>' . round(
								100 * ( ( intval( $lenoutputjs / 1024 ) ) /
								( ( intval( ( $len_inline_js + $lenjs ) / 1024 ) ) ) - 1 ),
								1
							) . '%</b></span><br />';
						}
					}

					$debuginfo .= '</div>';
				}

				if ( ( intval( $lenbuffer / 1024 ) > 0 ) && ( intval( $lenbufferout / 1024 ) > 0 ) ) {
					$debuginfo .= '<div class="ttirl_subtitle"><strong>Output - overall</strong></div><div>';
					$debuginfo .= '<span>Length HTML went from ' . intval( $lenbuffer / 1024 ) . 'kb to ' .
									intval( $lenbufferout / 1024 ) . 'kb</span><br />';
					$debuginfo .= '<span class="ttirlsmall">Change in size: <b>' . round(
						100 * ( ( intval( $lenbufferout / 1024 ) ) /
						( ( intval( ( $lenbuffer ) / 1024 ) ) ) - 1 ),
						1
					) . '%</b></span><br />';
					$debuginfo .= '</div>';

				}

				if ( ( true === $this->make_folding_css_report ) && ( count( $this->folding_css_report ) > 0 ) ) {
					$cntcssfilesforreport            = count( $this->folding_css_report );
					$startctrl                       = 0;
					$initselabove                    = 0;
					$newselabove                     = 0;
					$newselbelow                     = 0;
					$initrulesabove                  = 0;
					$newrulesabove                   = 0;
					$newrulesbelow                   = 0;
					$initmediaabove                  = 0;
					$newmediaabove                   = 0;
					$newmediabelow                   = 0;
					$initsizeofabove                 = 0;
					$newsizeofabove                  = 0;
					$newsizeofbelow                  = 0;
					$newfilesabove                   = 0;
					$newfilesbelow                   = 0;
					$totalselectorsold               = 0;
					$totalselectorsnew               = 0;
					$totalselectorsend               = 0;
					$total_merge_css_old_above_start = 0;
					$total_merge_css_old_below_start = 0;
					$total_merge_css_new_above_start = 0;
					$total_merge_css_new_below_start = 0;
					$total_merge_css_below_end       = 0;
					$total_merge_css_above_end       = 0;
					for ( $r = 0; $r < $cntcssfilesforreport; $r++ ) {
						if ( isset( $this->folding_css_report[ $r ]['mergeCSSNewAboveStart']['selectors'] ) ) {
							$newselabove                     = $newselabove + $this->folding_css_report[ $r ]['mergeCSSAboveEnd']['selectors'] - $this->folding_css_report[ $r ]['mergeCSSOldAboveStart']['selectors'];
							$newselbelow                     = $newselbelow + $this->folding_css_report[ $r ]['mergeCSSBelowEnd']['selectors'] - $this->folding_css_report[ $r ]['mergeCSSOldBelowStart']['selectors'];
							$totalselectorsold               = $totalselectorsold + $this->folding_css_report[ $r ]['mergeCSSOldBelowStart']['selectors'] +
													$this->folding_css_report[ $r ]['mergeCSSOldAboveStart']['selectors'];
							$totalselectorsnew               = $totalselectorsnew + $this->folding_css_report[ $r ]['mergeCSSNewBelowStart']['selectors'] +
													$this->folding_css_report[ $r ]['mergeCSSNewAboveStart']['selectors'];
							$totalselectorsend               = $totalselectorsend + $this->folding_css_report[ $r ]['mergeCSSBelowEnd']['selectors'] + $this->folding_css_report[ $r ]['mergeCSSAboveEnd']['selectors'];
							$total_merge_css_old_above_start = $total_merge_css_old_above_start + $this->folding_css_report[ $r ]['mergeCSSOldAboveStart']['selectors'];
							$total_merge_css_old_below_start = $total_merge_css_old_below_start + $this->folding_css_report[ $r ]['mergeCSSOldBelowStart']['selectors'];
							$total_merge_css_new_above_start = $total_merge_css_new_above_start + $this->folding_css_report[ $r ]['mergeCSSNewAboveStart']['selectors'];
							$total_merge_css_new_below_start = $total_merge_css_new_below_start + $this->folding_css_report[ $r ]['mergeCSSNewBelowStart']['selectors'];
							$total_merge_css_below_end       = $total_merge_css_below_end + $this->folding_css_report[ $r ]['mergeCSSBelowEnd']['selectors'];
							$total_merge_css_above_end       = $total_merge_css_above_end + $this->folding_css_report[ $r ]['mergeCSSAboveEnd']['selectors'];
						} else {
							if ( isset( $this->folding_css_report[ $r ]['splitCSSAllStart']['selectors'] ) ) {
								$initselabove    = $initselabove + $this->folding_css_report[ $r ]['splitCSSAllStart']['selectors'];
								$initrulesabove  = $initrulesabove + $this->folding_css_report[ $r ]['splitCSSAllStart']['rules'];
								$initmediaabove  = $initmediaabove + $this->folding_css_report[ $r ]['splitCSSAllStart']['atmedia'];
								$initsizeofabove = $initsizeofabove + $this->folding_css_report[ $r ]['splitCSSAllStart']['sizeoffile'];
							}

							if ( isset( $this->folding_css_report[ $r ]['splitCSSAllEndAbove']['selectors'] ) ) {
								$newselabove    = $newselabove + $this->folding_css_report[ $r ]['splitCSSAllEndAbove']['selectors'];
								$newrulesabove  = $newrulesabove + $this->folding_css_report[ $r ]['splitCSSAllEndAbove']['rules'];
								$newmediaabove  = $newmediaabove + $this->folding_css_report[ $r ]['splitCSSAllEndAbove']['atmedia'];
								$newsizeofabove = $newsizeofabove + $this->folding_css_report[ $r ]['splitCSSAllEndAbove']['sizeoffile'];
								++$newfilesabove;
							}

							if ( isset( $this->folding_css_report[ $r ]['splitCSSAllEndBelow']['selectors'] ) ) {
								$newselbelow    = $newselbelow + $this->folding_css_report[ $r ]['splitCSSAllEndBelow']['selectors'];
								$newrulesbelow  = $newrulesbelow + $this->folding_css_report[ $r ]['splitCSSAllEndBelow']['rules'];
								$newmediabelow  = $newmediabelow + $this->folding_css_report[ $r ]['splitCSSAllEndBelow']['atmedia'];
								$newsizeofbelow = $newsizeofbelow + $this->folding_css_report[ $r ]['splitCSSAllEndBelow']['sizeoffile'];
								++$newfilesbelow;
							}
						}
					}

					if ( count( $this->folding_css_report ) > 0 ) {
						$debuginfo .= '<div class="ttirl_subtitle"><strong>CSS folding</strong></div><div>';
						$debuginfo .= '<span>Number of CSS files<br /><span class="ttirlsmall">Before folding: ' . $cntcssfilesforreport . ' (' . round( $initsizeofabove / 1024, 0 ) . 'kB)<br />
After folding: ' . $newfilesabove . ' above the fold (' . round( $newsizeofabove / 1024, 0 ) . 'kB), ' . $newfilesbelow . ' below (' .
						round( $newsizeofbelow / 1024, 0 ) . 'kB)</span><br />
Above the fold CSS-size reduced by <b>' . round( 100 - ( $newsizeofabove / $initsizeofabove ) * 100, 0 ) . '%</b><br /><br />
Loadcharge for DOM:<br />
<span class="ttirlsmall">Initial above the fold:<br />
' . $initselabove . ' selectors with ' . $initrulesabove . ' rules and ' . $initmediaabove . ' @media parts<br />
Above after folding:<br />
' . $newselabove . ' selectors with ' . $newrulesabove . ' rules and ' . $newmediaabove . ' @media parts<br />
Below after folding:<br />
' . $newselbelow . ' selectors with ' . $newrulesbelow . ' rules and ' . $newmediabelow . ' @media parts</span><br />
DOM relief on page load: <b>-' . round( 100 - ( $newselabove / $initselabove ) * 100, 1 ) . '%</b> for selectors, <b>-' .
						round( 100 - ( $newrulesabove / $initrulesabove ) * 100, 0 ) . '%</b> for rules and <b>-' .
						round( 100 - ( $newmediaabove / $initmediaabove ) * 100, 0 ) . '%</b> for @media-parts.';
						$debuginfo .= '</span></div>';
					}
				}

				$debuginfo .= $debugopt;
			}

			if ( true === $this->show_debug_window ) {
				$debuginfo .= '</div>';
				$debuginfo .= '<style>
		#tt_ri_dbg {
			position: absolute;
			color: #000;
			left: 2px;
			top: 2px;
			z-index: 5000;
			padding: 4px;
			max-width: 25%;
			background-color: white;
			min-width: 205px;
			border: 1px solid #AAAAAA;
			opacity: 0.97;
			text-align: left;
			font-size: 14px;
			line-height: normal;
		}
		#tt_ri_dbg span, #tt_ri_dbg p, #tt_ri_dbg strong, #tt_ri_dbg small {
			color: #000;
		}
		#tt_ri_dbg span.tt_ri_dbg_close {
			font-weight: 700;
			background-color: #EFEFEF;
			border-radius: 4px;
			float: right;
			cursor: pointer;
			border: 1px solid #AAA;
			padding: 0 5px;
		}
		.ttirl_title {
			background-color: #e5bf90;
			border: 1px solid #60381c;
			padding: 0 5px;
		}
		.ttirl_subtitle {
			background-color: #edddbf;
			border: 1px solid #60381c;
			padding: 0 5px;
		}
		.ttirl_subtitleinfo {
			background-color: #c1dbed;
			border: 1px solid #073e61;
			padding: 0 5px;
		}
		 .ttirlsmall {
			font-size: 88%;
		}

	</style>';
				if ( ( str_replace( $this->show_debug_window_body_tag, '', $bufferout ) !== $bufferout ) && ( '' !== trim( $this->show_debug_window_body_tag ) ) ) {
					// the debugWindowBodyTag actually exists.
					$bufferout = str_replace( $this->show_debug_window_body_tag, $this->show_debug_window_body_tag . $debuginfo, $bufferout );
				} else {
					// we need identify the entire body tag.
					$bufferout_bodytag_arr = explode( '<body', $bufferout );
					if ( isset( $bufferout_bodytag_arr[1] ) ) {
						$bodytag_to_end                   = $bufferout_bodytag_arr[1];
						$bodytag_to_end_arr               = explode( '>', $bodytag_to_end );
						$this->show_debug_window_body_tag = '<body' . $bodytag_to_end_arr[0] . '>';
						if ( ( str_replace( $this->show_debug_window_body_tag, '', $bufferout ) !== $bufferout ) && ( '' !== trim( $this->show_debug_window_body_tag ) ) ) {
							// the new found debugWindowBodyTag actually exists.
							$bufferout = str_replace( $this->show_debug_window_body_tag, $this->show_debug_window_body_tag . $debuginfo, $bufferout );
						}
					}
				}
			}

			$hassomework = true;
			do {
				$bufferout = str_replace( "\r\n\r\n", "\r\n", $bufferout );
				$bufferout = str_replace( "\n\n", "\n", $bufferout );
				$bufferout = str_replace( "\t\n", "\n", $bufferout );
				$bufferout = str_replace( " \n", "\n", $bufferout );
				$bufferout = str_replace( "\t\r\n", "\r\n", $bufferout );
				$bufferout = str_replace( " \r\n", "\r\n", $bufferout );
				if ( ( str_replace( "\t\r\n", '', $bufferout ) === $bufferout ) && ( str_replace( " \r\n", '', $bufferout ) === $bufferout ) &&
						( str_replace( " \n", '', $bufferout ) === $bufferout ) && ( str_replace( "\n\n", '', $bufferout ) === $bufferout ) &&
						( str_replace( "\t\n", '', $bufferout ) === $bufferout ) && ( str_replace( "\r\n\r\n", '', $bufferout ) === $bufferout ) ) {
					$hassomework = false;
				}
			} while ( true === $hassomework );

		}

		if ( 1 === $this->dontmod ) {
			return( $bufferin );
		} elseif ( isset( $bufferout ) ) {
			if ( true === $this->try_fix_bad_css ) {
				// more cleanings.
				require_once 'addons/final-changes-html.php';
			}

			if ( true === $this->fix_html_defaults ) {
				$bufferout = str_replace( ' type="text/javascript"', '', $bufferout );
				$bufferout = str_replace( " type='text/javascript'", '', $bufferout );
				$bufferout = str_replace( 'style type="text/css"', 'style', $bufferout );
			}

			if ( true === $this->try_fix_bad_css ) {
				$bufferout = str_replace( 'class="site-header" role="banner"', 'class="site-header"', $bufferout );
				$bufferout = str_replace( 'class="main-navigation" role="navigation"', 'class="main-navigation"', $bufferout );
				$bufferout = str_replace( 'class="site-main" role="main"', 'class="site-main"', $bufferout );
				$bufferout = str_replace( 'class="site-footer" role="contentinfo"', 'class="site-footer"', $bufferout );
			}

			if ( false === $this->dontmodjs ) {
				if ( true === $this->defer_all_js ) {
					$bufferoutarr      = explode( '<script', $bufferout );
					$countbufferoutarr = count( $bufferoutarr );
					$bout              = $bufferoutarr[0] . '<script';
					for ( $bo = 1; $bo < $countbufferoutarr; $bo++ ) {
						$boscripttagarr = explode( '>', $bufferoutarr[ $bo ] );
						$boscripttag    = $boscripttagarr[0];
						if ( str_replace( 'src=', '', $boscripttag ) !== $boscripttag ) {
							if ( str_replace( 'type=', '', $boscripttag ) === $boscripttag ) {
								if ( str_replace( ' defer', '', $boscripttag ) === $boscripttag ) {
									if ( true === $this->dont_defer_jquery ) {
										if ( ( str_replace( '/jquery.js', '', $boscripttag ) === $boscripttag ) &&
											( str_replace( '/jquery.min.js', '', $boscripttag ) === $boscripttag ) &&
											( str_replace( "id='jquery-core-js'", '', $boscripttag ) === $boscripttag ) &&
											( str_replace( 'id="jquery-core-js"', '', $boscripttag ) === $boscripttag ) ) {
											$boscripttag = $boscripttag . ' defer';
										}
									} else {
										$boscripttag = $boscripttag . ' defer';
									}
								}
							}
						}

						array_shift( $boscripttagarr );
						$bufferoutarr[ $bo ] = $boscripttag . '>' . implode( '>', $boscripttagarr );

					}

					$bufferout = implode( '<script', $bufferoutarr );
				}
			}

				return( $bufferout );
		} else {
			return( $bufferin );
		}
	}

	/**
	 * Checks number of selectors, rules and @medias in a file for reporting.
	 *
	 * @param string  $entryname name of the entry.
	 * @param string  $filecontents CSS filecontents.
	 * @param boolean $mediacorrectrules correct total rules or not.
	 * @return void writes $this->folding_css_report.
	 */
	private function folding_css_reportentry( $entryname, $filecontents, $mediacorrectrules = false ) {
		$this->folding_css_report[ $this->if_css_rep ][ $entryname ] = array();
		if ( str_replace( ',@,', '', $filecontents ) !== $filecontents ) {
			$filecontents          = $this->crunchcss( $filecontents );
			$filecontents          = str_replace( '}}', '}', $filecontents );
			$css_total_rules_arr_o = explode( '}', $filecontents );
			$css_total_rules_arr   = array();
			$v                     = 0;
			foreach ( $css_total_rules_arr_o as $css_rule ) {
				$rulearr                   = explode( ',@,', $css_rule );
				$rule                      = $rulearr[1];
				$css_total_rules_arr[ $v ] = $rule;
				++$v;
			}
		} else {
			$filecontents        = $this->crunchcss( $filecontents );
			$filecontents        = str_replace( '}}', '}', $filecontents );
			$css_total_rules_arr = explode( '}', $filecontents );
		}

		$sizeof                 = strlen( $filecontents );
		$totalrules             = count( $css_total_rules_arr );
		$css_total_at_media_arr = explode( '@media', $filecontents );
		$totalatmedia           = count( $css_total_at_media_arr ) - 1;
		if ( true === $mediacorrectrules ) {
			$totalrules = $totalrules - $totalatmedia;
		}

		$css_total_selectors = 0;
		$onkeyframe          = 0;
		foreach ( $css_total_rules_arr as $css_total_rule_sel ) {
			// @media @-...-keyframes split into two elements - we count 1 selector per @media @-...-keyframes instruction
			if ( str_replace( '-keyframes', '', $css_total_rule_sel ) !== $css_total_rule_sel ) {
				++$css_total_selectors;
				$onkeyframe = 1;
			} elseif ( 1 === $onkeyframe ) {
				$onkeyframe = 0;
			} else {
				$css_total_rules_arr2 = explode( '{', $css_total_rule_sel );
				if ( count( $css_total_rules_arr2 ) > 1 ) {
					$css_total_rules_arrsels = explode( ',', $css_total_rules_arr2[ count( $css_total_rules_arr2 ) - 2 ] );
					$css_total_selectors     = $css_total_selectors + count( $css_total_rules_arrsels );
				}
			}
		}

		$totalselectors = $css_total_selectors;
		$this->folding_css_report[ $this->if_css_rep ][ $entryname ]['selectors']  = $totalselectors;
		$this->folding_css_report[ $this->if_css_rep ][ $entryname ]['rules']      = $totalrules - 1;
		$this->folding_css_report[ $this->if_css_rep ][ $entryname ]['atmedia']    = $totalatmedia;
		$this->folding_css_report[ $this->if_css_rep ][ $entryname ]['sizeoffile'] = $sizeof;
	}

	/**
	 * Creates and returns a md5-string based on tags, classes, ids and input types.
	 * creates $this->bufferinclasses, $this->bufferintags.
	 *
	 * @param string $bufferin HTML data.
	 * @return string md5-string used for naming.
	 */
	public function buffer_fold_meta( $bufferin ) {
		$err_log_tagcloud    = false;
		$numericjailarray    = $this->numericjailarray;
		$numericnojailarray  = $this->numericnojailarray;
		$bufferintags        = array();
		$bufferinarrbasezero = explode( '<body', $bufferin );
		$buffer_body         = '';
		if ( count( $bufferinarrbasezero ) > 1 ) {
			$buffer_body = '<body' . $bufferinarrbasezero[1];
		} else {
			$bufferinarrbasezero = explode( '<BODY', $bufferin );
			if ( count( $bufferinarrbasezero ) > 1 ) {
				$buffer_body = '<body' . $bufferinarrbasezero[1];
			} else {
				$pagename     = $this->current_page_name();
				$serverrequri = '';
				if ( isset( $_SERVER['REQUEST_URI'] ) ) {
					$serverrequri = sanitize_text_field( wp_unslash( $_SERVER['REQUEST_URI'] ) );
				}

				irld_trace_log( 'HTML-error IndexReloaded: No <body>-Tag found, page "' . $pagename . '", request uri: "' . $serverrequri . '" bufferin: ' . $bufferin, 0 );
			}
		}

		$pagename = $this->current_page_name();
		if ( ( defined( 'WP_REDIS_CLIENT' ) ) && ( is_plugin_active( 'redis-cache/redis-cache.php' ) ) ) {
			$object_cache_group      = 'indexreloaded';
			$opt_object_cache_expire = intval( get_option( 'indexreloaded_ObjectCacheExpire' ) );
			if ( 0 === $opt_object_cache_expire ) {
				$opt_object_cache_expire = 5184000; // 60 days. 172800 is redis-default - needs to be set in config.php
			}

			$object_cache_expire = $opt_object_cache_expire; // seconds.
			$keyrequest          = 'page-' . rawurlencode( $pagename ) . '-' . $this->user_role_md5;
			$found_cache         = null;
			$resultcache         = wp_cache_get( $keyrequest, $object_cache_group, false, $found_cache );
			if ( true === $found_cache ) {
				$resultcache          = json_decode( $resultcache, JSON_OBJECT_AS_ARRAY );
				$this->ccss_refracted = $resultcache['ccss_refracted'];
				$keyrequest_two       = 'real-page-' . rawurlencode( $pagename ) . '-' . $this->user_role_md5;
				$found_cache_two      = null;
				if ( 2 !== $this->ccss_refracted ) {
					$resultcache_two = wp_cache_get( $keyrequest_two, $object_cache_group, false, $found_cache_two );
				}

				if ( true === $found_cache_two ) {
					$resultcache_two      = json_decode( $resultcache_two, JSON_OBJECT_AS_ARRAY );
					$buffer_body          = $resultcache_two['modelbuffer_body'];
					$this->ccss_refracted = 2;
					if ( true === $this->errlog_caching ) {
						irld_trace_log( 'found ajax-delivered html for page ' . rawurlencode( $pagename ) . '-' . $this->user_role_md5 . ' CCSS is created from client HTML', 0 );
					}
				} else {
					$this->bufferintags        = $resultcache['bufferintags'];
					$this->bufferinclasses     = $resultcache['bufferinclasses'];
					$this->bufferinclasses_num = $resultcache['bufferinclasses_num'];
					$this->bufferinputtypes    = $resultcache['bufferinputtypes'];
					$this->bufferinids         = $resultcache['bufferinids'];
					$this->bufferinids_num     = $resultcache['bufferinids_num'];
					$ret                       = $resultcache['ret'];
					$this->modelbuffer_body    = $resultcache['modelbuffer_body'];
					if ( true === $this->errlog_caching ) {
						irld_trace_log( 'found cache of the model for page ' . rawurlencode( $pagename ) . '-' . $this->user_role_md5, 0 );
					}

					if ( 2 !== $this->ccss_refracted ) {
						$this->generate_css_below_the_fold = false;
						$this->inline_ccss                 = false;
						if ( true === $this->errlog_caching ) {
							irld_trace_log( 'as state of ccss refracted is ' . $this->ccss_refracted . ' I am not creating CCSS', 0 );
						}
					} elseif ( true === $this->errlog_caching ) {
							irld_trace_log( 'as state of ccss refracted is ' . $this->ccss_refracted . ' CCSS is created from client HTML', 0 );
					}

					return $ret;
				}
			} else {

				$keyrequest_two  = 'real-page-' . rawurlencode( $pagename ) . '-' . $this->user_role_md5;
				$found_cache_two = null;
				$resultcache_two = wp_cache_get( $keyrequest_two, $object_cache_group, false, $found_cache_two );
				if ( true === $found_cache_two ) {
					$resultcache_two      = json_decode( $resultcache_two, JSON_OBJECT_AS_ARRAY );
					$buffer_body          = $resultcache_two['modelbuffer_body'];
					$this->ccss_refracted = 2;
					if ( true === $this->errlog_caching ) {
						irld_trace_log( 'found no cache, but found ajax-delivered html for page ' . rawurlencode( $pagename ) . '-' . $this->user_role_md5 . ' CCSS is created from client HTML', 0 );
					}
				} else {
					$this->ccss_refracted              = 1;
					$this->generate_css_below_the_fold = false;
					$this->inline_ccss                 = false;
					if ( true === $this->errlog_caching ) {
						irld_trace_log( 'found no cache of the model for page ' . rawurlencode( $pagename ) . '-' . $this->user_role_md5 . ' using key "' . $keyrequest_two . '", not creating CCSS', 0 );
					}
				}
			}
		} else {
			$option_name    = 'indexreloaded_cache_real-page-' . rawurlencode( $pagename ) . '-' . $this->user_role_md5;
			$resultcache_db = get_option( $option_name );
			if ( false !== $resultcache_db ) {
				$resultcache_db       = json_decode( $resultcache_db, JSON_OBJECT_AS_ARRAY );
				$buffer_body          = $resultcache_db['modelbuffer_body'];
				$this->ccss_refracted = 2;
				if ( true === $this->errlog_caching ) {
					irld_trace_log( 'found ajax-delivered html for page ' . rawurlencode( $pagename ) . '-' . $this->user_role_md5 . ' in database, CCSS is created from client HTML', 0 );
				}
			} else {
				if ( true === $this->errlog_caching ) {
					irld_trace_log( 'object cache with redis is not active, and no database cache entry present, not creating CCSS', 0 );
				}

				$this->ccss_refracted              = 1;
				$this->generate_css_below_the_fold = false;
				$this->inline_ccss                 = false;
			}
		}

		// unscript $buffer_body.
		$all_js_clean = false;
		do {
			$unscript_buffer_body     = '';
			$unscript_buffer_body_arr = explode( '<script ', $buffer_body );
			if ( count( $unscript_buffer_body_arr ) > 1 ) {
				$unscript_buffer_body     .= $unscript_buffer_body_arr[0];
				$len_unscript_buffer_body  = strlen( $unscript_buffer_body );
				$unscript_buffer_body_rest = substr( $buffer_body, ( $len_unscript_buffer_body + 1 ) );
				$scriptend_pos             = strpos( $unscript_buffer_body_rest, '</script>' );
				$scriptendtag_pos          = strpos( $unscript_buffer_body_rest, '>' );
				$scripttag                 = substr( $unscript_buffer_body_rest, 0, $scriptendtag_pos );
				$htmlscript_contents       = '';
				if ( str_replace( '"text/template"', '', $scripttag ) !== $scripttag ) {
					$htmlscript_contents = substr( $unscript_buffer_body_rest, ( $scriptendtag_pos + 1 ), $scriptend_pos - strlen( $scripttag ) - 1 );
					if ( ! ( ( str_replace( '</', '', $htmlscript_contents ) !== $htmlscript_contents ) && ( str_replace( '>', '', $htmlscript_contents ) !== $htmlscript_contents ) ) ) {
						$htmlscript_contents = '';
					}
				}

				$unscript_buffer_body_after_scriptend = substr( $unscript_buffer_body_rest, ( $scriptend_pos + 9 ) );
				$buffer_body                          = $unscript_buffer_body . $htmlscript_contents . $unscript_buffer_body_after_scriptend;
			} else {
				$buffer_body  = $unscript_buffer_body_arr[0];
				$all_js_clean = true;
			}
		} while ( false === $all_js_clean );

		// unstyle $buffer_body.
		$all_css_clean = false;
		do {
			$unstyle_buffer_body     = '';
			$unstyle_buffer_body_arr = explode( '<style', $buffer_body );
			if ( count( $unstyle_buffer_body_arr ) > 1 ) {
				$unstyle_buffer_body               .= $unstyle_buffer_body_arr[0];
				$len_unstyle_buffer_body            = strlen( $unstyle_buffer_body );
				$unstyle_buffer_body_rest           = substr( $buffer_body, ( $len_unstyle_buffer_body + 1 ) );
				$styleend_pos                       = strpos( $unstyle_buffer_body_rest, '</style>' );
				$unstyle_buffer_body_after_styleend = substr( $unstyle_buffer_body_rest, ( $styleend_pos + 8 ) );
				$buffer_body                        = $unstyle_buffer_body . $unstyle_buffer_body_after_styleend;
			} else {
				$buffer_body   = $unstyle_buffer_body_arr[0];
				$all_css_clean = true;
			}
		} while ( false === $all_css_clean );

		$buffer_body = str_replace( '</div >', '</div>', $buffer_body );
		// tags.
		$buffer_body = preg_replace( '/\>\s+\</m', '><', $buffer_body );
		$buffer_body = str_replace( "\n", ' ', $buffer_body );
		$buffer_body = str_replace( "\t", '', $buffer_body );
		$buffer_body = str_replace( "\r", '', $buffer_body );
		$buffer_body = str_replace( '> <', '><', $buffer_body );

		$this->modelbuffer_body = $buffer_body;
		// tags basic.
		$bufferintags['html']             = array();
		$bufferintags['html']['starts']   = array();
		$bufferintags['html']['starts'][] = -7;
		$bufferintags['html']['ends']     = array();
		$bufferintags['html']['ends'][]   = strlen( $buffer_body );

		// tags singletons.
		$singletons     = ',img,area,br,hr,embed,input,polygon,path,';
		$singletons_arr = explode( ',', $singletons );
		foreach ( $singletons_arr as $singletons_tag ) {
			if ( '' !== trim( $singletons_tag ) ) {
				$buffer_body_singletons_arr       = explode( '<' . $singletons_tag, strtolower( $buffer_body ) );
				$count_buffer_body_singletons_arr = count( $buffer_body_singletons_arr );
				if ( $count_buffer_body_singletons_arr > 1 ) {
					$bufferintags[ $singletons_tag ]           = array();
					$bufferintags[ $singletons_tag ]['starts'] = array();
					$bufferintags[ $singletons_tag ]['ends']   = array();
					$pos_add                                   = 0;
					$posstart                                  = 0;
					$len_tag                                   = strlen( $singletons_tag ) + 1;
					$i_singleton_tag                           = 0;
					foreach ( $buffer_body_singletons_arr as $singleton_tag ) {
						$posstart                                    = $posstart + $pos_add + strlen( $singleton_tag );
						$bufferintags[ $singletons_tag ]['starts'][] = $posstart;
						$buffer_body_remain                          = substr( $buffer_body, $posstart );
						$tag_ends                                    = strpos( $buffer_body_remain, '>' ) + $posstart;
						$bufferintags[ $singletons_tag ]['ends'][]   = $tag_ends;
						$pos_add                                     = $len_tag;
						++$i_singleton_tag;
						if ( $i_singleton_tag + 1 === $count_buffer_body_singletons_arr ) {
							break;

						}
					}
				}
			}
		}

		// tags rest of.
		$bufferinarrbase = explode( '<', $buffer_body );
		$pos_add         = 0;
		$posstart        = 0;
		$len_tag         = 1;
		$monitortag      = 'xxxdiv';
		foreach ( $bufferinarrbase as $taginput ) {
			$taginputdetailarr = explode( '>', $taginput );
			$taginputdetail    = trim( $taginputdetailarr[0] );
			if ( ( str_replace( '!', '', $taginputdetail ) === $taginputdetail ) ) {
				if ( str_replace( ':::', '', $taginputdetail ) === $taginputdetail ) {
					$tagarr = explode( ' ', $taginput );
					if ( strlen( trim( $tagarr[0] ) ) < strlen( $taginputdetail ) ) {
						if ( ( str_replace( '=', '', trim( $tagarr[0] ) ) === trim( $tagarr[0] ) ) && ( str_replace( '>', '', trim( $tagarr[0] ) ) === trim( $tagarr[0] ) ) ) {
							if ( ( '' !== trim( $tagarr[0] ) ) && ( str_replace( ',' . trim( $tagarr[0] ) . ',', '', $singletons ) === $singletons ) ) {
								if ( ! isset( $bufferintags[ strtolower( trim( $tagarr[0] ) ) ] ) ) {
									$bufferintags[ strtolower( trim( $tagarr[0] ) ) ]           = array();
									$bufferintags[ strtolower( trim( $tagarr[0] ) ) ]['starts'] = array();
									$bufferintags[ strtolower( trim( $tagarr[0] ) ) ]['ends']   = array();
								}

								if ( strtolower( trim( $tagarr[0] ) ) === $monitortag ) {
									$monitorthis = true;
								} else {
									$monitorthis = false;
								}

								if ( true === $monitorthis ) {
									irld_trace_log( 'tracking ' . $monitortag . ' tag found with $posstart: ' . $posstart, 0 );
								}

								$bufferintags[ strtolower( trim( $tagarr[0] ) ) ]['starts'][] = $posstart;
								$buffer_body_remain = substr( $buffer_body, $posstart );
								if ( true === $monitorthis ) {
									irld_trace_log( 'tracking ' . $monitortag . ' tag, buffer_body_remain: "' . substr( $buffer_body_remain, 0, 256 ) . '".........', 0 );
								}

								$body_remain_tag_ends_arr = explode( '</' . strtolower( trim( $tagarr[0] ) ) . '>', substr( $buffer_body_remain, 1 ) );
								$posend                   = 0;
								$pos_endadd               = 0;
								$len_endtag               = strlen( '</' . strtolower( trim( $tagarr[0] ) ) . '>' );
								$previous_tag             = strtolower( trim( $tagarr[0] ) );
								$open_start_tags          = 1;
								foreach ( $body_remain_tag_ends_arr as $body_remain_tag_end ) {
									$body_remain_tag_end_morestart_tags_arr = explode( '<' . strtolower( $previous_tag ), $body_remain_tag_end );
									$count_start_tags                       = count( $body_remain_tag_end_morestart_tags_arr );
									$open_start_tags                        = $open_start_tags + $count_start_tags - 2;
									$posend                                 = $posend + $pos_endadd + strlen( $body_remain_tag_end );
									if ( true === $monitorthis ) {
										irld_trace_log( 'tracking ' . $monitortag . ' tag, open_start_tags: ' . $open_start_tags, 0 );
									}

									$pos_endadd = $len_endtag;
									if ( 0 === $open_start_tags ) {
										$found_end_tag = true;
										break;
									}
								}

								$bufferintags[ strtolower( trim( $tagarr[0] ) ) ]['ends'][] = $posstart + $posend + $len_endtag;
								if ( true === $monitorthis ) {
									if ( true === $found_end_tag ) {
										irld_trace_log( 'tracking ' . $monitortag . ' tag, resumes in ends: ' . ( $posstart + $posend + $len_endtag ) );
									} else {
										irld_trace_log( 'tracking ' . $monitortag . ' tag, no closing tag found: ' . $posstart );
									}
								}

								$posstart = $posstart + $pos_add + strlen( $taginput );
								$pos_add  = $len_tag;
							} else {
								$posstart = $posstart + $pos_add + strlen( $taginput );
								$pos_add  = $len_tag;
							}
						} else {
							$posstart = $posstart + $pos_add + strlen( $taginput );
							$pos_add  = $len_tag;
						}
					} elseif ( ( str_replace( '=', '', trim( $taginputdetail ) ) === trim( $taginputdetail ) ) && ( str_replace( '>', '', trim( $taginputdetail ) ) === trim( $taginputdetail ) ) &&
								( str_replace( '/', '', trim( $taginputdetail ) ) === trim( $taginputdetail ) ) ) {

						if ( ( '' !== trim( $taginputdetail ) ) && ( str_replace( ',' . $taginputdetail . ',', '', $singletons ) === $singletons ) ) {
							if ( ! isset( $bufferintags[ strtolower( trim( $taginputdetail ) ) ] ) ) {
								$bufferintags[ strtolower( trim( $taginputdetail ) ) ]           = array();
								$bufferintags[ strtolower( trim( $taginputdetail ) ) ]['starts'] = array();
								$bufferintags[ strtolower( trim( $taginputdetail ) ) ]['ends']   = array();
							}

							if ( strtolower( trim( $taginputdetail ) ) === $monitortag ) {
								$monitorthis = true;
							} else {
								$monitorthis = false;
							}

							$bufferintags[ strtolower( trim( $taginputdetail ) ) ]['starts'][] = $posstart;
							$buffer_body_remain       = substr( $buffer_body, $posstart );
							$body_remain_tag_ends_arr = explode( '</' . strtolower( trim( $taginputdetail ) ) . '>', substr( $buffer_body_remain, 1 ) );
							$posend                   = 0;
							$pos_endadd               = 0;
							$len_endtag               = strlen( '</' . strtolower( trim( $taginputdetail ) ) . '>' );
							$found_end_tag            = false;
							$open_start_tags          = 1;
							foreach ( $body_remain_tag_ends_arr as $body_remain_tag_end ) {
								$body_remain_tag_end_morestart_tags_arr = explode( '<' . strtolower( trim( $taginputdetail ) ), $body_remain_tag_end );
								$count_start_tags                       = count( $body_remain_tag_end_morestart_tags_arr );
								$open_start_tags                        = $open_start_tags + $count_start_tags - 2;
								$posend                                 = $posend + $pos_endadd + strlen( $body_remain_tag_end );
								$pos_endadd                             = $len_endtag;
								if ( 0 === $open_start_tags ) {
									$found_end_tag = true;
									break;
								}
							}

							$bufferintags[ strtolower( trim( $taginputdetail ) ) ]['ends'][] = $posstart + $posend + $len_endtag;
							if ( true === $monitorthis ) {
								if ( true === $found_end_tag ) {
									irld_trace_log( 'tracking ' . $monitortag . ' tag, resumes in ends: ' . ( $posstart + $posend + 1 + $len_endtag ) );
								} else {
									irld_trace_log( 'tracking ' . $monitortag . ' tag, no closing tag found: ' . $posstart );
								}
							}

							$posstart = $posstart + $pos_add + strlen( $taginput );
							$pos_add  = $len_tag;
						} else {
							$posstart = $posstart + $pos_add + strlen( $taginput );
							$pos_add  = $len_tag;
						}
					} else {
						$posstart = $posstart + $pos_add + strlen( $taginput );
						$pos_add  = $len_tag;
					}
				} else {
					$posstart = $posstart + $pos_add + strlen( $taginput );
					$pos_add  = $len_tag;
				}
			} else {
				$posstart = $posstart + $pos_add + strlen( $taginput );
				$pos_add  = $len_tag;
			}
		}

		foreach ( $this->tags_to_keep_above_the_fold as $tag_to_keep_above_the_fold ) {
			if ( ! isset( $bufferintags[ $tag_to_keep_above_the_fold ] ) ) {
				$bufferintags[ $tag_to_keep_above_the_fold ]           = array();
				$bufferintags[ $tag_to_keep_above_the_fold ]['starts'] = array();
				$bufferintags[ $tag_to_keep_above_the_fold ]['ends']   = array();
			}

			$bufferintags[ $tag_to_keep_above_the_fold ]['starts'][] = -1;
			$bufferintags[ $tag_to_keep_above_the_fold ]['ends'][]   = -1;
		}

		ksort( $bufferintags );
		$this->bufferintags = $bufferintags;

		// make model-array with all classes found below <body>.
		$bufferinclasses      = array();
		$bufferinclasses_num  = array();
		$bufferinarrbase      = explode( 'class="', $buffer_body );
		$pos_add              = 7;
		$posstart             = 0;
		$len_explodearg_class = 7;
		$monitorclass         = 'xxx-ast-builder-menu-1';
		$previous_taginput    = '';
		foreach ( $bufferinarrbase as $taginput ) {
			if ( '' !== $previous_taginput ) {
				// find last tag - holding class.
				$previous_taginput_arr      = explode( '<', $previous_taginput );
				$end_previous_taginput      = end( $previous_taginput_arr );
				$prev_tag_raw_arr           = explode( ' ', $end_previous_taginput );
				$prev_tag_raw               = array_shift( $prev_tag_raw_arr );
				$previous_tag               = str_replace( "\t", '', str_replace( "\n", '', $prev_tag_raw ) );
				$distance_tagstart_to_class = 1 + strlen( $end_previous_taginput );
				$posstart_tag               = $posstart - $distance_tagstart_to_class - 7;
				if ( str_replace( ',' . $previous_tag . ',', '', $singletons ) === $singletons ) {
					$buffer_body_remain       = substr( $buffer_body, $posstart_tag );
					$body_remain_tag_ends_arr = explode( '</' . strtolower( $previous_tag ) . '>', substr( $buffer_body_remain, 1 ) );
					$posend                   = 0;
					$pos_endadd               = 0;
					$previous_tag_ends        = 0;
					$len_endtag               = strlen( '</' . strtolower( $previous_tag ) . '>' );
					$count_start_tags_inc     = 1;
					$found_end_tag            = false;
					$open_start_tags          = 1;
					foreach ( $body_remain_tag_ends_arr as $body_remain_tag_end ) {
						$body_remain_tag_end_morestart_tags_arr = explode( '<' . strtolower( $previous_tag ), $body_remain_tag_end );
						$count_start_tags                       = count( $body_remain_tag_end_morestart_tags_arr );
						$open_start_tags                        = $open_start_tags + $count_start_tags - 2;
						$posend                                 = $posend + $pos_endadd + strlen( $body_remain_tag_end );
						$pos_endadd                             = $len_endtag;
						if ( 0 === $open_start_tags ) {
							$found_end_tag = true;
							break;
						}
					}

					$previous_tag_ends = $posstart_tag + $posend + $len_endtag;
				} else {
					$buffer_body_remain       = substr( $buffer_body, $posstart_tag );
					$body_remain_tag_ends_arr = explode( '>', substr( $buffer_body_remain, 1 ) );
					$posend                   = 0;
					$previous_tag_ends        = 0;
					$posend                   = strlen( $body_remain_tag_ends_arr[0] ); // + 1;
					$previous_tag_ends        = $posstart_tag + $posend + 1;
				}

				$classesarr  = explode( '"', $taginput );
				$classesstr  = $classesarr[0];
				$classarr    = explode( ' ', $classesstr );
				$monitorthis = false;
				foreach ( $classarr as $classinput ) {
					if ( ( str_replace( '=', '', trim( $classinput ) ) === trim( $classinput ) ) && ( str_replace( '>', '', trim( $classinput ) ) === trim( $classinput ) ) ) {
						if ( str_replace( '/', '', trim( $classinput ) ) === trim( $classinput ) ) {
							if ( '' !== trim( $classinput ) ) {
								$classinputnn = preg_replace( '/\d/', '', trim( $classinput ) );
								$dlen         = strlen( trim( $classinput ) ) - strlen( $classinputnn );
								if ( 0 === $dlen ) {
									if ( ! isset( $bufferinclasses[ trim( $classinput ) ] ) ) {
										$bufferinclasses[ trim( $classinput ) ]           = array();
										$bufferinclasses[ trim( $classinput ) ]['tag']    = array();
										$bufferinclasses[ trim( $classinput ) ]['starts'] = array();
										$bufferinclasses[ trim( $classinput ) ]['ends']   = array();
									}

									if ( strtolower( trim( $classinput ) ) === $monitorclass ) {
										$monitorthis = true;
									}

									if ( true === $monitorthis ) {
										irld_trace_log( 'tracking ' . $monitorclass . ' class on tag ' . $previous_tag . ' found with position ' . $posstart_tag . ' to ' . $previous_tag_ends, 0 );
									}

									$bufferinclasses[ trim( $classinput ) ]['starts'][] = $posstart_tag;
									$bufferinclasses[ trim( $classinput ) ]['ends'][]   = $previous_tag_ends;
									$bufferinclasses[ trim( $classinput ) ]['tag'][]    = $previous_tag;

								} else {
									$innocent               = true;
									$current_jailidentifier = '';
									foreach ( $numericjailarray as $jailidentifier ) {
										if ( str_replace( $jailidentifier, '', substr( $classinputnn, 0, strlen( $jailidentifier ) ) ) !== substr( $classinputnn, 0, strlen( $jailidentifier ) ) ) {
											$current_jailidentifier = $jailidentifier;
											$innocent               = false;
											break;
										}
									}

									foreach ( $numericnojailarray as $jailidentifier ) {
										if ( str_replace( $jailidentifier, '', $classinputnn ) !== $classinputnn ) {
											$current_jailidentifier = '';
											$innocent               = true;
											break;
										}
									}

									if ( strtolower( trim( $classinput ) ) === $monitorclass ) {
										$monitorthis = true;
									}

									if ( true === $innocent ) {
										if ( ! isset( $bufferinclasses[ trim( $classinput ) ] ) ) {
											$bufferinclasses[ trim( $classinput ) ]           = array();
											$bufferinclasses[ trim( $classinput ) ]['tag']    = array();
											$bufferinclasses[ trim( $classinput ) ]['starts'] = array();
											$bufferinclasses[ trim( $classinput ) ]['ends']   = array();
										}

										if ( true === $monitorthis ) {
											irld_trace_log( 'tracking numeric element ' . trim( $classinput ) . ' class on tag ' . $previous_tag . ' found with position ' . $posstart_tag . ' to ' . $previous_tag_ends, 0 );
										}

										$bufferinclasses[ trim( $classinput ) ]['starts'][] = $posstart_tag;
										$bufferinclasses[ trim( $classinput ) ]['ends'][]   = $previous_tag_ends;
										$bufferinclasses[ trim( $classinput ) ]['tag'][]    = $previous_tag;

									} else {
										if ( true === $err_log_tagcloud ) {
											irld_trace_log( 'numeric class : ' . trim( $classinput ) );
										}

										if ( ! isset( $bufferinclasses_num[ trim( $current_jailidentifier ) ] ) ) {
											$bufferinclasses_num[ trim( $current_jailidentifier ) ]           = array();
											$bufferinclasses_num[ trim( $current_jailidentifier ) ]['tag']    = array();
											$bufferinclasses_num[ trim( $current_jailidentifier ) ]['starts'] = array();
											$bufferinclasses_num[ trim( $current_jailidentifier ) ]['ends']   = array();
										}

										if ( true === $monitorthis ) {
											irld_trace_log( 'tracking numericjailed element ' . trim( $classinput ) . ' class on tag ' . $previous_tag . ' found with position ' . $posstart_tag . ' to ' . $previous_tag_ends, 0 );
										}

										$bufferinclasses_num[ trim( $current_jailidentifier ) ]['starts'][] = $posstart_tag;
										$bufferinclasses_num[ trim( $current_jailidentifier ) ]['ends'][]   = $previous_tag_ends;
										$bufferinclasses_num[ trim( $current_jailidentifier ) ]['tag'][]    = $previous_tag;

									}
								}
							}
						}
					}
				}
			}

			$posstart          = $posstart + $pos_add + strlen( $taginput );
			$pos_add           = $len_explodearg_class;
			$previous_taginput = $taginput;
		}

		foreach ( $this->classes_to_keep_above_the_fold as $class_to_keep_above_the_fold ) {
			if ( ! isset( $bufferinclasses[ $class_to_keep_above_the_fold ] ) ) {
				$bufferinclasses[ $class_to_keep_above_the_fold ]           = array();
				$bufferinclasses[ $class_to_keep_above_the_fold ]['tag']    = array();
				$bufferinclasses[ $class_to_keep_above_the_fold ]['starts'] = array();
				$bufferinclasses[ $class_to_keep_above_the_fold ]['ends']   = array();
			}

			$bufferinclasses[ $class_to_keep_above_the_fold ]['starts'][] = -1;
			$bufferinclasses[ $class_to_keep_above_the_fold ]['ends'][]   = -1;
			$bufferinclasses[ $class_to_keep_above_the_fold ]['tag'][]    = 'any';

		}

		ksort( $bufferinclasses );
		$this->bufferinclasses = $bufferinclasses;
		ksort( $bufferinclasses_num );
		$this->bufferinclasses_num = $bufferinclasses_num;

		// now tags and classes are ok - we do the types, typically associated to input- or button-tags.
		$bufferinputtypes     = array();
		$bufferinarrbase      = explode( 'type="', $buffer_body );
		$pos_add              = 0;
		$posstart             = 0;
		$len_explodearg_class = 6;
		$monitortype          = 'nnnnnumber';
		$previous_taginput    = '';
		foreach ( $bufferinarrbase as $taginput ) {
			if ( '' !== $previous_taginput ) {
				if ( trim( substr( $previous_taginput, -1 ) ) === '' ) {
					// find last tag - holding class.
					$previous_taginput_arr      = explode( '<', $previous_taginput );
					$end_previous_taginput      = end( $previous_taginput_arr );
					$prev_tag_raw_arr           = explode( ' ', $end_previous_taginput );
					$prev_tag_raw               = array_shift( $prev_tag_raw_arr );
					$previous_tag               = str_replace( "\t", '', str_replace( "\n", '', $prev_tag_raw ) );
					$distance_tagstart_to_class = 1 + strlen( $end_previous_taginput );
					$posstart_tag               = $posstart - $distance_tagstart_to_class;
					if ( str_replace( ',' . $previous_tag . ',', '', $singletons ) === $singletons ) {
						$buffer_body_remain       = substr( $buffer_body, $posstart_tag );
						$body_remain_tag_ends_arr = explode( '</' . strtolower( $previous_tag ) . '>', substr( $buffer_body_remain, 1 ) );
						$posend                   = 0;
						$pos_endadd               = 0;
						$previous_tag_ends        = 0;
						$len_endtag               = strlen( '</' . strtolower( $previous_tag ) . '>' );
						$count_start_tags_inc     = 1;
						$found_end_tag            = false;
						$open_start_tags          = 1;
						foreach ( $body_remain_tag_ends_arr as $body_remain_tag_end ) {
							$body_remain_tag_end_morestart_tags_arr = explode( '<' . strtolower( $previous_tag ), $body_remain_tag_end );
							$count_start_tags                       = count( $body_remain_tag_end_morestart_tags_arr );
							$open_start_tags                        = $open_start_tags + $count_start_tags - 2;
							$posend                                 = $posend + $pos_endadd + strlen( $body_remain_tag_end );
							$pos_endadd                             = $len_endtag;
							if ( 0 === $open_start_tags ) {
								$found_end_tag = true;
								break;
							}
						}

						$previous_tag_ends = $posstart_tag + $posend + $len_endtag;
					} else {
						$buffer_body_remain       = substr( $buffer_body, $posstart_tag );
						$body_remain_tag_ends_arr = explode( '>', substr( $buffer_body_remain, 1 ) );
						$posend                   = 0;
						$previous_tag_ends        = 0;
						$posend                   = strlen( $body_remain_tag_ends_arr[0] ); // + 1;
						$previous_tag_ends        = $posstart_tag + $posend + 1;
					}

					$classesarr = explode( '"', $taginput );
					$classesstr = $classesarr[0];
					if ( ( str_replace( '=', '', trim( $classesstr ) ) === trim( $classesstr ) ) && ( str_replace( '>', '', trim( $classesstr ) ) === trim( $classesstr ) ) ) {
						if ( str_replace( '/', '', trim( $classesstr ) ) === trim( $classesstr ) ) {
							if ( str_replace( '\\', '', trim( $classesstr ) ) === trim( $classesstr ) ) {
								if ( '' !== trim( $classesstr ) ) {
									if ( ! isset( $bufferinputtypes[ trim( $classesstr ) ] ) ) {
										$bufferinputtypes[ trim( $classesstr ) ]           = array();
										$bufferinputtypes[ trim( $classesstr ) ]['tag']    = array();
										$bufferinputtypes[ trim( $classesstr ) ]['starts'] = array();
										$bufferinputtypes[ trim( $classesstr ) ]['ends']   = array();
									}

									$bufferinputtypes[ trim( $classesstr ) ]['starts'][] = $posstart_tag;
									$bufferinputtypes[ trim( $classesstr ) ]['ends'][]   = $previous_tag_ends;
									$bufferinputtypes[ trim( $classesstr ) ]['tag'][]    = $previous_tag;

									if ( strtolower( trim( $classesstr ) ) === $monitortype ) {
										$monitorthis = true;
									} else {
										$monitorthis = false;
									}

									if ( true === $monitorthis ) {
										irld_trace_log( 'tracking ' . trim( $classesstr ) . ' type, starts: ' . $posstart_tag . ', ends: ' . $previous_tag_ends . ', on tag: ' . $previous_tag, 0 );
									}
								}
							}
						}
					}
				}
			}

			$posstart          = $posstart + $pos_add + strlen( $taginput );
			$pos_add           = $len_explodearg_class;
			$previous_taginput = $taginput;

		}

		ksort( $bufferinputtypes );
		$this->bufferinputtypes = $bufferinputtypes;

		// make model-array with all ids found below <body>.
		$bufferinids          = array();
		$bufferinids_num      = array();
		$bufferinidsnocms     = array();
		$bufferinarrbase      = explode( 'id="', $buffer_body );
		$pos_add              = 0;
		$posstart             = 0;
		$len_explodearg_class = 4;
		$monitorid            = 'xxmasthead';
		$previous_taginput    = '';

		foreach ( $bufferinarrbase as $taginput ) {
			if ( '' !== $previous_taginput ) {
				// find last tag - holding class.
				$previous_taginput_arr      = explode( '<', $previous_taginput );
				$end_previous_taginput      = end( $previous_taginput_arr );
				$prev_tag_raw_arr           = explode( ' ', $end_previous_taginput );
				$prev_tag_raw               = array_shift( $prev_tag_raw_arr );
				$previous_tag               = str_replace( "\t", '', str_replace( "\n", '', $prev_tag_raw ) );
				$distance_tagstart_to_class = 1 + strlen( $end_previous_taginput );
				$posstart_tag               = $posstart - $distance_tagstart_to_class;
				if ( str_replace( ',' . $previous_tag . ',', '', $singletons ) === $singletons ) {
					$buffer_body_remain       = substr( $buffer_body, $posstart_tag );
					$body_remain_tag_ends_arr = explode( '</' . strtolower( $previous_tag ) . '>', substr( $buffer_body_remain, 1 ) );
					$posend                   = 0;
					$pos_endadd               = 0;
					$previous_tag_ends        = 0;
					$len_endtag               = strlen( '</' . strtolower( $previous_tag ) . '>' );
					$count_start_tags_inc     = 1;
					$found_end_tag            = false;
					$open_start_tags          = 1;
					foreach ( $body_remain_tag_ends_arr as $body_remain_tag_end ) {
						$body_remain_tag_end_morestart_tags_arr = explode( '<' . strtolower( $previous_tag ), $body_remain_tag_end );
						$count_start_tags                       = count( $body_remain_tag_end_morestart_tags_arr );
						$open_start_tags                        = $open_start_tags + $count_start_tags - 2;
						$posend                                 = $posend + $pos_endadd + strlen( $body_remain_tag_end );
						$pos_endadd                             = $len_endtag;
						if ( 0 === $open_start_tags ) {
							$found_end_tag = true;
							break;
						}
					}

					$previous_tag_ends = $posstart_tag + $posend + $len_endtag;
				} else {
					$buffer_body_remain       = substr( $buffer_body, $posstart_tag );
					$body_remain_tag_ends_arr = explode( '>', substr( $buffer_body_remain, 1 ) );
					$posend                   = 0;
					$previous_tag_ends        = 0;
					$posend                   = strlen( $body_remain_tag_ends_arr[0] ); // + 1;
					$previous_tag_ends        = $posstart_tag + $posend + 1;
				}

				$classesarr = explode( '"', $taginput );
				$classesstr = $classesarr[0];
				if ( ( str_replace( '=', '', trim( $classesstr ) ) === trim( $classesstr ) ) &&
						( str_replace( '>', '', trim( $classesstr ) ) === trim( $classesstr ) ) ) {
					$classinputnn = preg_replace( '/\d/', '', trim( $classesstr ) );
					$dlen         = strlen( trim( $classesstr ) ) - strlen( $classinputnn );
					if ( 0 === $dlen ) {
						if ( ! isset( $bufferinids[ trim( $classesstr ) ] ) ) {
							$bufferinids[ trim( $classesstr ) ]           = array();
							$bufferinids[ trim( $classesstr ) ]['tag']    = array();
							$bufferinids[ trim( $classesstr ) ]['starts'] = array();
							$bufferinids[ trim( $classesstr ) ]['ends']   = array();
						}

						$bufferinids[ trim( $classesstr ) ]['starts'][] = $posstart_tag;
						$bufferinids[ trim( $classesstr ) ]['ends'][]   = $previous_tag_ends;
						$bufferinids[ trim( $classesstr ) ]['tag'][]    = $previous_tag;

						if ( strtolower( trim( $classesstr ) ) === $monitorid ) {
							$monitorthis = true;
						} else {
							$monitorthis = false;
						}

						if ( true === $monitorthis ) {
							irld_trace_log( 'tracking ' . $monitorid . ' type, starts: ' . $posstart_tag . ', ends: ' . $previous_tag_ends . ', on tag: ' . $previous_tag, 0 );
						}

						if ( 0 === preg_match( '/\\d/', $classesstr ) ) {
							if ( ( 0 === intval( substr( $classesstr, 1 ) ) ) && ( substr( $classesstr, 0, 1 ) !== 'c' ) ) {
								if ( 0 === intval( substr( trim( $classesstr ), ( strlen( trim( $classesstr ) ) - 2 ) ) ) ) {
									if ( '' !== trim( $classesstr ) ) {
										$bufferinidsnocms[ trim( $classesstr ) ] = 1;
									}
								}
							}

							if ( ( intval( substr( $classesstr, 1 ) ) > 0 ) && ( substr( $classesstr, 0, 1 ) !== 'c' ) ) {
								if ( 0 === intval( substr( trim( $classesstr ), ( strlen( trim( $classesstr ) ) - 2 ) ) ) ) {
									if ( '' !== trim( $classesstr ) ) {
										$bufferinidsnocms[ trim( $classesstr ) ] = 1;
									}
								}
							}
						}
					} else {
						$innocent               = true;
						$current_jailidentifier = '';
						foreach ( $numericjailarray as $jailidentifier ) {
							if ( str_replace( $jailidentifier, '', $classinputnn ) !== $classinputnn ) {
								$current_jailidentifier = $jailidentifier;
								$innocent               = false;
								break;
							}
						}

						foreach ( $numericnojailarray as $jailidentifier ) {
							if ( str_replace( $jailidentifier, '', $classinputnn ) !== $classinputnn ) {
								$current_jailidentifier = '';
								$innocent               = true;
								break;
							}
						}

						if ( true === $innocent ) {
							if ( ! isset( $bufferinids[ trim( $classesstr ) ] ) ) {
								$bufferinids[ trim( $classesstr ) ]           = array();
								$bufferinids[ trim( $classesstr ) ]['tag']    = array();
								$bufferinids[ trim( $classesstr ) ]['starts'] = array();
								$bufferinids[ trim( $classesstr ) ]['ends']   = array();
							}

							$bufferinids[ trim( $classesstr ) ]['starts'][] = $posstart_tag;
							$bufferinids[ trim( $classesstr ) ]['ends'][]   = $previous_tag_ends;
							$bufferinids[ trim( $classesstr ) ]['tag'][]    = $previous_tag;

							if ( strtolower( trim( $classesstr ) ) === $monitorid ) {
								$monitorthis = true;
							} else {
								$monitorthis = false;
							}

							if ( true === $monitorthis ) {
								irld_trace_log( 'tracking ' . trim( $classesstr ) . ' id, starts: ' . $posstart_tag . ', ends: ' . $previous_tag_ends . ', on tag: ' . $previous_tag, 0 );
							}

							if ( 0 === preg_match( '/\\d/', $classesstr ) ) {
								if ( ( 0 === intval( substr( $classesstr, 1 ) ) ) && ( substr( $classesstr, 0, 1 ) !== 'c' ) ) {
									if ( 0 === intval( substr( trim( $classesstr ), ( strlen( trim( $classesstr ) ) - 2 ) ) ) ) {
										if ( '' !== trim( $classesstr ) ) {
											$bufferinidsnocms[ trim( $classesstr ) ] = 1;
										}
									}
								}

								if ( ( intval( substr( $classesstr, 1 ) ) > 0 ) && ( substr( $classesstr, 0, 1 ) !== 'c' ) ) {
									if ( 0 === intval( substr( trim( $classesstr ), ( strlen( trim( $classesstr ) ) - 2 ) ) ) ) {
										if ( '' !== trim( $classesstr ) ) {
											$bufferinidsnocms[ trim( $classesstr ) ] = 1;
										}
									}
								}
							}
						} else {
							if ( true === $err_log_tagcloud ) {
								irld_trace_log( 'numeric id : ' . trim( $classesstr ), 0 );
							}

							if ( ! isset( $bufferinids_num[ trim( $current_jailidentifier ) ] ) ) {
								$bufferinids_num[ trim( $current_jailidentifier ) ]           = array();
								$bufferinids_num[ trim( $current_jailidentifier ) ]['tag']    = array();
								$bufferinids_num[ trim( $current_jailidentifier ) ]['starts'] = array();
								$bufferinids_num[ trim( $current_jailidentifier ) ]['ends']   = array();
							}

							$bufferinids_num[ trim( $current_jailidentifier ) ]['starts'][] = $posstart_tag;
							$bufferinids_num[ trim( $current_jailidentifier ) ]['ends'][]   = $previous_tag_ends;
							$bufferinids_num[ trim( $current_jailidentifier ) ]['tag'][]    = $previous_tag;
						}
					}
				}
			}

			$posstart          = $posstart + $pos_add + strlen( $taginput );
			$pos_add           = $len_explodearg_class;
			$previous_taginput = $taginput;
		}

		foreach ( $this->ids_to_keep_above_the_fold as $id_to_keep_above_the_fold ) {
			if ( ! isset( $bufferinids[ $id_to_keep_above_the_fold ] ) ) {
				$bufferinids[ $id_to_keep_above_the_fold ]           = array();
				$bufferinids[ $id_to_keep_above_the_fold ]['tag']    = array();
				$bufferinids[ $id_to_keep_above_the_fold ]['starts'] = array();
				$bufferinids[ $id_to_keep_above_the_fold ]['ends']   = array();
			}

			$bufferinids[ $id_to_keep_above_the_fold ]['starts'][] = -1;
			$bufferinids[ $id_to_keep_above_the_fold ]['ends'][]   = -1;
			$bufferinids[ $id_to_keep_above_the_fold ]['tag'][]    = 'any';
			$bufferinidsnocms[ $id_to_keep_above_the_fold ]        = 1;
		}

		ksort( $bufferinids );
		ksort( $bufferinidsnocms );
		$this->bufferinids = $bufferinids;
		ksort( $bufferinids_num );
		$this->bufferinids_num = $bufferinids_num;
		// no ids from content elements.
		$ret = implode( '', array_keys( $bufferintags ) ) . implode( '', array_keys( $bufferinclasses ) ) .
				implode( '', array_keys( $bufferinputtypes ) ) . implode( '', array_keys( $bufferinidsnocms ) ) .
				implode( '', array_keys( $bufferinclasses_num ) ) . implode( '', array_keys( $bufferinids_num ) );
		if ( true === $err_log_tagcloud ) {
			irld_trace_log( 'md5: ' . md5( $ret ) . ', CLOUD : "' . $ret . '"', 0 );
		}
		$ret = md5( $ret );
		if ( ( defined( 'WP_REDIS_CLIENT' ) ) && ( is_plugin_active( 'redis-cache/redis-cache.php' ) ) ) {
			$resultcache                        = array();
			$resultcache['bufferintags']        = $this->bufferintags;
			$resultcache['bufferinclasses']     = $this->bufferinclasses;
			$resultcache['bufferinputtypes']    = $this->bufferinputtypes;
			$resultcache['bufferinids']         = $this->bufferinids;
			$resultcache['bufferinids_num']     = $this->bufferinids_num;
			$resultcache['bufferinclasses_num'] = $this->bufferinclasses_num;
			$resultcache['ret']                 = $ret;
			$resultcache['modelbuffer_body']    = $this->modelbuffer_body;
			$resultcache['ccss_refracted']      = $this->ccss_refracted;
			$resultcache                        = wp_json_encode( $resultcache );
			$keyrequest                         = 'page-' . rawurlencode( $pagename ) . '-' . $this->user_role_md5;
			wp_cache_set( $keyrequest, $resultcache, $object_cache_group, $object_cache_expire );
			$wp_version = get_bloginfo( 'version' );
			if ( version_compare( $wp_version, '6.3.0' ) > 0 ) {
				wp_cache_set_last_changed( $object_cache_group );
			}
			if ( true === $this->errlog_caching ) {
				irld_trace_log( 'cached model for page ' . rawurlencode( $pagename ) . '-' . $this->user_role_md5 . ' using refract-level ' . $this->ccss_refracted . ', keyrequest: ' . $keyrequest . ', length of model: ' . strlen( $this->modelbuffer_body ) . ', returns: ' . $ret, 0 );
			}
		}

		return $ret;
	}

	/**
	 * Splits $filecontent into an array, one holding CSS for above the fold, the other below the fold
	 *
	 * @param string $filecontent all CSS.
	 * @return array $filecontents, [0] = $filecontentabovethefold;[1] = $filecontentbelowthefold;
	 */
	private function split_css_below_above_the_fold( $filecontent ) {
		$dtf                = array();
		$dtf['func']        = 1;
		$dtf['filecontent'] = $filecontent;
		// remove comments.
		$filecontent = preg_replace( '!/\*[^*]*\*+([^/][^*]*\*+)*/!', '', $filecontent );
		// and other clean outs.
		$filecontent = str_replace( "\t", '', $filecontent );
		$filecontent = str_replace( "\r", '', $filecontent );
		$filecontent = str_replace( "\n", '', $filecontent );
		$filecontent = str_replace( '  ', ' ', $filecontent );
		$filecontent = str_replace( ': ', ':', $filecontent );
		// clean. lets  folding report.
		if ( true === $this->make_folding_css_report ) {
			$this->folding_css_reportentry( 'splitCSSAllStart', $filecontent );
		}

		$dtf['make_folding_css_report'] = $this->make_folding_css_report;
		$dtf['bufferinclasses']         = $this->bufferinclasses;
		$dtf['bufferinids']             = $this->bufferinids;
		$dtf['bufferintags']            = $this->bufferintags;
		$dtf['bufferinputtypes']        = $this->bufferinputtypes;

		$dta             = $this->get_split_merge_css( $dtf );
		$cssabove        = $dta['cssabove'];
		$cssbelow        = $dta['cssbelow'];
		$opos_above      = $dta['oPosabove'];
		$opos_below      = $dta['oPosbelow'];
		$filecontents    = array();
		$filecontents[0] = $cssabove;
		$filecontents[1] = $cssbelow;
		$filecontents[2] = $this->crunchCSS( $opos_above );
		$filecontents[3] = $this->crunchCSS( $opos_below );
		if ( true === $this->make_folding_css_report ) {
			$this->folding_css_reportentry( 'splitCSSAllEndAbove', $cssabove );
		}

		if ( true === $this->make_folding_css_report ) {
			$this->folding_css_reportentry( 'splitCSSAllEndBelow', $cssbelow );
		}

		return $filecontents;
	}

	/**
	 * Crunches CSS.
	 *
	 * @param string  $buffer CSS to crunch.
	 * @param boolean $minimal only minimal crunch.
	 * @return string.
	 */
	private function crunchcss( $buffer, $minimal = false ) {
		// remove comments.
		$buffer = preg_replace( '!/\*[^*]*\*+([^/][^*]*\*+)*/!', '', $buffer );
		if ( false === $minimal ) {
			// remove tabs, spaces, new lines, etc.
			$buffer = str_replace( array( "\r\n", "\r", "\n", "\t", '  ', '    ', '    ' ), '', $buffer );
			$buffer = str_replace( '{ ', '{', $buffer );
			$buffer = str_replace( ' }', '}', $buffer );
			$buffer = str_replace( '; ', ';', $buffer );
			$buffer = str_replace( ', ', ',', $buffer );
			$buffer = str_replace( ' {', '{', $buffer );
			$buffer = str_replace( '} ', '}', $buffer );
			$buffer = str_replace( ': ', ':', $buffer );
			$buffer = str_replace( ' :', ':', $buffer );
			$buffer = str_replace( ' ,', ',', $buffer );
			$buffer = str_replace( ' ;', ';', $buffer );
		} else {
			$buffer = str_replace( "\r\n", "\n", $buffer );
		}

		return $buffer;
	}

	/**
	 * Uncrunches CS.
	 *
	 * @param string $buffer CSS, compressed or not.
	 *
	 * @return string uncompressed CSS.
	 */
	private function un_crunch_css( $buffer ) {
		$buffer  = $this->crunchcss( $buffer );
		$buffer  = str_replace( '}', ';}', $buffer );
		$buffer  = str_replace( ';;', ';', $buffer );
		$buffer  = str_replace( '{', " {\n\t", $buffer );
		$buffer  = str_replace( ';', ";\n\t", $buffer );
		$buffer  = str_replace( '}', "}\n", $buffer );
		$buffer  = str_replace( "\t}", '}', $buffer );
		$buffer  = str_replace( "}\n;\n}", "}\n}", $buffer );
		$barr    = explode( '@media', $buffer );
		$cntbatt = count( $barr );
		for ( $i = 0; $i < $cntbatt; $i++ ) {
			$barrmedia    = explode( "}\n}", $barr[ $i ] );
			$cntbarrmedia = count( $barrmedia );
			if ( $cntbarrmedia > 1 ) {
				$barrinsidemedia = explode( "\n", $barrmedia[0] );
				if ( count( $barrinsidemedia ) > 1 ) {
					$barrinsidemedia[1] = str_replace( "\t", '', $barrinsidemedia[1] );
				}

				$barrmedia[0] = implode( "\n\t", $barrinsidemedia );
			}

			$barr[ $i ] = implode( "}\n}", $barrmedia );
		}

		$buffer = implode( '@media', $barr );
		return $buffer;
	}

	/**
	 * Checks if Input is already compressed.
	 *
	 * @param string $buffer string to check for compression.
	 * @return boolean true if compressed.
	 */
	private function is_compressed( $buffer ) {
		$buffercomp = $buffer;
		// remove comments.
		$buffer = preg_replace( '!/\*[^*]*\*+([^/][^*]*\*+)*/!', '', $buffer );
		$buffer = str_replace( array( "\t", "\r", "\n" ), '', $buffer );
		$buffer = str_replace( ' ', '', $buffer );
		$ret    = false;
		if ( 0 !== strlen( $buffer ) ) {
			if ( ( strlen( $buffercomp ) / strlen( $buffer ) ) < 1.1 ) {
				$ret = true;
			}
		}

		if ( true === $this->errlog_jsmin ) {
			irld_trace_log( 'Compression level is ' . substr( ( strlen( $buffercomp ) / strlen( $buffer ) ), 0, 10 ) );
		}

		return $ret;
	}

	/**
	 * Compress JS.
	 *
	 * @param string  $buffer JS to minify.
	 * @param boolean $do_minify true when minifying is needed.
	 * @param boolean $minimal if true only perform minimal minification not using jsmin.
	 *
	 * @return string
	 */
	private function compressjs( $buffer, $do_minify, $minimal = false ) {
		$buffer = str_replace( '/* <![CDATA[ */', '', $buffer );
		$buffer = str_replace( '/* ]]> */', '', $buffer );
		if ( true === $do_minify ) {
			// settings say to minify JS.
			if ( false === $minimal ) {
				// remove comments.
				$buffer = preg_replace( '!/\*[^*]*\*+([^/][^*]*\*+)*/!', '', $buffer );
				// script has been recognised as non compressed by function is_compressed.
				$buffer           = str_replace( array( "\t", '  ', '    ', '     ' ), '', $buffer );
				$this->lib_js_min = new \Indexreloadedjsmin();
				$buffer           = $this->lib_js_min->minify( $buffer );

			} else {
				$buffer = str_replace( "\r\n", "\n", $buffer );
				// remove comments.
				$buffer = preg_replace( '!/\*[^*]*\*+([^/][^*]*\*+)*/!', '', $buffer );
				if ( true === $this->errlog_jsmin ) {
					irld_trace_log( 'Nominify 2 for ' . $buffer );
				}
			}

			$buffer = str_replace( "\t", '', $buffer );

		} elseif ( true === $this->errlog_jsmin ) {
			// remove comments.
			$buffer = preg_replace( '!/\*[^*]*\*+([^/][^*]*\*+)*/!', '', $buffer );
			irld_trace_log( 'Nominify 3 for ' . $buffer );
		} else {
			// remove comments.
			$buffer = preg_replace( '!/\*[^*]*\*+([^/][^*]*\*+)*/!', '', $buffer );
		}

		return $buffer;
	}

	/**
	 * Checks for @import instructions, reads the file and inserts text in output.
	 *
	 * @param string $writecsstext CSS text to inspect .
	 * @param string $checkpath path to file (if present).
	 * @param array  $checkpatharr array with the parts of path to a file.
	 * @param int    $countcheckpatharr number of parts in path.
	 *
	 * @return string $writecsstext
	 */
	private function handle_css_at_import_files( $writecsstext, $checkpath, $checkpatharr, $countcheckpatharr ) {
		// now first the @imports ... like @import "example.css" all; @import.
		$writecsstextout = '';
		if ( '' !== $writecsstext ) {
			$hypos                = '';
			$writecsstextarr      = array();
			$writecsstextarr      = explode( '@import', $writecsstext );
			$writecsstextarrcount = count( $writecsstextarr );
			$initialcss           = $writecsstextarr[0];
			for ( $q = 1; $q < $writecsstextarrcount; $q++ ) {
				$hypos               = '';
				$writecsstextqarr    = array();
				$atimporttoreplace   = '';
				$writecsstextqarr    = explode( ';', $writecsstextarr[ $q ] );
				$writecsstextqarr[0] = str_replace( '#url(', 'url(', $writecsstextqarr[0] );
				$writecsstextqarr[0] = str_replace( ' all', '', $writecsstextqarr[0] );
				$writecsstextqarr[0] = str_replace( '"', '")', $writecsstextqarr[0] );
				$writecsstextqarr[0] = str_replace( ' ")', 'url("', $writecsstextqarr[0] );
				$fullimportelement   = $writecsstextqarr[0] . ';';
				$remainingcss        = '';
				if ( 2 === count( $writecsstextqarr ) ) {
					if ( '' !== $writecsstextqarr[1] ) {
						$remainingcss = $writecsstextqarr[1];
					}
				} elseif ( count( $writecsstextqarr ) > 2 ) {
					$remainingcss = implode( ';', $writecsstextqarr );
				}

				if ( '\'' === substr( ltrim( $writecsstextqarr[0] ), 0, 1 ) ) {
					$hypos               = '\'';
					$writecsstextqarr[0] = substr( ltrim( $writecsstextqarr[0] ), 1 );
				}

				if ( '"' === substr( ltrim( $writecsstextqarr[0] ), 0, 1 ) ) {
					$hypos               = '"';
					$writecsstextqarr[0] = substr( ltrim( $writecsstextqarr[0] ), 1 );
				}

				$writecsstextqarr[0] = ltrim( $writecsstextqarr[0] );
				if ( '' === $hypos ) {
					$strposspace      = strpos( $writecsstextqarr[0], ' ' );
					$writecsstextarr2 = array();
					if ( $strposspace > 1 ) {
						$writecsstextarr2[0] = substr( $writecsstextqarr[0], 0, $strposspace );
						$writecsstextarr2[1] = substr( $writecsstextqarr[0], $strposspace + 1 );
					} else {
						$writecsstextarr2[0] = $writecsstextqarr[0];
						$writecsstextarr2[1] = '';
					}
				} else {
					$writecsstextarr2 = explode( $hypos, $writecsstextqarr[0] );
				}

				$urltocheck    = $writecsstextarr2[0];
				$urltocheckout = str_replace( 'https://', '', $urltocheck );
				$urltocheckout = str_replace( 'http://', '', $urltocheckout );
				if ( $urltocheckout === $urltocheck ) {
					$urltocheck = str_replace( 'url(', '', $urltocheck );
					$urltocheck = str_replace( '"', '', $urltocheck );
					$urltocheck = str_replace( "'", '', $urltocheck );
					$urltocheck = str_replace( ')', '', $urltocheck );
					if ( '/' !== substr( $urltocheck, 0, 1 ) ) {
						$checkuppatharr      = explode( '../', $urltocheck );
						$countcheckuppatharr = count( $checkuppatharr );
						if ( $countcheckuppatharr > 0 ) {
							$outurltocheck      = $checkuppatharr[ $countcheckuppatharr - 1 ];
							$outurltocheckpart1 = '';
							for ( $p = 0; $p <= ( $countcheckpatharr - $countcheckuppatharr ); $p++ ) {
								$outurltocheckpart1 .= $checkpatharr[ $p ] . '/';
							}

							$urltocheck = $outurltocheckpart1 . $outurltocheck;
						} else {
							$urltocheck = $checkpath . '/' . $urltocheck;
						}

						$writecsstextarr2[0] = $urltocheck;
						$atimporttoreplace   = '@import' . $fullimportelement;
					} else {
						$atimporttoreplace = '@import' . $fullimportelement;
					}
				} else {
					$atimporttoreplace = '@import' . $fullimportelement;
				}

				$filefromroot = $urltocheck;
				if ( DIRECTORY_SEPARATOR !== substr( $filefromroot, 0, 1 ) ) {
					$filefromroot = DIRECTORY_SEPARATOR . $filefromroot;
				}

				$rawfilestrarr = explode(
					'?',
					realpath(
						str_replace(
							$this->extensionrelwinpath . '\Classes\Controller',
							'',
							str_replace( $this->extensionrelpath . '/Classes/Controller', '', __DIR__ )
						)
					) . $filefromroot
				);
				$rawfilestr    = $rawfilestrarr[0];
				$fileimport    = str_replace( ':\\', ':\\\\', $rawfilestr );

				if ( file_exists( $fileimport ) ) {
					$writecsstextout .= file_get_contents( $fileimport ) . "\n"; //phpcs:ignore WordPress.WP.AlternativeFunctions.file_get_contents_file_get_contents
				} else {
					$writecsstextout .= $atimporttoreplace . "\n";
				}

				$writecsstextout .= $remainingcss;
			}

			$writecsstextout = $initialcss . $writecsstextout;
		}

		return $writecsstextout;
	}

	/**
	 * Modified function for static version numbers on files, based on the filemtime.
	 *
	 * @param string $file Relative path to file including all potential query parameters (not htmlspecialchared yet).
	 *
	 * @return string Relative path with version filename including the timestamp.
	 */
	private function create_version_numbered_filename( $file ) {
		$lookup_file = explode( '?', $file );
		$path        = realpath(
			str_replace(
				$this->extensionrelwinpath . '\Classes\Controller',
				'',
				str_replace( $this->extensionrelpath . '/Classes/Controller', '', __DIR__ )
			)
		) . $lookup_file[0];
		if ( ! file_exists( $path ) ) {
			// File not found, return filename unaltered.
			$full_name = $file;
		} else {
			// If use of .htaccess rule is not configured.
			// we use the default query-string method.
			if ( isset( $lookup_file[1] ) ) {
				$separator = '&';
			} else {
				$separator = '?';
			}

			$full_name = $file . $separator . filemtime( $path );
		}

		return $full_name;
	}


	/**
	 * Used to determine page name.
	 * Url-name of the page like 'home.html?L=2&no_cache=1&purge_cache=0&objecttype=someobjecttype&id=4546'.
	 * removes all numbers in querystring, as well as no_cache=1,purge_cache=1,L=0.
	 *
	 * @return string name like 'home.html?L=&objecttype=someobjecttype&id='.
	 */
	private function current_page_name() {
		if ( ! isset( $_SERVER['REQUEST_URI'] ) ) {
			if ( isset( $_SERVER['PHP_SELF'] ) ) {
				$serverrequri = sanitize_text_field( wp_unslash( $_SERVER['PHP_SELF'] ) );
			}
		} else {
			$serverrequri = sanitize_text_field( wp_unslash( $_SERVER['REQUEST_URI'] ) );
		}

		$slcurrent_page_namearr = explode( '?', $serverrequri );
		if ( count( $slcurrent_page_namearr ) > 1 ) {
			if ( str_replace( '?s=', '', $serverrequri ) === $serverrequri ) {
				$slcurrent_page_name = $slcurrent_page_namearr[0];
			} else {
				$slcurrent_page_name = $slcurrent_page_namearr[0] . '?s=';
			}
		} else {
			$slcurrent_page_name = $serverrequri;
		}

		return $slcurrent_page_name;
	}

	/**
	 * Call for folding.
	 *
	 * @param array $datain data to split and model arrays.
	 *
	 * @return array $data
	 */
	private function get_split_merge_css( $datain ) {
		$dataarr         = array(
			'data' => $datain,
		);
		$css_above_below = new \Indexreloadedcssabovebelow();
		$data            = $css_above_below->main( $dataarr, $this );
		return $data;
	}

	/**
	 * Function to get the client IP address.
	 *
	 * @return string client IP address
	 */
	private function get_client_ip() {
		$ipaddress = '';
		if ( getenv( 'HTTP_CLIENT_IP' ) ) {
			$ipaddress = getenv( 'HTTP_CLIENT_IP' );
		} elseif ( getenv( 'HTTP_X_FORWARDED_FOR' ) ) {
			$ipaddress = getenv( 'HTTP_X_FORWARDED_FOR' );
		} elseif ( getenv( 'HTTP_X_FORWARDED' ) ) {
			$ipaddress = getenv( 'HTTP_X_FORWARDED' );
		} elseif ( getenv( 'HTTP_FORWARDED_FOR' ) ) {
			$ipaddress = getenv( 'HTTP_FORWARDED_FOR' );
		} elseif ( getenv( 'HTTP_FORWARDED' ) ) {
			$ipaddress = getenv( 'HTTP_FORWARDED' );
		} elseif ( getenv( 'REMOTE_ADDR' ) ) {
			$ipaddress = getenv( 'REMOTE_ADDR' );
		} else {
			$ipaddress = 'UNKNOWN';
		}

		return $ipaddress;
	}

	/**
	 * Amen and EOF
	 */
}
